@@ -12,14 +12,14 @@ from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
-import unittest
+from unittest import TestCase
 
 from ansible.errors import AnsibleFilterError
 
 from ansible_collections.ansible.utils.plugins.filter.ip4_hex import _ip4_hex
 
 
-class TestIpWrap(unittest.TestCase):
+class TestIpWrap(TestCase):
     def setUp(self):
         pass
 
