@@ -58,7 +58,10 @@ class TestEosRoute_MapsModule(TestEosModule):
                                 description="merged_map",
                                 action="permit",
                                 sequence=10,
-                                match=dict(router_id=22),
+                                match=dict(
+                                    router_id=22,
+                                    community=dict(community_list="list1"),
+                                ),
                             ),
                             dict(
                                 description="newmap",
@@ -114,6 +117,9 @@ class TestEosRoute_MapsModule(TestEosModule):
                                     tag=3,
                                     local_preference=51,
                                     evpn=True,
+                                    ipv6=dict(
+                                        address="10.1.1.1/32",
+                                    ),
                                 ),
                             ),
                         ],
@@ -132,6 +138,7 @@ class TestEosRoute_MapsModule(TestEosModule):
             "set tag 3",
             "set local-preference 51",
             "set evpn next-hop unchanged",
+            "set ipv6 next-hop 10.1.1.1/32",
         ]
         self.execute_module(changed=True, commands=commands)
 
@@ -148,7 +155,10 @@ class TestEosRoute_MapsModule(TestEosModule):
                                 action="permit",
                                 sequence=10,
                                 set=dict(bgp=20),
-                                match=dict(router_id=22),
+                                match=dict(
+                                    router_id=22,
+                                    community=dict(community_list="list1"),
+                                ),
                             ),
                             dict(
                                 description="newmap",
@@ -215,6 +225,7 @@ class TestEosRoute_MapsModule(TestEosModule):
             "route-map mapmerge permit 10",
             "match ipv6 resolved-next-hop prefix-list listr",
             "no match router-id prefix-list 22",
+            "no match community list1",
             "no set bgp bestpath as-path weight 20",
             "no description",
             "route-map mapmerge deny 90",
@@ -235,7 +246,10 @@ class TestEosRoute_MapsModule(TestEosModule):
                                 description="merged_map",
                                 action="permit",
                                 sequence=10,
-                                match=dict(router_id=22),
+                                match=dict(
+                                    router_id=22,
+                                    community=dict(community_list="list1"),
+                                ),
                                 set=dict(bgp=20),
                             ),
                             dict(
@@ -264,6 +278,19 @@ class TestEosRoute_MapsModule(TestEosModule):
                             ),
                         ],
                     ),
+                    dict(
+                        route_map="mapmerge3",
+                        entries=[
+                            dict(
+                                action="permit",
+                                sequence=5,
+                                set=dict(
+                                    metric=dict(value="+20"),
+                                    community_attributes=dict(community=dict(number="20000:20000")),
+                                ),
+                            ),
+                        ],
+                    ),
                 ],
             ),
         )
@@ -316,10 +343,12 @@ class TestEosRoute_MapsModule(TestEosModule):
         commands = [
             "no route-map mapmerge deny 25",
             "no route-map mapmerge2 deny 45",
+            "no route-map mapmerge3 permit 5",
             "route-map mapmerge permit 10",
             "match ipv6 address prefix-list test_prefix",
             "set metric igp-nexthop-cost",
             "no match router-id prefix-list 22",
+            "no match community list1",
             "no set bgp bestpath as-path weight 20",
             "no description",
             "route-map mapmerge deny 90",
@@ -338,7 +367,7 @@ class TestEosRoute_MapsModule(TestEosModule):
 
     def test_eos_route_maps_delete_all(self):
         set_module_args(dict(state="deleted"))
-        commands = ["no route-map mapmerge", "no route-map mapmerge2"]
+        commands = ["no route-map mapmerge", "no route-map mapmerge2", "no route-map mapmerge3"]
         self.execute_module(changed=True, commands=commands)
 
     def test_eos_route_maps_render(self):
@@ -353,7 +382,10 @@ class TestEosRoute_MapsModule(TestEosModule):
                                 description="merged_map",
                                 action="permit",
                                 sequence=10,
-                                match=dict(router_id=22),
+                                match=dict(
+                                    router_id=22,
+                                    community=dict(community_list="list1"),
+                                ),
                             ),
                             dict(
                                 description="newmap",
@@ -380,6 +412,19 @@ class TestEosRoute_MapsModule(TestEosModule):
                             ),
                         ],
                     ),
+                    dict(
+                        route_map="mapmerge3",
+                        entries=[
+                            dict(
+                                action="permit",
+                                sequence=5,
+                                set=dict(
+                                    metric=dict(value="+20"),
+                                    community_attributes=dict(community=dict(number="20000:20000")),
+                                ),
+                            ),
+                        ],
+                    ),
                 ],
             ),
         )
@@ -387,6 +432,7 @@ class TestEosRoute_MapsModule(TestEosModule):
             "route-map mapmerge permit 10",
             "description merged_map",
             "match router-id prefix-list 22",
+            "match community list1",
             "route-map mapmerge deny 25",
             "description newmap",
             "match interface Ethernet1",
@@ -395,6 +441,9 @@ class TestEosRoute_MapsModule(TestEosModule):
             "match ipv6 resolved-next-hop prefix-list list1",
             "set metric 25 +igp-metric",
             "set as-path prepend last-as 2",
+            "route-map mapmerge3 permit 5",
+            "set metric +20",
+            "set community 20000:20000",
         ]
 
         result = self.execute_module(changed=False)
@@ -415,7 +464,10 @@ class TestEosRoute_MapsModule(TestEosModule):
                 {
                     "action": "permit",
                     "description": "merged_map",
-                    "match": {"router_id": "22"},
+                    "match": {
+                        "router_id": "22",
+                        "community": {"community_list": "list1"},
+                    },
                     "sequence": 10,
                     "set": {"bgp": 20},
                 },
@@ -439,9 +491,19 @@ class TestEosRoute_MapsModule(TestEosModule):
                     "sub_route_map": {"name": "mapmerge"},
                 },
             ],
+            "mapmerge3": [
+                {
+                    "action": "permit",
+                    "sequence": 5,
+                    "set": {
+                        "metric": {"value": "+20"},
+                        "community_attributes": {"community": {"number": "20000:20000"}},
+                    },
+                },
+            ],
         }
         for entry in result["gathered"]:
-            if entry.get("route_map") in ["mapmerge", "mapmerge2"]:
+            if entry.get("route_map") in ["mapmerge", "mapmerge2", "mapmerge3"]:
                 self.assertEqual(
                     gathered_list[entry["route_map"]],
                     entry["entries"],
@@ -461,6 +523,9 @@ class TestEosRoute_MapsModule(TestEosModule):
             "sub-route-map mapmerge",
             "set metric 25 +igp-metric",
             "set as-path prepend last-as 2",
+            "route-map mapmerge3 permit 5",
+            "set metric +20",
+            "set community 20000:20000",
         ]
 
         parsed_str = "\n".join(commands)
@@ -500,5 +565,18 @@ class TestEosRoute_MapsModule(TestEosModule):
                 ],
                 "route_map": "mapmerge2",
             },
+            {
+                "entries": [
+                    {
+                        "action": "permit",
+                        "sequence": 5,
+                        "set": {
+                            "metric": {"value": "+20"},
+                            "community_attributes": {"community": {"number": "20000:20000"}},
+                        },
+                    },
+                ],
+                "route_map": "mapmerge3",
+            },
         ]
         self.assertEqual(parsed_list, result["parsed"])
