@@ -21,6 +21,17 @@ description:
     - Get facts for one storage account or all storage accounts within a resource group.
 
 options:
+    auth_mode:
+        description:
+            - The mode in which to run the command. C(login) mode will directly use your login credentials for the authentication.
+            - The legacy C(key) mode will attempt to query for an account key if no authentication parameters for the account are provided.
+            - Can also be set via the environment variable C(AZURE_STORAGE_AUTH_MODE).
+        default: key
+        type: str
+        choices:
+            - key
+            - login
+        version_added: "3.10.0"
     name:
         description:
             - Only show results for a specific account.
@@ -138,6 +149,25 @@ storageaccounts:
             returned: always
             type: str
             sample: Standard_ZRS
+        allow_cross_tenant_replication:
+            description:
+                - Allow or disallow cross AAD tenant object replication.
+            type: bool
+            returned: always
+            sample: true
+        allow_shared_key_access:
+            description:
+                - Indicates whether the storage account permits requests to be authorized with the account access key via Shared Key.
+            type: bool
+            returned: always
+            sample: true
+        default_to_o_auth_authentication:
+            description:
+                - A boolean flag which indicates whether the default authentication is OAuth or not.
+                - The default interpretation is false for this property.
+            type: bool
+            returned: always
+            sample: true
         custom_domain:
             description:
                 - User domain assigned to the storage account.
@@ -205,12 +235,77 @@ storageaccounts:
                             type: dict
                             returned: always
                             sample: {'enabled': true}
+                encryption_identity:
+                    description:
+                        - The identity to be used with service-side encryption at rest.
+                    type: dict
+                    returned: always
+                    sample: {"encryption_user_assigned_identity": \
+                        "/subscriptions/xxxx/resourcegroups/testRG/providers/Microsoft.ManagedIdentity/userAssignedIdentities/identity-11"}
+                key_vault_properties:
+                    description:
+                        - Dict of Microsoft Keyvault properties.
+                        - Create the Storage account with encryption enabled with Microsoft KeyVault for CMK.
+                    type: dict
+                    returned: always
+                    sample: {"key_name": "testkey",
+                             "key_vault_uri": "https://vxxxxxxx01.vault.azure.net/",
+                             "key_version": "0bd2556671c64fc998xxxxeb12"}
         is_hns_enabled:
             description:
                 - Account HierarchicalNamespace enabled if sets to true.
             type: bool
             returned: always
             sample: true
+        immutable_storage_with_versioning:
+            description:
+                - The property is immutable and can only be set to true at the account creation time.
+                - When set to true, it enables object level immutability for all the containers in the account by default.
+            type: complex
+            returned: when-used
+            contains:
+                enabled:
+                    description:
+                        - A boolean flag which enables account-level immutability.
+                        - All the containers under such an account have object-level immutability enabled by default.
+                    type: bool
+                    returned: when-used
+                    sample: true
+                immutability_policy:
+                    description:
+                        - Specifies the default account-level immutability policy which is inherited and
+                          applied to objects that do not possess an explicit immutability policy at the object level.
+                        - The object-level immutability policy has higher precedence than the container-level immutability policy,
+                          which has a higher precedence than the account-level immutability policy.
+                    type: dict
+                    returned: when-used
+                    contains:
+                        allow_protected_append_writes:
+                            description:
+                                - This property can only be changed for disabled and unlocked time-based retention policies.
+                                - When enabled, new blocks can be written to an append blob while maintaining immutability protection and compliance.
+                                - Only new blocks can be added and any existing blocks cannot be modified or deleted.
+                            type: bool
+                            returned: when-used
+                            sample: true
+                        state:
+                            description:
+                                - The ImmutabilityPolicy state defines the mode of the policy.
+                            type: str
+                            returned: when-used
+                            sample: Unlocked
+                        immutability_period_since_creation_in_days:
+                            description:
+                                - The immutability period for the blobs in the container since the policy creation, in days.
+                            type: int
+                            returned: when-used
+                            sample: true
+        enable_nfs_v3:
+            description:
+                - NFS 3.0 protocol.
+            type: bool
+            returned: always
+            sample: false
         kind:
             description:
                 - The kind of storage.
@@ -509,6 +604,12 @@ storageaccounts:
             returned: always
             type: dict
             sample: { "tag1": "abc" }
+        large_file_shares_state:
+            description:
+                - Allow large file shares if sets to Enabled.
+            type: str
+            returned: always
+            sample: Enabled
         static_website:
             description:
                 - Static website configuration for the storage account.
@@ -539,6 +640,7 @@ storageaccounts:
 
 from ansible_collections.azure.azcollection.plugins.module_utils.azure_rm_common import AzureRMModuleBase
 from ansible.module_utils._text import to_native
+from ansible.module_utils.basic import env_fallback
 
 
 AZURE_OBJECT_CLASS = 'StorageAccount'
@@ -548,6 +650,12 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
     def __init__(self):
 
         self.module_arg_spec = dict(
+            auth_mode=dict(
+                type='str',
+                choices=['key', 'login'],
+                fallback=(env_fallback, ['AZURE_STORAGE_AUTH_MODE']),
+                default="key"
+            ),
             name=dict(type='str'),
             resource_group=dict(type='str', aliases=['resource_group_name']),
             tags=dict(type='list', elements='str'),
@@ -574,9 +682,6 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
                                                         facts_module=True)
 
     def exec_module(self, **kwargs):
-        is_old_facts = self.module._name == 'azure_rm_storageaccount_facts'
-        if is_old_facts:
-            self.module.deprecate("The 'azure_rm_storageaccount_facts' module has been renamed to 'azure_rm_storageaccount_info'", version=(2.9, ))
 
         for key in self.module_arg_spec:
             setattr(self, key, kwargs[key])
@@ -594,11 +699,6 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
 
         filtered = self.filter_tag(results)
 
-        if is_old_facts:
-            self.results['ansible_facts'] = {
-                'azure_storageaccounts': self.serialize(filtered),
-                'storageaccounts': self.format_to_dict(filtered),
-            }
         self.results['storageaccounts'] = self.format_to_dict(filtered)
         return self.results
 
@@ -674,11 +774,17 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
             public_network_access=account_obj.public_network_access,
             allow_blob_public_access=account_obj.allow_blob_public_access,
             is_hns_enabled=account_obj.is_hns_enabled if account_obj.is_hns_enabled else False,
+            large_file_shares_state=account_obj.large_file_shares_state,
+            enable_nfs_v3=account_obj.enable_nfs_v3 if hasattr(account_obj, 'enable_nfs_v3') else None,
+            allow_cross_tenant_replication=account_obj.allow_cross_tenant_replication,
+            allow_shared_key_access=account_obj.allow_shared_key_access,
+            default_to_o_auth_authentication=account_obj.default_to_o_auth_authentication,
             static_website=dict(
                 enabled=False,
                 index_document=None,
                 error_document404_path=None,
             ),
+            immutable_storage_with_versioning=account_obj.immutable_storage_with_versioning.as_dict() if account_obj.immutable_storage_with_versioning else None
         )
 
         account_dict['geo_replication_stats'] = None
@@ -773,6 +879,22 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
                     account_dict['encryption']['services']['queue'] = dict(enabled=True)
                 if account_obj.encryption.services.blob:
                     account_dict['encryption']['services']['blob'] = dict(enabled=True)
+            if account_obj.encryption.encryption_identity:
+                account_dict['encryption']['encryption_identity'] = dict(
+                    encryption_user_assigned_identity=account_obj.encryption.encryption_identity.encryption_user_assigned_identity)
+            else:
+                account_dict['encryption']['encryption_identity'] = None
+            if account_obj.encryption.key_vault_properties:
+                account_dict['encryption']['key_vault_properties'] = dict(key_vault_uri=account_obj.encryption.key_vault_properties.key_vault_uri,
+                                                                          key_name=account_obj.encryption.key_vault_properties.key_name,
+                                                                          key_version=account_obj.encryption.key_vault_properties.key_version)
+            else:
+                account_dict['encryption']['key_vault_properties'] = None
+
+        account_dict['identity'] = dict()
+        if account_obj.identity:
+            account_dict['identity'] = account_obj.identity.as_dict()
+
         return account_dict
 
     def format_endpoint_dict(self, name, key, endpoint, storagetype, protocol='https'):
@@ -800,7 +922,7 @@ class AzureRMStorageAccountInfo(AzureRMModuleBase):
         if kind == "FileStorage":
             return None
         try:
-            return self.get_blob_service_client(resource_group, name).get_service_properties()
+            return self.get_blob_service_client(resource_group, name, self.auth_mode).get_service_properties()
         except Exception:
             pass
         return None
