@@ -35,6 +35,7 @@ class TestDnacNetworkSettings(TestDnacModule):
     playbook_config_reserve_pool_deletion = test_data.get("playbook_config_reserve_pool_deletion")
     playbook_config_global_pool_deletion = test_data.get("playbook_config_global_pool_deletion")
     playbook_config_device_controlability = test_data.get("playbook_config_device_controlability")
+    playbook_reset_network = test_data.get("playbook_reset_network")
 
     def setUp(self):
         super(TestDnacNetworkSettings, self).setUp()
@@ -76,12 +77,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "not_verified" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -98,7 +99,7 @@ class TestDnacNetworkSettings(TestDnacModule):
                 self.test_data.get("update"),
                 self.test_data.get("task"),
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
+                self.test_data.get("dhcp_get_response"),
                 self.test_data.get("dns_get"),
                 self.test_data.get("telemetry_get"),
                 self.test_data.get("ntp_get"),
@@ -110,13 +111,13 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "network_update" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
-                self.test_data.get("AAA_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
+                self.test_data.get("get_AAA"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
                 self.test_data.get("update"),
@@ -144,24 +145,24 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_update_dhcp" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
             ]
 
         if "exception_update_ntp" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -170,12 +171,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_update_timezone" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -186,12 +187,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_update_dns" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -204,12 +205,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_update_banner" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -224,12 +225,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_update_aaa" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -246,12 +247,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_site_not_exist" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -272,12 +273,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_update_telemetry" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("AAA_get"),
                 self.test_data.get("update"),
                 self.test_data.get("task"),
@@ -294,52 +295,52 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "exception_dns_get" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
+                self.test_data.get("dhcp_get_response"),
             ]
 
         if "exception_telemetry_get" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
             ]
 
         if "exception_ntp_get" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
             ]
 
         if "exception_timezone_get" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
+                self.test_data.get("ntp_get_response"),
             ]
 
         if "exception_banner_get" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
             ]
 
         if "exception_aaa_get" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
             ]
 
         if "exception_dhcp_get" in self._testMethodName:
@@ -350,12 +351,12 @@ class TestDnacNetworkSettings(TestDnacModule):
         if "update_not_required" in self._testMethodName:
             self.run_dnac_exec.side_effect = [
                 self.test_data.get("get_sites_test"),
-                self.test_data.get("dhcp_get"),
-                self.test_data.get("dns_get"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
                 self.test_data.get("telemetry_get"),
-                self.test_data.get("ntp_get"),
-                self.test_data.get("timeZone_get"),
-                self.test_data.get("banner_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
                 self.test_data.get("get_AAA"),
                 self.test_data.get("get_sites_test"),
             ]
@@ -429,6 +430,32 @@ class TestDnacNetworkSettings(TestDnacModule):
                 self.test_data.get("get_tasks_by_id_device_controlability"),
             ]
 
+        if "resetting_server_configuration" in self._testMethodName:
+            self.run_dnac_exec.side_effect = [
+                self.test_data.get("get_sites_resetting_server_configuration"),
+                self.test_data.get("dhcp_get_response"),
+                self.test_data.get("dns_get_response"),
+                self.test_data.get("telemetry_get"),
+                self.test_data.get("ntp_get_response"),
+                self.test_data.get("timezone_get_response"),
+                self.test_data.get("banner_get_response"),
+                self.test_data.get("get_AAA"),
+                self.test_data.get("update"),
+                self.test_data.get("task"),
+                self.test_data.get("update"),
+                self.test_data.get("task"),
+                self.test_data.get("update"),
+                self.test_data.get("task"),
+                self.test_data.get("update"),
+                self.test_data.get("task"),
+                self.test_data.get("update"),
+                self.test_data.get("task"),
+                self.test_data.get("update"),
+                self.test_data.get("task"),
+                self.test_data.get("update"),
+                self.test_data.get("task"),
+            ]
+
     def test_Network_settings_workflow_manager_network_network_not_need_update(self):
         """
         Test case for site workflow manager when creating a site.
@@ -1030,3 +1057,28 @@ class TestDnacNetworkSettings(TestDnacModule):
             "An exception occurred while retrieving Site details for Site 'Global/Abc2' does not exist in the Cisco Catalyst Center.",
             result["response"]
         )
+
+    def test_Network_settings_workflow_manager_resetting_server_configuration(self):
+        """
+        Test case for network settings workflow manager when resetting server configuration.
+
+        This test case checks the behavior of the network settings workflow manager when resetting server configuration.
+        """
+        set_module_args(
+            dict(
+                dnac_host="1.1.1.1",
+                dnac_username="dummy",
+                dnac_password="dummy",
+                dnac_log=True,
+                state="merged",
+                config_verify=False,
+                dnac_version="2.3.7.9",
+                config=self.playbook_reset_network
+            )
+        )
+        result = self.execute_module(changed=True, failed=False)
+        print(result["response"][2]["network"]["msg"])
+        self.assertEqual(
+            {'Global/Testing/test': 'Network Updated successfully'},
+            result["response"][2]["network"]["msg"]
+        )
