@@ -176,7 +176,7 @@ def main():
         role=dict(type='str', choices=['admin', 'readonly', 'user'], required=True),
         password=dict(type='str', required=True, no_log=True),
     )
-    argument_spec = intersight_argument_spec
+    argument_spec = intersight_argument_spec.copy()
     argument_spec.update(
         state=dict(type='str', choices=['present', 'absent'], default='present'),
         organization=dict(type='str', default='default'),
@@ -197,18 +197,43 @@ def main():
     )
 
     intersight = IntersightModule(module)
+    organization_moid = None
+    # get Organization Moid
+    intersight.get_resource(
+        resource_path='/organization/Organizations',
+        query_params={
+            '$filter': "Name eq '" + intersight.module.params['organization'] + "'",
+            '$select': 'Moid',
+        },
+    )
+    if intersight.result['api_response'].get('Moid'):
+        # resource exists and moid was returned
+        organization_moid = intersight.result['api_response']['Moid']
     intersight.result['api_response'] = {}
     intersight.result['trace_id'] = ''
 
     # get the current state of the resource
+    filter_str = "Name eq '" + intersight.module.params['name'] + "'"
+    filter_str += "and Organization.Moid eq '" + organization_moid + "'"
     intersight.get_resource(
         resource_path='/iam/EndPointUserPolicies',
         query_params={
-            '$filter': "Name eq '" + intersight.module.params['name'] + "'",
+            '$filter': filter_str,
             '$expand': 'EndPointUserRoles($expand=EndPointRole,EndPointUser),Organization',
         },
     )
 
+    if module.params['state'] == 'present':
+        intersight.api_body = {
+            'Name': intersight.module.params['name'],
+            'PasswordProperties': {
+                'EnforceStrongPassword': intersight.module.params['enforce_strong_password'],
+                'EnablePasswordExpiry': intersight.module.params['enable_password_expiry'],
+                'PasswordHistory': intersight.module.params['password_history'],
+            },
+        }
+        intersight.set_tags_and_description()
+
     user_policy_moid = None
     resource_values_match = False
     if intersight.result['api_response'].get('Moid'):
@@ -237,19 +262,9 @@ def main():
                         },
                     }
                 )
-            intersight.api_body = {
-                'Name': intersight.module.params['name'],
-                'Tags': intersight.module.params['tags'],
-                'Description': intersight.module.params['description'],
-                'PasswordProperties': {
-                    'EnforceStrongPassword': intersight.module.params['enforce_strong_password'],
-                    'EnablePasswordExpiry': intersight.module.params['enable_password_expiry'],
-                    'PasswordHistory': intersight.module.params['password_history'],
-                },
-                'EndPointUserRoles': end_point_user_roles,
-                'Organization': {
-                    'Name': intersight.module.params['organization'],
-                },
+            intersight.api_body['EndPointUserRoles'] = end_point_user_roles
+            intersight.api_body['Organization'] = {
+                'Name': intersight.module.params['organization'],
             }
             resource_values_match = compare_values(intersight.api_body, intersight.result['api_response'])
         elif module.params['state'] == 'absent':
@@ -260,38 +275,13 @@ def main():
             user_policy_moid = None
 
     if module.params['state'] == 'present' and not resource_values_match:
-        intersight.api_body = {
-            'Name': intersight.module.params['name'],
-            'Tags': intersight.module.params['tags'],
-            'Description': intersight.module.params['description'],
-            'PasswordProperties': {
-                'EnforceStrongPassword': intersight.module.params['enforce_strong_password'],
-                'EnablePasswordExpiry': intersight.module.params['enable_password_expiry'],
-                'PasswordHistory': intersight.module.params['password_history'],
-            },
+        intersight.api_body['Organization'] = {
+            'Moid': organization_moid,
         }
-        organization_moid = None
-        if not user_policy_moid or module.params['purge']:
-            # get Organization Moid which is needed when resources are created
-            saved_response = intersight.result['api_response']
-            intersight.get_resource(
-                resource_path='/organization/Organizations',
-                query_params={
-                    '$filter': "Name eq '" + intersight.module.params['organization'] + "'",
-                    '$select': 'Moid',
-                },
-            )
-            if intersight.result['api_response'].get('Moid'):
-                # resource exists and moid was returned
-                organization_moid = intersight.result['api_response']['Moid']
-            intersight.result['api_response'] = saved_response
-            if not user_policy_moid:
-                # Initial create: Organization must be set, but can't be changed after initial POST
-                intersight.api_body['Organization'] = {
-                    'Moid': organization_moid,
-                }
-            elif module.params['purge']:
-                # update existing resource and purge any existing users
+
+        if module.params['purge']:
+            # update existing resource and purge any existing users
+            if intersight.result['api_response'].get('EndPointUserRoles'):
                 for end_point_user_role in intersight.result['api_response']['EndPointUserRoles']:
                     intersight.delete_resource(
                         moid=end_point_user_role['Moid'],
@@ -311,62 +301,78 @@ def main():
             # resource exists and moid was returned
             user_policy_moid = intersight.result['api_response']['Moid']
 
-        # EndPointUser local_users list config
-        for user in intersight.module.params['local_users']:
-            intersight.api_body = {
-                'Name': user['username'],
-            }
-            if organization_moid:
-                intersight.api_body['Organization'] = {
-                    'Moid': organization_moid,
-                }
-            intersight.configure_resource(
-                moid=None,
-                resource_path='/iam/EndPointUsers',
-                body=intersight.api_body,
-                query_params={
-                    '$filter': "Name eq '" + user['username'] + "'",
-                },
-            )
-            user_moid = None
-            if intersight.result['api_response'].get('Moid'):
-                # resource exists and moid was returned
-                user_moid = intersight.result['api_response']['Moid']
-            # GET EndPointRole Moid
-            intersight.get_resource(
-                resource_path='/iam/EndPointRoles',
-                query_params={
-                    '$filter': "Name eq '" + user['role'] + "' and Type eq 'IMC'",
-                },
-            )
-            end_point_role_moid = None
-            if intersight.result['api_response'].get('Moid'):
-                # resource exists and moid was returned
-                end_point_role_moid = intersight.result['api_response']['Moid']
-            # EndPointUserRole config
-            intersight.api_body = {
-                'EndPointUser': {
-                    'Moid': user_moid,
-                },
-                'EndPointRole': [
-                    {
-                        'Moid': end_point_role_moid,
+            # EndPointUser local_users list config
+            for user in intersight.module.params['local_users']:
+                intersight.result['api_response'] = {}
+                # check for existing user in this organization
+                filter_str = "Name eq '" + user['username'] + "'"
+                filter_str += "and Organization.Moid eq '" + organization_moid + "'"
+                intersight.get_resource(
+                    resource_path='/iam/EndPointUsers',
+                    query_params={
+                        '$filter': filter_str
+                    },
+                )
+                user_moid = None
+                if intersight.result['api_response'].get('Moid'):
+                    # resource exists and moid was returned
+                    user_moid = intersight.result['api_response']['Moid']
+                else:
+                    # create user if it doesn't exist
+                    intersight.api_body = {
+                        'Name': user['username'],
                     }
-                ],
-                'Password': user['password'],
-                'Enabled': user['enable'],
-                'EndPointUserPolicy': {
-                    'Moid': user_policy_moid,
-                },
-            }
-            intersight.configure_resource(
-                moid=None,
-                resource_path='/iam/EndPointUserRoles',
-                body=intersight.api_body,
-                query_params={
-                    '$filter': "EndPointUserPolicy.Moid eq '" + user_policy_moid + "'",
-                },
-            )
+                    if organization_moid:
+                        intersight.api_body['Organization'] = {
+                            'Moid': organization_moid,
+                        }
+                    intersight.configure_resource(
+                        moid=None,
+                        resource_path='/iam/EndPointUsers',
+                        body=intersight.api_body,
+                        query_params={
+                            '$filter': "Name eq '" + user['username'] + "'",
+                        },
+                    )
+                    user_moid = None
+                    if intersight.result['api_response'].get('Moid'):
+                        # resource exists and moid was returned
+                        user_moid = intersight.result['api_response']['Moid']
+                # GET EndPointRole Moid
+                intersight.get_resource(
+                    resource_path='/iam/EndPointRoles',
+                    query_params={
+                        '$filter': "Name eq '" + user['role'] + "' and Type eq 'IMC'",
+                    },
+                )
+                end_point_role_moid = None
+                if intersight.result['api_response'].get('Moid'):
+                    # resource exists and moid was returned
+                    end_point_role_moid = intersight.result['api_response']['Moid']
+                # EndPointUserRole config
+                intersight.api_body = {
+                    'EndPointUser': {
+                        'Moid': user_moid,
+                    },
+                    'EndPointRole': [
+                        {
+                            'Moid': end_point_role_moid,
+                        }
+                    ],
+                    'Password': user['password'],
+                    'Enabled': user['enable'],
+                    'EndPointUserPolicy': {
+                        'Moid': user_policy_moid,
+                    },
+                }
+                intersight.configure_resource(
+                    moid=None,
+                    resource_path='/iam/EndPointUserRoles',
+                    body=intersight.api_body,
+                    query_params={
+                        '$filter': "EndPointUserPolicy.Moid eq '" + user_policy_moid + "'",
+                    },
+                )
 
     module.exit_json(**intersight.result)
 
