@@ -81,6 +81,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               neighbor 198.51.100.1 local-as 20
               neighbor 198.51.100.1 activate
               neighbor 198.51.100.1 next-hop-self all
+              neighbor 198.51.100.1 password 7 021E015232511520495706
               neighbor 198.51.100.1 aigp send cost-community 100 poi igp-cost transitive
               neighbor 198.51.100.1 route-server-client
               neighbor 198.51.100.1 prefix-list AS65100-PREFIX-OUT out
@@ -145,6 +146,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "address-family ipv4 multicast vrf blue",
             "bgp dampening 10 10 10 10",
             "aggregate-address 192.0.3.1 255.255.255.255 as-confed-set",
+            "exit-address-family",
             "address-family nsap",
             "bgp aggregate-timer 20",
             "bgp dmzlink-bw",
@@ -153,6 +155,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "neighbor 198.51.100.1 route-map test-route-out out",
             "network 192.0.1.1 route-map test_route",
             "default-metric 10",
+            "exit-address-family",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(sorted(result["commands"]), sorted(commands))
@@ -173,6 +176,10 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                     remote_as=65001,
                                     soft_reconfiguration=True,
                                     prefix_list=dict(name="PREFIX-OUT", out=True),
+                                    password_options=dict(
+                                        encryption=7,
+                                        pass_key="021E015232511520495706",
+                                    ),
                                 ),
                             ],
                             network=[dict(address="192.0.3.1", mask="255.255.255.0")],
@@ -186,9 +193,11 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "router bgp 65000",
             "address-family ipv4 unicast vrf blue",
             "neighbor 192.0.3.1 remote-as 65001",
+            "neighbor 192.0.3.1 password 7 021E015232511520495706",
             "neighbor 192.0.3.1 prefix-list PREFIX-OUT out",
             "neighbor 192.0.3.1 soft-reconfiguration inbound",
             "network 192.0.3.1 mask 255.255.255.0",
+            "exit-address-family",
         ]
 
         result = self.execute_module(changed=True)
@@ -211,6 +220,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               neighbor TEST-PEER-GROUP send-community
               neighbor TEST-PEER-GROUP next-hop-self all
               neighbor 2001:db8::1 activate
+              maximum-secondary-paths eibgp 2
+              maximum-paths 12
              !
              address-family ipv4 multicast
               table-map test_tableMap filter
@@ -238,6 +249,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               neighbor 198.51.100.1 next-hop-self all
               neighbor 198.51.100.1 aigp send cost-community 100 poi igp-cost transitive
               neighbor 198.51.100.1 route-server-client
+              neighbor 198.51.100.1 as-override split-horizon
               neighbor 198.51.100.1 prefix-list AS65100-PREFIX-OUT out
               neighbor 198.51.100.1 slow-peer detection threshold 150
               neighbor 198.51.100.1 route-map test-out out
@@ -251,6 +263,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                         {
                             "afi": "ipv4",
                             "bgp": {"redistribute_internal": True},
+                            "maximum_paths": {"paths": 12},
+                            "maximum_secondary_paths": {"eibgp": 2},
                             "neighbors": [
                                 {
                                     "neighbor_address": "TEST-PEER-GROUP",
@@ -460,6 +474,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "neighbor 198.51.110.1 route-map test-replaced-route out",
             "no neighbor 198.51.100.1",
             "no network 198.51.110.10 mask 255.255.255.255 backdoor",
+            "exit-address-family",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(sorted(result["commands"]), sorted(commands))
@@ -501,7 +516,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               bgp slow-peer detection threshold 150
               bgp dampening 1 1 1 1
               network 198.51.110.10 mask 255.255.255.255 backdoor
-              aggregate-address 192.0.2.1 255.255.255.255 as-confed-set
+              aggregate-address 192.0.2.10 255.255.255.255 as-confed-set
               neighbor 198.51.100.1 remote-as 10
               neighbor 198.51.100.1 local-as 20
               neighbor 198.51.100.1 activate
@@ -525,7 +540,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                             vrf="blue",
                             aggregate_address=[
                                 dict(
-                                    address="192.0.2.1",
+                                    address="192.0.2.10",
                                     netmask="255.255.255.255",
                                     as_confed_set=True,
                                 ),
@@ -658,6 +673,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               neighbor 198.51.100.1 local-as 20
               neighbor 198.51.100.1 activate
               neighbor 198.51.100.1 next-hop-self all
+              neighbor 198.51.100.1 as-override split-horizon
               neighbor 198.51.100.1 aigp send cost-community 100 poi igp-cost transitive
               neighbor 198.51.100.1 route-server-client
               neighbor 198.51.100.1 prefix-list AS65100-PREFIX-OUT out
@@ -724,6 +740,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                 dict(
                                     activate=True,
                                     address="198.51.100.1",
+                                    as_override=dict(set=True, split_horizon=True),
                                     aigp=dict(
                                         send=dict(
                                             cost_community=dict(
@@ -850,7 +867,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
         set_module_args(dict(state="deleted"))
         commands = [
             "router bgp 65000",
-            "no address-family ipv4",
+            "no address-family ipv4 unicast",
             "no address-family ipv4 multicast vrf blue",
             "no address-family ipv4 mdt",
             "no address-family ipv4 multicast",
@@ -938,6 +955,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                             afi="ipv4",
                             safi="multicast",
                             vrf="blue",
+                            maximum_paths=dict(paths=12),
+                            maximum_secondary_paths=dict(eibgp=2),
                             aggregate_address=[
                                 dict(
                                     address="192.0.2.1",
@@ -957,6 +976,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                 dict(
                                     activate=True,
                                     address="198.51.100.1",
+                                    as_override=dict(set=True, split_horizon=True),
                                     aigp=dict(
                                         send=dict(
                                             cost_community=dict(
@@ -1023,14 +1043,18 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "router bgp 65000",
             "address-family ipv4 multicast vrf blue",
             "bgp dampening 1 1 1 1",
+            "maximum-secondary-paths eibgp 2",
+            "maximum-paths 12",
             "neighbor 198.51.100.1 remote-as 10",
             "neighbor 198.51.100.1 activate",
             "neighbor 198.51.100.1 aigp send cost-community 100 poi igp-cost transitive",
             "neighbor 198.51.100.1 route-map test-route out",
+            "neighbor 198.51.100.1 as-override split-horizon",
             "neighbor 198.51.100.1 route-server-client",
             "neighbor 198.51.100.1 slow-peer detection threshold 150",
             "network 198.51.110.10 mask 255.255.255.255 backdoor",
             "aggregate-address 192.0.2.1 255.255.255.255 as-confed-set",
+            "exit-address-family",
             "address-family ipv4 multicast",
             "network 198.51.111.11 mask 255.255.255.255 route-map test",
             "aggregate-address 192.0.3.1 255.255.255.255 as-confed-set",
@@ -1038,6 +1062,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "distance bgp 10 10 100",
             "table-map test_tableMap filter",
             "snmp context testsnmp user abc credential encrypted access ipv6 ipcal",
+            "exit-address-family",
         ]
         result = self.execute_module(changed=False)
         self.assertEqual(sorted(result["rendered"]), sorted(commands))
@@ -1061,6 +1086,8 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                       neighbor TEST-PEER-GROUP send-community
                       neighbor TEST-PEER-GROUP next-hop-self all
                       neighbor 2001:db8::1 activate
+                      maximum-secondary-paths eibgp 2
+                      maximum-paths 12
                      !
                      address-family ipv4 multicast
                       table-map test_tableMap filter
@@ -1086,6 +1113,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                       neighbor 198.51.100.1 local-as 20
                       neighbor 198.51.100.1 activate
                       neighbor 198.51.100.1 next-hop-self all
+                      neighbor 198.51.100.1 password 7 021E015232511520495706
                       neighbor 198.51.100.1 aigp send cost-community 100 poi igp-cost transitive
                       neighbor 198.51.100.1 route-server-client
                       neighbor 198.51.100.1 prefix-list AS65100-PREFIX-OUT out
@@ -1112,10 +1140,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                 "metric": 100,
                                 "match": {
                                     "internal": True,
-                                    "externals": {
-                                        "type_1": True,
-                                        "type_2": True,
-                                    },
+                                    "externals": {"type_1": True, "type_2": True},
                                 },
                             },
                         },
@@ -1128,8 +1153,14 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                         },
                         {"neighbor_address": "2001:db8::1", "activate": True},
                     ],
+                    # --- CHANGE: Key order adjusted to match desired output ---
+                    "maximum_secondary_paths": {"eibgp": 2},
+                    "maximum_paths": {"paths": 12},
+                    # --- CHANGE: 'safi' key added ---
+                    "safi": "unicast",
                 },
                 {
+                    # Second address-family (ipv4 multicast) - NO CHANGES
                     "afi": "ipv4",
                     "safi": "multicast",
                     "table_map": {"name": "test_tableMap", "filter": True},
@@ -1151,6 +1182,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                     "distance": {"external": 10, "internal": 10, "local": 100},
                 },
                 {
+                    # Third address-family (ipv4 mdt) - NO CHANGES
                     "afi": "ipv4",
                     "safi": "mdt",
                     "bgp": {
@@ -1165,6 +1197,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                     },
                 },
                 {
+                    # Fourth address-family (ipv4 multicast vrf blue)
                     "afi": "ipv4",
                     "safi": "multicast",
                     "vrf": "blue",
@@ -1196,8 +1229,9 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                         {
                             "remote_as": "10",
                             "local_as": {"set": True, "number": "20"},
-                            "activate": True,
+                            # --- CHANGE: Key order adjusted to match desired output ---
                             "neighbor_address": "198.51.100.1",
+                            "activate": True,
                             "nexthop_self": {"all": True},
                             "aigp": {
                                 "send": {
@@ -1207,10 +1241,12 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
                                     },
                                 },
                             },
+                            "password_options": {
+                                "encryption": 7,
+                                "pass_key": "021E015232511520495706",
+                            },
                             "route_server_client": True,
-                            "prefix_lists": [
-                                {"name": "AS65100-PREFIX-OUT", "out": True},
-                            ],
+                            "prefix_lists": [{"name": "AS65100-PREFIX-OUT", "out": True}],
                             "slow_peer_options": {"detection": {"threshold": 150}},
                             "route_maps": [{"name": "test-out", "out": True}],
                         },
@@ -1253,7 +1289,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
         )
         commands = [
             "router bgp 65000",
-            "address-family ipv4",
+            "address-family ipv4 unicast",
             "neighbor 192.31.39.212 activate",
             "neighbor 192.31.39.212 soft-reconfiguration inbound",
             "neighbor 192.31.47.206 activate",
@@ -1261,6 +1297,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "network 192.0.3.1 mask 255.255.255.0",
             "network 192.0.2.1 mask 255.255.255.0",
             "network 192.0.4.1 mask 255.255.255.0",
+            "exit-address-family",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(sorted(result["commands"]), sorted(commands))
@@ -1287,6 +1324,7 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
               table-map test_tableMap filter
               network 198.51.111.11 mask 255.255.255.255 route-map test
               aggregate-address 192.0.3.1 255.255.255.255 as-confed-set
+              redistribute ospf 200 metric 100 match internal external 1 external 2
               default-metric 12
               distance bgp 10 10 100
              exit-address-family
@@ -1347,6 +1385,9 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
         )
         commands = [
             "router bgp 65000",
+            "no neighbor TEST-PEER-GROUP",
+            "no neighbor 2001:db8::1",
+            "no neighbor 198.51.100.1",
             "address-family ipv4 multicast",
             "no default-metric 12",
             "no distance bgp 10 10 100",
@@ -1354,29 +1395,211 @@ class TestIosBgpAddressFamilyModule(TestIosModule):
             "no table-map test_tableMap filter",
             "no network 198.51.111.11 mask 255.255.255.255 route-map test",
             "no aggregate-address 192.0.3.1 255.255.255.255 as-confed-set",
+            "exit-address-family",
             "address-family ipv4 mdt",
             "no bgp dmzlink-bw",
             "no bgp soft-reconfig-backup",
             "no bgp dampening 1 10 100 5",
+            "exit-address-family",
             "address-family ipv4 multicast vrf blue",
             "no bgp aggregate-timer 10",
             "no bgp dampening 1 1 1 1",
             "no bgp slow-peer detection threshold 150",
-            "no neighbor 198.51.100.1",
             "no network 198.51.110.10 mask 255.255.255.255 backdoor",
             "no aggregate-address 192.0.2.1 255.255.255.255 as-confed-set",
-            "address-family ipv4",
+            "exit-address-family",
+            "address-family ipv4 unicast",
             "no bgp redistribute-internal",
             "no redistribute connected",
+            "no redistribute ospf 200",
             "neighbor 192.31.39.212 activate",
             "neighbor 192.31.39.212 soft-reconfiguration inbound",
             "neighbor 192.31.47.206 activate",
             "neighbor 192.31.47.206 soft-reconfiguration inbound",
-            "no neighbor TEST-PEER-GROUP",
-            "no neighbor 2001:db8::1",
             "network 192.0.3.1 mask 255.255.255.0",
             "network 192.0.2.1 mask 255.255.255.0",
             "network 192.0.4.1 mask 255.255.255.0",
+            "exit-address-family",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(sorted(result["commands"]), sorted(commands))
+
+    def test_ios_bgp_address_family_ipv6_replaced(self):
+        self.execute_show_command.return_value = dedent(
+            """\
+            router bgp 65000
+             bgp log-neighbor-changes
+             neighbor 2001:db8::1 remote-as 65002
+             !
+             address-family ipv6 unicast
+              aggregate-address 2001:DB8:1234::/48 summary-only
+              aggregate-address 2001:DB8:2::/48 as-set
+              neighbor 2001:db8::1 activate
+            exit-address-family
+            """,
+        )
+
+        set_module_args(
+            dict(
+                config=dict(
+                    as_number="65000",
+                    address_family=[
+                        dict(
+                            afi="ipv6",
+                            safi="unicast",
+                            aggregate_addresses=[
+                                dict(
+                                    address="2001:db8:cd::/48",
+                                    summary_only=True,
+                                ),
+                            ],
+                            neighbors=[
+                                dict(
+                                    neighbor_address="2001:db8::2",
+                                    activate=True,
+                                    remote_as=65003,
+                                    description="New-IPv6-Neighbor",
+                                ),
+                            ],
+                        ),
+                    ],
+                ),
+                state="replaced",
+            ),
+        )
+
+        commands = [
+            "router bgp 65000",
+            "address-family ipv6 unicast",
+            "aggregate-address 2001:db8:cd::/48 summary-only",
+            "neighbor 2001:db8::2 activate",
+            "neighbor 2001:db8::2 remote-as 65003",
+            "neighbor 2001:db8::2 description New-IPv6-Neighbor",
+            "no aggregate-address 2001:DB8:2::/48 as-set",
+            "no aggregate-address 2001:DB8:1234::/48 summary-only",
+            "no neighbor 2001:db8::1",
+            "exit-address-family",
+        ]
+
+        result = self.execute_module(changed=True)
+        self.assertEqual(sorted(result["commands"]), sorted(commands))
+
+    def test_ios_bgp_address_family_ipv6_merged(self):
+        """Test IPv6 BGP configuration - merged state"""
+        self.execute_show_command.return_value = dedent(
+            """\
+            router bgp 65000
+             bgp log-neighbor-changes
+             !
+             address-family ipv6 unicast
+              aggregate-address 2001:DB8:1111::/48 as-set
+              neighbor 2001:db8::1 remote-as 65002
+              neighbor 2001:db8::1 activate
+             exit-address-family
+            """,
+        )
+
+        set_module_args(
+            dict(
+                config=dict(
+                    as_number="65000",
+                    address_family=[
+                        dict(
+                            afi="ipv6",
+                            safi="unicast",
+                            aggregate_addresses=[
+                                dict(
+                                    address="2001:DB8:2222::/48",
+                                    summary_only=True,
+                                ),
+                            ],
+                            neighbors=[
+                                dict(
+                                    neighbor_address="2001:db8::2",
+                                    activate=True,
+                                    remote_as=65003,
+                                ),
+                            ],
+                            networks=[
+                                dict(address="2001:DB8:FEED::/64"),
+                            ],
+                        ),
+                    ],
+                ),
+                state="merged",
+            ),
+        )
+
+        commands = [
+            "router bgp 65000",
+            "address-family ipv6 unicast",
+            "aggregate-address 2001:DB8:2222::/48 summary-only",
+            "neighbor 2001:db8::2 remote-as 65003",
+            "neighbor 2001:db8::2 activate",
+            "network 2001:DB8:FEED::/64",
+            "exit-address-family",
+        ]
+
+        result = self.execute_module(changed=True)
+        self.assertEqual(sorted(result["commands"]), sorted(commands))
+
+    def test_ios_bgp_address_family_ipv6_overridden(self):
+        """Test IPv6 BGP configuration - overridden state"""
+        self.execute_show_command.return_value = dedent(
+            """\
+            router bgp 65000
+             !
+             address-family ipv4 unicast
+              neighbor 192.0.2.1 remote-as 65001
+              neighbor 192.0.2.1 activate
+             exit-address-family
+             !
+             address-family ipv6 unicast
+              aggregate-address 2001:DB8:OLD::/48 as-set
+              neighbor 2001:db8::OLD remote-as 65002
+              neighbor 2001:db8::OLD activate
+             exit-address-family
+            """,
+        )
+
+        set_module_args(
+            dict(
+                config=dict(
+                    as_number="65000",
+                    address_family=[
+                        dict(
+                            afi="ipv6",
+                            safi="unicast",
+                            aggregate_addresses=[
+                                dict(
+                                    address="2001:DB8:NEW::/48",
+                                    summary_only=True,
+                                ),
+                            ],
+                            neighbors=[
+                                dict(
+                                    neighbor_address="2001:db8::NEW",
+                                    activate=True,
+                                    remote_as=65003,
+                                ),
+                            ],
+                        ),
+                    ],
+                ),
+                state="overridden",
+            ),
+        )
+        commands = [
+            "router bgp 65000",
+            "no neighbor 192.0.2.1",
+            "address-family ipv6 unicast",
+            "no aggregate-address 2001:DB8:OLD::/48 as-set",
+            "no neighbor 2001:db8::OLD",
+            "aggregate-address 2001:DB8:NEW::/48 summary-only",
+            "neighbor 2001:db8::NEW remote-as 65003",
+            "neighbor 2001:db8::NEW activate",
+            "exit-address-family",
+        ]
+
+        result = self.execute_module(changed=True)
+        self.assertEqual(sorted(result["commands"]), sorted(commands))
