@@ -33,38 +33,59 @@ def is_list_complex(x):
 
 
 def has_diff_elem(ls1, ls2):
-    return any((elem not in ls1 for elem in ls2))
+    """Checks if there are different elements between two lists."""
+    if len(ls1) != len(ls2):
+        return True
+    return any(elem not in ls1 for elem in ls2)
+
+
+def compare_dicts(dict1, dict2, common_keys):
+    """Compares two dictionaries considering the defined rules."""
+    for key in dict1:
+        if key in dict2 and key in common_keys:
+            val1, val2 = dict1[key], dict2[key]
+
+            if isinstance(val1, str) and have_to_change_to_lowercase(val1.lower()):
+                if val1.lower() != val2.lower():
+                    return True
+            elif isinstance(val1, list):
+                if has_diff_elem(val1, val2):
+                    return True
+            else:
+                if isinstance(val1, dict) and isinstance(val2, dict):
+                    # common_keys between val1 and val2
+                    new_common_keys = set(val1.keys()) & set(val2.keys())
+                    compare_dicts(val1, val2, new_common_keys)
+                    if compare_dicts(val1, val2, new_common_keys):
+                        return True
+                else:
+                    if str(val1) != str(val2):
+                        return True
+    return False
 
 
 def has_diff_elem2(ls1, ls2):
-    for elem in ls2:
+    """Compares two lists, with dictionaries inside them, to detect differences."""
+    if len(ls1) != len(ls2):
+        return True
+    # Only compare common keys between ls1 and ls2
+    common_keys = set(ls1[0].keys()) & set(ls2[0].keys())
+    for i, elem in enumerate(ls2):
         if isinstance(elem, dict):
-            find = False
-            keys1 = elem.keys()
-            for elem2 in ls1:
-                keys2 = elem2.keys()
-                common_keys = []
-                for key in keys1:
-                    if key in keys2:
-                        common_keys.append(key)
-                has_diff = False
-                for k in common_keys:
-                    if isinstance(elem2[k], str) and have_to_change_to_lowercase(elem2[k].lower()):
-                        if elem2[k].lower() != elem[k].lower():
-                            has_diff = True
-                    else:
-                        if elem2[k] != elem[k]:
-                            has_diff = True
-                if not has_diff:
-                    find = True
-                    break
-            if not find:
+            # Ensure ls1[i] is also a dictionary
+            if not isinstance(ls1[i], dict):
                 return True
+            if compare_dicts(ls1[i], elem, common_keys):
+                return True
+        else:
+            # If elements are not dictionaries, compare them directly
+            if str(ls1[i]) != str(elem):
+                return True
+
     return False
 
 
 def have_to_change_to_lowercase(attr):
-    # print("hola")
     return attr in lowercase_change_words
 
 
@@ -75,7 +96,6 @@ def delete_default_rule(ls):
             del ls[index]
             break
         index = index + 1
-    print(ls)
     return ls
 
 
@@ -132,9 +152,14 @@ def meraki_compare_equality(current_value, requested_value):
 
 def meraki_compare_equality2(current_value, requested_value):
     # print("meraki_compare_equality", current_value, requested_value)
+    if requested_value is not None and current_value is None:
+        # print("requested_value is not None and current_value is None", False)
+        return False
     if requested_value is None:
+        # print("requested_value is None", True)
         return True
     if current_value is None:
+        # print("current_value", True)
         return True
     if isinstance(current_value, dict) and isinstance(requested_value, dict):
         all_dict_params = list(current_value.keys()) + \
@@ -143,6 +168,7 @@ def meraki_compare_equality2(current_value, requested_value):
     elif isinstance(current_value, list) and isinstance(requested_value, list):
         return compare_list(current_value, requested_value)
     else:
+        # print("current_value == requested_value", current_value == requested_value)
         return current_value == requested_value
 
 
@@ -229,7 +255,7 @@ class MERAKI(object):
                 suppress_logging=params.get("meraki_suppress_logging"),
                 simulate=params.get("meraki_simulate"),
                 be_geo_id=params.get("meraki_be_geo_id"),
-                caller="MerakiAnsibleCollection/2.20.5 Cisco",
+                caller="MerakiAnsibleCollection/2.21.2 Cisco",
                 use_iterator_for_get_pages=params.get(
                     "meraki_use_iterator_for_get_pages"),
                 inherit_logging_config=params.get(
@@ -309,7 +335,7 @@ class MERAKI(object):
         except exceptions.APIError as e:
             self.fail_json(
                 msg=(
-                    "An error occured when executing operation."
+                    "An error occurred when executing operation."
                     "The error was: {error}"
                 ).format(error=to_native(e))
             )
