@@ -5,71 +5,105 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-DOCUMENTATION = '''
+DOCUMENTATION = r"""
 author:
-    - Felix Fontein (@felixfontein)
+  - Felix Fontein (@felixfontein)
 name: docker_api
 short_description: Run tasks in docker containers
 version_added: 1.1.0
 description:
-    - Run commands or put/fetch files to an existing docker container.
-    - Uses the L(requests library,https://pypi.org/project/requests/) to interact
-      directly with the Docker daemon instead of using the Docker CLI. Use the
-      R(community.docker.docker,ansible_collections.community.docker.docker_connection)
-      connection plugin if you want to use the Docker CLI.
+  - Run commands or put/fetch files to an existing docker container.
+  - Uses the L(requests library,https://pypi.org/project/requests/) to interact directly with the Docker daemon instead of
+    using the Docker CLI. Use the P(community.docker.docker#connection) connection plugin if you want to use the Docker CLI.
 notes:
-    - Does B(not work with TCP TLS sockets)! This is caused by the inability to send C(close_notify) without closing the connection
-      with Python's C(SSLSocket)s. See U(https://github.com/ansible-collections/community.docker/issues/605) for more information.
+  - Does B(not work with TCP TLS sockets)! This is caused by the inability to send C(close_notify) without closing the connection
+    with Python's C(SSLSocket)s. See U(https://github.com/ansible-collections/community.docker/issues/605) for more information.
 extends_documentation_fragment:
-    - community.docker.docker.api_documentation
-    - community.docker.docker.var_names
+  - community.docker.docker.api_documentation
+  - community.docker.docker.var_names
 options:
-    remote_user:
-        type: str
-        description:
-            - The user to execute as inside the container.
-        vars:
-            - name: ansible_user
-            - name: ansible_docker_user
-        ini:
-            - section: defaults
-              key: remote_user
-        env:
-            - name: ANSIBLE_REMOTE_USER
-        cli:
-            - name: user
-        keyword:
-            - name: remote_user
-    remote_addr:
-        type: str
-        description:
-            - The name of the container you want to access.
-        default: inventory_hostname
-        vars:
-            - name: inventory_hostname
-            - name: ansible_host
-            - name: ansible_docker_host
-    container_timeout:
-        default: 10
-        description:
-            - Controls how long we can wait to access reading output from the container once execution started.
-        env:
-            - name: ANSIBLE_TIMEOUT
-            - name: ANSIBLE_DOCKER_TIMEOUT
-              version_added: 2.2.0
-        ini:
-            - key: timeout
-              section: defaults
-            - key: timeout
-              section: docker_connection
-              version_added: 2.2.0
-        vars:
-            - name: ansible_docker_timeout
-              version_added: 2.2.0
-        cli:
-            - name: timeout
-        type: integer
-'''
+  remote_user:
+    type: str
+    description:
+      - The user to execute as inside the container.
+    vars:
+      - name: ansible_user
+      - name: ansible_docker_user
+    ini:
+      - section: defaults
+        key: remote_user
+    env:
+      - name: ANSIBLE_REMOTE_USER
+    cli:
+      - name: user
+    keyword:
+      - name: remote_user
+  remote_addr:
+    type: str
+    description:
+      - The name of the container you want to access.
+    default: inventory_hostname
+    vars:
+      - name: inventory_hostname
+      - name: ansible_host
+      - name: ansible_docker_host
+  container_timeout:
+    default: 10
+    description:
+      - Controls how long we can wait to access reading output from the container once execution started.
+    env:
+      - name: ANSIBLE_TIMEOUT
+      - name: ANSIBLE_DOCKER_TIMEOUT
+        version_added: 2.2.0
+    ini:
+      - key: timeout
+        section: defaults
+      - key: timeout
+        section: docker_connection
+        version_added: 2.2.0
+    vars:
+      - name: ansible_docker_timeout
+        version_added: 2.2.0
+    cli:
+      - name: timeout
+    type: integer
+  extra_env:
+    description:
+      - Provide extra environment variables to set when running commands in the Docker container.
+      - This option can currently only be provided as Ansible variables due to limitations of ansible-core's configuration
+        manager.
+    vars:
+      - name: ansible_docker_extra_env
+    type: dict
+    version_added: 3.12.0
+  working_dir:
+    description:
+      - The directory inside the container to run commands in.
+      - Requires Docker API version 1.35 or later.
+    env:
+      - name: ANSIBLE_DOCKER_WORKING_DIR
+    ini:
+      - key: working_dir
+        section: docker_connection
+    vars:
+      - name: ansible_docker_working_dir
+    type: string
+    version_added: 3.12.0
+  privileged:
+    description:
+      - Whether commands should be run with extended privileges.
+      - B(Note) that this allows command to potentially break out of the container. Use with care!
+    env:
+      - name: ANSIBLE_DOCKER_PRIVILEGED
+    ini:
+      - key: privileged
+        section: docker_connection
+    vars:
+      - name: ansible_docker_privileged
+    type: boolean
+    default: false
+    version_added: 3.12.0
+"""
 
 import os
 import os.path
@@ -98,6 +132,8 @@ from ansible_collections.community.docker.plugins.plugin_utils.common_api import
 
 from ansible_collections.community.docker.plugins.module_utils._api.errors import APIError, DockerException, NotFound
 
+from ansible_collections.community.docker.plugins.module_utils.version import LooseVersion
+
 MIN_DOCKER_API = None
 
 
@@ -159,9 +195,9 @@ class Connection(ConnectionBase):
             self._connected = True
 
             if self.actual_user is None and display.verbosity > 2:
-                # Since we're not setting the actual_user, look it up so we have it for logging later
+                # Since we are not setting the actual_user, look it up so we have it for logging later
                 # Only do this if display verbosity is high enough that we'll need the value
-                # This saves overhead from calling into docker when we don't need to
+                # This saves overhead from calling into docker when we do not need to
                 display.vvv(u"Trying to determine actual user")
                 result = self._call_client(lambda: self.client.get_json('/containers/{0}/json', self.get_option('remote_addr')))
                 if result.get('Config'):
@@ -192,7 +228,7 @@ class Connection(ConnectionBase):
         data = {
             'Container': self.get_option('remote_addr'),
             'User': self.get_option('remote_user') or '',
-            'Privileged': False,
+            'Privileged': self.get_option('privileged'),
             'Tty': False,
             'AttachStdin': need_stdin,
             'AttachStdout': True,
@@ -203,6 +239,27 @@ class Connection(ConnectionBase):
         if 'detachKeys' in self.client._general_configs:
             data['detachKeys'] = self.client._general_configs['detachKeys']
 
+        if self.get_option('extra_env'):
+            data['Env'] = []
+            for k, v in self.get_option('extra_env').items():
+                for val, what in ((k, 'Key'), (v, 'Value')):
+                    if not isinstance(val, str):
+                        raise AnsibleConnectionFailure(
+                            'Non-string {0} found for extra_env option. Ambiguous env options must be '
+                            'wrapped in quotes to avoid them being interpreted. {1}: {2!r}'
+                            .format(what.lower(), what, val)
+                        )
+                data['Env'].append(u'{0}={1}'.format(to_text(k, errors='surrogate_or_strict'), to_text(v, errors='surrogate_or_strict')))
+
+        if self.get_option('working_dir') is not None:
+            data['WorkingDir'] = self.get_option('working_dir')
+            if self.client.docker_api_version < LooseVersion('1.35'):
+                raise AnsibleConnectionFailure(
+                    'Providing the working directory requires Docker API version 1.35 or newer.'
+                    ' The Docker daemon the connection is using has API version {0}.'
+                    .format(self.client.docker_api_version_str)
+                )
+
         exec_data = self._call_client(lambda: self.client.post_json_to_json('/containers/{0}/exec', self.get_option('remote_addr'), data=data))
         exec_id = exec_data['Id']
 
@@ -252,11 +309,11 @@ class Connection(ConnectionBase):
         ''' Make sure that we put files into a standard path
 
             If a path is relative, then we need to choose where to put it.
-            ssh chooses $HOME but we aren't guaranteed that a home dir will
-            exist in any given chroot.  So for now we're choosing "/" instead.
+            ssh chooses $HOME but we are not guaranteed that a home dir will
+            exist in any given chroot.  So for now we are choosing "/" instead.
             This also happens to be the former default.
 
-            Can revisit using $HOME instead if it's a problem
+            Can revisit using $HOME instead if it is a problem
         '''
         if getattr(self._shell, "_IS_WINDOWS", False):
             import ntpath
