@@ -15,8 +15,7 @@ import logging
 import struct
 from functools import partial
 
-from ansible.module_utils.six import PY3, binary_type, iteritems, string_types, raise_from
-from ansible.module_utils.six.moves.urllib.parse import quote
+from ansible_collections.community.docker.plugins.module_utils._six import PY3, binary_type, iteritems, string_types, raise_from, quote
 
 from .. import auth
 from .._import_helper import fail_on_missing_imports
@@ -202,7 +201,14 @@ class APIClient(
 
     def _retrieve_server_version(self):
         try:
-            return self.version(api_version=False)["ApiVersion"]
+            version_result = self.version(api_version=False)
+        except Exception as e:
+            raise DockerException(
+                'Error while fetching server API version: {0}'.format(e)
+            )
+
+        try:
+            return version_result["ApiVersion"]
         except KeyError:
             raise DockerException(
                 'Invalid response from docker daemon: key "ApiVersion"'
@@ -210,7 +216,7 @@ class APIClient(
             )
         except Exception as e:
             raise DockerException(
-                'Error while fetching server API version: {0}'.format(e)
+                'Error while fetching server API version: {0}. Response seems to be broken.'.format(e)
             )
 
     def _set_request_timeout(self, kwargs):
@@ -574,6 +580,7 @@ class APIClient(
 
     def post_json_to_text(self, pathfmt, *args, **kwargs):
         data = kwargs.pop('data', None)
+        return self._result(self._post_json(self._url(pathfmt, *args, versioned_api=True), data, **kwargs))
 
     def post_json_to_stream_socket(self, pathfmt, *args, **kwargs):
         data = kwargs.pop('data', None)
