@@ -15,13 +15,14 @@ from functools import partial
 
 from ansible.module_utils.common.text.converters import to_native, to_text
 from ansible.module_utils.common.text.formatters import human_to_bytes
-from ansible.module_utils.six import string_types
+from ansible_collections.community.docker.plugins.module_utils._six import string_types
 
 from ansible_collections.community.docker.plugins.module_utils.util import (
     clean_dict_booleans_for_docker_api,
     compare_generic,
     normalize_healthcheck,
     omit_none_from_dict,
+    sanitize_labels,
 )
 
 from ansible_collections.community.docker.plugins.module_utils._platform import (
@@ -37,13 +38,19 @@ _DEFAULT_IP_REPLACEMENT_STRING = '[[DEFAULT_IP:iewahhaeB4Sae6Aen8IeShairoh4zeph7
 
 
 _MOUNT_OPTION_TYPES = dict(
-    volume_driver='volume',
-    volume_options='volume',
-    propagation='bind',
-    no_copy='volume',
-    labels='volume',
-    tmpfs_size='tmpfs',
-    tmpfs_mode='tmpfs',
+    create_mountpoint=('bind',),
+    labels=('volume',),
+    no_copy=('volume',),
+    non_recursive=('bind',),
+    propagation=('bind',),
+    read_only_force_recursive=('bind',),
+    read_only_non_recursive=('bind',),
+    subpath=('volume', 'image'),
+    tmpfs_size=('tmpfs',),
+    tmpfs_mode=('tmpfs',),
+    tmpfs_options=('tmpfs',),
+    volume_driver=('volume',),
+    volume_options=('volume',),
 )
 
 
@@ -195,7 +202,7 @@ class Engine(object):
         pass
 
     @abc.abstractmethod
-    def ignore_mismatching_result(self, module, client, api_version, option, image, container_value, expected_value):
+    def ignore_mismatching_result(self, module, client, api_version, option, image, container_value, expected_value, host_info):
         pass
 
     @abc.abstractmethod
@@ -299,8 +306,11 @@ class EngineDriver(object):
     def connect_container_to_network(self, client, container_id, network_id, parameters=None):
         pass
 
+    def create_container_supports_more_than_one_network(self, client):
+        return False
+
     @abc.abstractmethod
-    def create_container(self, client, container_name, create_parameters):
+    def create_container(self, client, container_name, create_parameters, networks=None):
         pass
 
     @abc.abstractmethod
@@ -579,12 +589,18 @@ def _preprocess_mounts(module, values):
             mount_dict = dict(mount)
 
             # Sanity checks
-            if mount['source'] is None and mount_type not in ('tmpfs', 'volume'):
+            if mount['source'] is None and mount_type not in ('tmpfs', 'volume', 'image', 'cluster'):
                 module.fail_json(msg='source must be specified for mount "{0}" of type "{1}"'.format(target, mount_type))
-            for option, req_mount_type in _MOUNT_OPTION_TYPES.items():
-                if mount[option] is not None and mount_type != req_mount_type:
+            for option, req_mount_types in _MOUNT_OPTION_TYPES.items():
+                if mount[option] is not None and mount_type not in req_mount_types:
                     module.fail_json(
-                        msg='{0} cannot be specified for mount "{1}" of type "{2}" (needs type "{3}")'.format(option, target, mount_type, req_mount_type)
+                        msg='{0} cannot be specified for mount "{1}" of type "{2}" (needs type{3} "{4}")'.format(
+                            option,
+                            target,
+                            mount_type,
+                            "" if len(req_mount_types) == 1 else "s",
+                            '", "'.join(req_mount_types),
+                        )
                     )
 
             # Streamline options
@@ -603,6 +619,18 @@ def _preprocess_mounts(module, values):
                     mount_dict['tmpfs_mode'] = int(mount_dict['tmpfs_mode'], 8)
                 except Exception as dummy:
                     module.fail_json(msg='tmp_fs mode of mount "{0}" is not an octal string!'.format(target))
+            if mount_dict['tmpfs_options']:
+                opts = []
+                for idx, opt in enumerate(mount_dict['tmpfs_options']):
+                    if len(opt) != 1:
+                        module.fail_json(msg='tmpfs_options[{1}] of mount "{0}" must be a one-element dictionary!'.format(target, idx + 1))
+                    k, v = list(opt.items())[0]
+                    if not isinstance(k, str):
+                        module.fail_json(msg='key {2!r} in tmpfs_options[{1}] of mount "{0}" must be a string!'.format(target, idx + 1, k))
+                    if v is not None and not isinstance(v, str):
+                        module.fail_json(msg='value {2!r} in tmpfs_options[{1}] of mount "{0}" must be a string or null/none!'.format(target, idx + 1, v))
+                    opts.append([k, v] if v is not None else [k])
+                mount_dict['tmpfs_options'] = opts
 
             # Add result to list
             mounts.append(omit_none_from_dict(mount_dict))
@@ -648,6 +676,17 @@ def _preprocess_mounts(module, values):
     return values
 
 
+def _preprocess_labels(module, values):
+    result = {}
+    if 'labels' in values:
+        labels = values['labels']
+        if labels is not None:
+            labels = dict(labels)
+            sanitize_labels(labels, 'labels', module=module)
+        result['labels'] = labels
+    return result
+
+
 def _preprocess_log(module, values):
     result = {}
     if 'log_driver' not in values:
@@ -895,6 +934,11 @@ OPTION_DEVICE_REQUESTS = (
     ))
 )
 
+OPTION_DEVICE_CGROUP_RULES = (
+    OptionGroup()
+    .add_option('device_cgroup_rules', type='list', elements='str')
+)
+
 OPTION_DNS_SERVERS = (
     OptionGroup()
     .add_option('dns_servers', type='list', elements='str')
@@ -935,9 +979,11 @@ OPTION_HEALTHCHECK = (
     OptionGroup(preprocess=_preprocess_healthcheck)
     .add_option('healthcheck', type='dict', ansible_suboptions=dict(
         test=dict(type='raw'),
+        test_cli_compatible=dict(type='bool', default=False),
         interval=dict(type='str'),
         timeout=dict(type='str'),
         start_period=dict(type='str'),
+        start_interval=dict(type='str'),
         retries=dict(type='int'),
     ))
 )
@@ -968,7 +1014,7 @@ OPTION_KERNEL_MEMORY = (
 )
 
 OPTION_LABELS = (
-    OptionGroup()
+    OptionGroup(preprocess=_preprocess_labels)
     .add_option('labels', type='dict', needs_no_suboptions=True)
 )
 
@@ -1147,7 +1193,7 @@ OPTION_MOUNTS_VOLUMES = (
     .add_option('mounts', type='set', elements='dict', ansible_suboptions=dict(
         target=dict(type='str', required=True),
         source=dict(type='str'),
-        type=dict(type='str', choices=['bind', 'volume', 'tmpfs', 'npipe'], default='volume'),
+        type=dict(type='str', choices=['bind', 'volume', 'tmpfs', 'npipe', 'cluster', 'image'], default='volume'),
         read_only=dict(type='bool'),
         consistency=dict(type='str', choices=['default', 'consistent', 'cached', 'delegated']),
         propagation=dict(type='str', choices=['private', 'rprivate', 'shared', 'rshared', 'slave', 'rslave']),
@@ -1157,6 +1203,12 @@ OPTION_MOUNTS_VOLUMES = (
         volume_options=dict(type='dict'),
         tmpfs_size=dict(type='str'),
         tmpfs_mode=dict(type='str'),
+        non_recursive=dict(type='bool'),
+        create_mountpoint=dict(type='bool'),
+        read_only_non_recursive=dict(type='bool'),
+        read_only_force_recursive=dict(type='bool'),
+        subpath=dict(type='str'),
+        tmpfs_options=dict(type='list', elements='dict'),
     ))
     .add_option('volumes', type='set', elements='str')
     .add_option('volume_binds', type='set', elements='str', not_an_ansible_option=True, copy_comparison_from='volumes')
@@ -1192,6 +1244,7 @@ OPTIONS = [
     OPTION_DEVICE_READ_IOPS,
     OPTION_DEVICE_WRITE_IOPS,
     OPTION_DEVICE_REQUESTS,
+    OPTION_DEVICE_CGROUP_RULES,
     OPTION_DNS_SERVERS,
     OPTION_DNS_OPTS,
     OPTION_DNS_SEARCH_DOMAINS,
