@@ -8,19 +8,20 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: docker_image
 
 short_description: Manage docker images
 
 description:
-  - Build, load or pull an image, making the image available for creating containers. Also supports tagging
-    an image, pushing an image, and archiving an image to a C(.tar) file.
-
+  - Build, load or pull an image, making the image available for creating containers. Also supports tagging an image, pushing
+    an image, and archiving an image to a C(.tar) file.
+  - We recommend to use the individual modules M(community.docker.docker_image_build), M(community.docker.docker_image_export),
+    M(community.docker.docker_image_load), M(community.docker.docker_image_pull), M(community.docker.docker_image_push),
+    M(community.docker.docker_image_remove), and M(community.docker.docker_image_tag) instead of this module.
 notes:
-  - Building images is done using Docker daemon's API. It is not possible to use BuildKit / buildx this way.
-
+  - Building images is done using Docker daemon's API. It is not possible to use BuildKit / buildx this way. Use M(community.docker.docker_image_build)
+    to build images with BuildKit.
 extends_documentation_fragment:
   - community.docker.docker.api_documentation
   - community.docker.attributes
@@ -33,27 +34,30 @@ attributes:
       - When trying to pull an image, the module assumes this is always changed in check mode.
   diff_mode:
     support: none
+  idempotent:
+    support: partial
+    details:
+      - Whether the module is idempotent depends on the exact parameters, in particular of O(force_source) and O(force_tag).
+      # TODO: improve idempotent details!
 
 options:
   source:
     description:
-      - "Determines where the module will try to retrieve the image from."
-      - "Use C(build) to build the image from a C(Dockerfile). I(build.path) must
-         be specified when this value is used."
-      - "Use C(load) to load the image from a C(.tar) file. I(load_path) must
-         be specified when this value is used."
-      - "Use C(pull) to pull the image from a registry."
-      - "Use C(local) to make sure that the image is already available on the local
-         docker daemon. This means that the module does not try to build, pull or load the image."
+      - Determines where the module will try to retrieve the image from.
+      - Use V(build) to build the image from a C(Dockerfile). O(build.path) must be specified when this value is used.
+      - Use V(load) to load the image from a C(.tar) file. O(load_path) must be specified when this value is used.
+      - Use V(pull) to pull the image from a registry.
+      - Use V(local) to make sure that the image is already available on the local docker daemon. This means that the module
+        does not try to build, pull or load the image.
     type: str
     choices:
-    - build
-    - load
-    - pull
-    - local
+      - build
+      - load
+      - pull
+      - local
   build:
     description:
-      - "Specifies options used for building images."
+      - Specifies options used for building images.
     type: dict
     suboptions:
       cache_from:
@@ -63,8 +67,9 @@ options:
         elements: str
       dockerfile:
         description:
-          - Use with state C(present) and source C(build) to provide an alternate name for the Dockerfile to use when building an image.
-          - This can also include a relative path (relative to I(path)).
+          - Use with O(state=present) and O(source=build) to provide an alternate name for the Dockerfile to use when building
+            an image.
+          - This can also include a relative path (relative to O(build.path)).
         type: str
       http_timeout:
         description:
@@ -73,8 +78,8 @@ options:
         type: int
       path:
         description:
-          - Use with state 'present' to build an image. Will be the path to a directory containing the context and
-            Dockerfile for building an image.
+          - Use with state 'present' to build an image. Will be the path to a directory containing the context and Dockerfile
+            for building an image.
         type: path
         required: true
       pull:
@@ -99,6 +104,8 @@ options:
       etc_hosts:
         description:
           - Extra hosts to add to C(/etc/hosts) in building containers, as a mapping of hostname to IP address.
+          - Instead of an IP address, the special value V(host-gateway) can also be used, which resolves to the host's gateway
+            IP and allows building containers to connect to services running on the host.
         type: dict
       args:
         description:
@@ -112,13 +119,19 @@ options:
         suboptions:
           memory:
             description:
-              - Set memory limit for build.
-            type: int
+              - Memory limit for build in format C(<number>[<unit>]). Number is a positive integer. Unit can be V(B) (byte),
+                V(K) (kibibyte, 1024B), V(M) (mebibyte), V(G) (gibibyte), V(T) (tebibyte), or V(P) (pebibyte).
+              - Omitting the unit defaults to bytes.
+              - Before community.docker 3.6.0, no units were allowed.
+            type: str
           memswap:
             description:
-              - Total memory (memory + swap).
-              - Use C(-1) to disable swap.
-            type: int
+              - Total memory limit (memory + swap) for build in format C(<number>[<unit>]), or the special values V(unlimited)
+                or V(-1) for unlimited swap usage. Number is a positive integer. Unit can be V(B) (byte), V(K) (kibibyte,
+                1024B), V(M) (mebibyte), V(G) (gibibyte), V(T) (tebibyte), or V(P) (pebibyte).
+              - Omitting the unit defaults to bytes.
+              - Before community.docker 3.6.0, no units were allowed, and neither was the special value V(unlimited).
+            type: str
           cpushares:
             description:
               - CPU shares (relative weight).
@@ -126,88 +139,98 @@ options:
           cpusetcpus:
             description:
               - CPUs in which to allow execution.
-              - For example, C(0-3) or C(0,1).
+              - For example, V(0-3) or V(0,1).
             type: str
       use_config_proxy:
         description:
-          - If set to C(true) and a proxy configuration is specified in the docker client configuration
-            (by default C($HOME/.docker/config.json)), the corresponding environment variables will
-            be set in the container being built.
+          - If set to V(true) and a proxy configuration is specified in the docker client configuration (by default C($HOME/.docker/config.json)),
+            the corresponding environment variables will be set in the container being built.
         type: bool
       target:
         description:
-          - When building an image specifies an intermediate build stage by
-            name as a final stage for the resulting image.
+          - When building an image specifies an intermediate build stage by name as a final stage for the resulting image.
         type: str
       platform:
         description:
           - Platform in the format C(os[/arch[/variant]]).
         type: str
         version_added: 1.1.0
+      shm_size:
+        description:
+          - Size of C(/dev/shm) in format C(<number>[<unit>]). Number is positive integer. Unit can be V(B) (byte), V(K) (kibibyte,
+            1024B), V(M) (mebibyte), V(G) (gibibyte), V(T) (tebibyte), or V(P) (pebibyte).
+          - Omitting the unit defaults to bytes. If you omit the size entirely, Docker daemon uses V(64M).
+        type: str
+        version_added: 3.6.0
+      labels:
+        description:
+          - Dictionary of key value pairs.
+        type: dict
+        version_added: 3.6.0
   archive_path:
     description:
-      - Use with state C(present) to archive an image to a .tar file.
+      - Use with O(state=present) to archive an image to a C(.tar) file.
     type: path
   load_path:
     description:
-      - Use with state C(present) to load an image from a .tar file.
-      - Set I(source) to C(load) if you want to load the image.
+      - Use with O(state=present) to load an image from a C(.tar) file.
+      - Set O(source=load) if you want to load the image.
     type: path
   force_source:
     description:
-      - Use with state C(present) to build, load or pull an image (depending on the
-        value of the I(source) option) when the image already exists.
+      - Use with O(state=present) to build, load or pull an image (depending on the value of the O(source) option) when the
+        image already exists.
     type: bool
     default: false
   force_absent:
     description:
-      - Use with state I(absent) to un-tag and remove all images matching the specified name.
+      - Use with O(state=absent) to un-tag and remove all images matching the specified name.
     type: bool
     default: false
   force_tag:
     description:
-      - Use with state C(present) to force tagging an image.
+      - Use with O(state=present) to force tagging an image.
     type: bool
     default: false
   name:
     description:
-      - "Image name. Name format will be one of: C(name), C(repository/name), C(registry_server:port/name).
-        When pushing or pulling an image the name can optionally include the tag by appending C(:tag_name)."
-      - Note that image IDs (hashes) are only supported for I(state=absent), for I(state=present) with I(source=load),
-        and for I(state=present) with I(source=local).
+      - 'Image name. Name format will be one of: C(name), C(repository/name), C(registry_server:port/name). When pushing or
+        pulling an image the name can optionally include the tag by appending C(:tag_name).'
+      - Note that image IDs (hashes) are only supported for O(state=absent), for O(state=present) with O(source=load), and
+        for O(state=present) with O(source=local).
     type: str
     required: true
   pull:
     description:
-      - "Specifies options used for pulling images."
+      - Specifies options used for pulling images.
     type: dict
     version_added: 1.3.0
     suboptions:
       platform:
         description:
           - When pulling an image, ask for this specific platform.
-          - Note that this value is not used to determine whether the image needs to be pulled. This might change
-            in the future in a minor release, though.
+          - Note that this value is not used to determine whether the image needs to be pulled. This might change in the future
+            in a minor release, though.
         type: str
   push:
     description:
-      - Push the image to the registry. Specify the registry as part of the I(name) or I(repository) parameter.
+      - Push the image to the registry. Specify the registry as part of the O(name) or O(repository) parameter.
     type: bool
     default: false
   repository:
     description:
-      - Use with state C(present) to tag the image.
-      - Expects format C(repository:tag). If no tag is provided, will use the value of the I(tag) parameter or C(latest).
-      - If I(push=true), I(repository) must either include a registry, or will be assumed to belong to the default
-        registry (Docker Hub).
+      - Use with O(state=present) to tag the image.
+      - Expects format C(repository:tag). If no tag is provided, will use the value of the O(tag) parameter or V(latest).
+      - If O(push=true), O(repository) must either include a registry, or will be assumed to belong to the default registry
+        (Docker Hub).
     type: str
   state:
     description:
       - Make assertions about the state of an image.
-      - When C(absent) an image will be removed. Use the force option to un-tag and remove all images
-        matching the provided name.
-      - When C(present) check if an image exists using the provided name and tag. If the image is not found or the
-        force option is used, the image will either be pulled, built or loaded, depending on the I(source) option.
+      - When V(absent) an image will be removed. Use the force option to un-tag and remove all images matching the provided
+        name.
+      - When V(present) check if an image exists using the provided name and tag. If the image is not found or the force option
+        is used, the image will either be pulled, built or loaded, depending on the O(source) option.
     type: str
     default: present
     choices:
@@ -215,9 +238,8 @@ options:
       - present
   tag:
     description:
-      - Used to select an image when pulling. Will be added to the image when pushing, tagging or building. Defaults to
-        I(latest).
-      - If I(name) parameter format is I(name:tag), then tag value from I(name) will take precedence.
+      - Used to select an image when pulling. Will be added to the image when pushing, tagging or building. Defaults to V(latest).
+      - If O(name) parameter format is C(name:tag), then tag value from O(name) will take precedence.
     type: str
     default: latest
 
@@ -229,15 +251,24 @@ author:
   - Chris Houseknecht (@chouseknecht)
   - Sorin Sbarnea (@ssbarnea)
 
-'''
-
-EXAMPLES = '''
+seealso:
+  - module: community.docker.docker_image_build
+  - module: community.docker.docker_image_export
+  - module: community.docker.docker_image_info
+  - module: community.docker.docker_image_load
+  - module: community.docker.docker_image_pull
+  - module: community.docker.docker_image_push
+  - module: community.docker.docker_image_remove
+  - module: community.docker.docker_image_tag
+"""
 
+EXAMPLES = r"""
+---
 - name: Pull an image
   community.docker.docker_image:
     name: pacur/centos-7
     source: pull
-    # Select platform for pulling. If not specified, will pull whatever docker prefers.
+  # Select platform for pulling. If not specified, will pull whatever docker prefers.
     pull:
       platform: amd64
 
@@ -250,9 +281,9 @@ EXAMPLES = '''
 
 - name: Tag and push to local registry
   community.docker.docker_image:
-    # Image will be centos:7
+  # Image will be centos:7
     name: centos
-    # Will be pushed to localhost:5000/centos:7
+  # Will be pushed to localhost:5000/centos:7
     repository: localhost:5000/centos
     tag: 7
     push: true
@@ -262,7 +293,7 @@ EXAMPLES = '''
   community.docker.docker_image:
     name: myimage:7.1.2
     repository: myimage:latest
-    # As 'latest' usually already is present, we need to enable overwriting of existing tags:
+  # As 'latest' usually already is present, we need to enable overwriting of existing tags:
     force_tag: true
     source: local
 
@@ -311,33 +342,35 @@ EXAMPLES = '''
     name: myimage:latest
     build:
       path: /path/to/build/dir
-      # Use as cache source for building myimage
+    # Use as cache source for building myimage
       cache_from:
         - nginx:latest
         - alpine:3.8
     source: build
-'''
+"""
 
-RETURN = '''
+RETURN = r"""
 image:
-    description: Image inspection results for the affected image.
-    returned: success
-    type: dict
-    sample: {}
+  description: Image inspection results for the affected image.
+  returned: success
+  type: dict
+  sample: {}
 stdout:
-    description: Docker build output when building an image.
-    returned: success
-    type: str
-    sample: ""
-    version_added: 1.0.0
-'''
+  description: Docker build output when building an image.
+  returned: success
+  type: str
+  sample: ""
+  version_added: 1.0.0
+"""
 
+import base64
 import errno
 import json
 import os
 import traceback
 
 from ansible.module_utils.common.text.converters import to_native
+from ansible.module_utils.common.text.formatters import human_to_bytes
 
 from ansible_collections.community.docker.plugins.module_utils.common_api import (
     AnsibleDockerClient,
@@ -377,6 +410,17 @@ from ansible_collections.community.docker.plugins.module_utils._api.utils.utils
 )
 
 
+def convert_to_bytes(value, module, name, unlimited_value=None):
+    if value is None:
+        return value
+    try:
+        if unlimited_value is not None and value in ('unlimited', str(unlimited_value)):
+            return unlimited_value
+        return human_to_bytes(value)
+    except ValueError as exc:
+        module.fail_json(msg='Failed to convert %s to bytes: %s' % (name, to_native(exc)))
+
+
 class ImageManager(DockerBaseClass):
 
     def __init__(self, client, results):
@@ -402,6 +446,12 @@ class ImageManager(DockerBaseClass):
         self.archive_path = parameters['archive_path']
         self.cache_from = build.get('cache_from')
         self.container_limits = build.get('container_limits')
+        if self.container_limits and 'memory' in self.container_limits:
+            self.container_limits['memory'] = convert_to_bytes(
+                self.container_limits['memory'], self.client.module, 'build.container_limits.memory')
+        if self.container_limits and 'memswap' in self.container_limits:
+            self.container_limits['memswap'] = convert_to_bytes(
+                self.container_limits['memswap'], self.client.module, 'build.container_limits.memswap', unlimited_value=-1)
         self.dockerfile = build.get('dockerfile')
         self.force_source = parameters['force_source']
         self.force_absent = parameters['force_absent']
@@ -424,6 +474,8 @@ class ImageManager(DockerBaseClass):
         self.buildargs = build.get('args')
         self.build_platform = build.get('platform')
         self.use_config_proxy = build.get('use_config_proxy')
+        self.shm_size = convert_to_bytes(build.get('shm_size'), self.client.module, 'build.shm_size')
+        self.labels = clean_dict_booleans_for_docker_api(build.get('labels'))
 
         # If name contains a tag, it takes precedence over tag parameter.
         if not is_image_name_id(self.name):
@@ -533,7 +585,7 @@ class ImageManager(DockerBaseClass):
                 try:
                     self.client.delete_json('/images/{0}', name, params={'force': self.force_absent})
                 except NotFound:
-                    # If the image vanished while we were trying to remove it, don't fail
+                    # If the image vanished while we were trying to remove it, do not fail
                     pass
                 except Exception as exc:
                     self.fail("Error removing image %s - %s" % (name, to_native(exc)))
@@ -665,8 +717,11 @@ class ImageManager(DockerBaseClass):
                     push_registry, dummy = resolve_repository_name(push_repository)
                     headers = {}
                     header = get_config_header(self.client, push_registry)
-                    if header:
-                        headers['X-Registry-Auth'] = header
+                    if not header:
+                        # For some reason, from Docker 28.3.3 on not specifying X-Registry-Auth seems to be invalid.
+                        # See https://github.com/moby/moby/issues/50614.
+                        header = base64.urlsafe_b64encode(b"{}")
+                    headers['X-Registry-Auth'] = header
                     response = self.client._post_json(
                         self.client._url("/images/{0}/push", push_repository),
                         data=None,
@@ -704,7 +759,7 @@ class ImageManager(DockerBaseClass):
         :param name: name of the image. required.
         :param tag: image tag.
         :param repository: path to the repository. required.
-        :param push: bool. push the image once it's tagged.
+        :param push: bool. push the image once it is tagged.
         :return: None
         '''
         repo, repo_tag = parse_repository_tag(repository)
@@ -726,7 +781,7 @@ class ImageManager(DockerBaseClass):
             if not self.check_mode:
                 try:
                     # Finding the image does not always work, especially running a localhost registry. In those
-                    # cases, if we don't set force=True, it errors.
+                    # cases, if we do not set force=True, it errors.
                     params = {
                         'tag': repo_tag,
                         'repo': repo,
@@ -825,6 +880,12 @@ class ImageManager(DockerBaseClass):
         if self.build_platform is not None:
             params['platform'] = self.build_platform
 
+        if self.shm_size is not None:
+            params['shmsize'] = self.shm_size
+
+        if self.labels:
+            params['labels'] = json.dumps(self.labels)
+
         if context is not None:
             headers['Content-Type'] = 'application/tar'
 
@@ -945,8 +1006,8 @@ def main():
         build=dict(type='dict', options=dict(
             cache_from=dict(type='list', elements='str'),
             container_limits=dict(type='dict', options=dict(
-                memory=dict(type='int'),
-                memswap=dict(type='int'),
+                memory=dict(type='str'),
+                memswap=dict(type='str'),
                 cpushares=dict(type='int'),
                 cpusetcpus=dict(type='str'),
             )),
@@ -962,6 +1023,8 @@ def main():
             target=dict(type='str'),
             etc_hosts=dict(type='dict'),
             platform=dict(type='str'),
+            shm_size=dict(type='str'),
+            labels=dict(type='dict'),
         )),
         archive_path=dict(type='path'),
         force_source=dict(type='bool', default=False),
