@@ -3,32 +3,31 @@
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import (absolute_import, division, print_function)
-__metaclass__ = type
+from __future__ import annotations
 
-DOCUMENTATION = '''
-  name: json_query
-  short_description: Select a single element or a data subset from a complex data structure
-  description:
-    - This filter lets you query a complex JSON structure and iterate over it using a loop structure.
-  positional: expr
-  options:
-    _input:
-      description:
-        - The JSON data to query.
-      type: any
-      required: true
-    expr:
-      description:
-        - The query expression.
-        - See U(http://jmespath.org/examples.html) for examples.
-      type: string
-      required: true
-  requirements:
-    - jmespath
-'''
+DOCUMENTATION = r"""
+name: json_query
+short_description: Select a single element or a data subset from a complex data structure
+description:
+  - This filter lets you query a complex JSON structure and iterate over it using a loop structure.
+positional: expr
+options:
+  _input:
+    description:
+      - The JSON data to query.
+    type: any
+    required: true
+  expr:
+    description:
+      - The query expression.
+      - See U(http://jmespath.org/examples.html) for examples.
+    type: string
+    required: true
+requirements:
+  - jmespath
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Define data to work on in the examples below
   ansible.builtin.set_fact:
     domain_definition:
@@ -99,13 +98,13 @@ EXAMPLES = '''
     msg: "{{ domain_definition | to_json | from_json | community.general.json_query(server_name_query) }}"
   vars:
     server_name_query: "domain.server[?contains(name,'server1')].port"
-'''
+"""
 
-RETURN = '''
-  _value:
-    description: The result of the query.
-    type: any
-'''
+RETURN = r"""
+_value:
+  description: The result of the query.
+  type: any
+"""
 
 from ansible.errors import AnsibleError, AnsibleFilterError
 
@@ -125,10 +124,17 @@ def json_query(data, expr):
                            'json_query filter')
 
     # Hack to handle Ansible Unsafe text, AnsibleMapping and AnsibleSequence
-    # See issue: https://github.com/ansible-collections/community.general/issues/320
-    jmespath.functions.REVERSE_TYPES_MAP['string'] = jmespath.functions.REVERSE_TYPES_MAP['string'] + ('AnsibleUnicode', 'AnsibleUnsafeText', )
-    jmespath.functions.REVERSE_TYPES_MAP['array'] = jmespath.functions.REVERSE_TYPES_MAP['array'] + ('AnsibleSequence', )
-    jmespath.functions.REVERSE_TYPES_MAP['object'] = jmespath.functions.REVERSE_TYPES_MAP['object'] + ('AnsibleMapping', )
+    # See issues https://github.com/ansible-collections/community.general/issues/320
+    # and https://github.com/ansible/ansible/issues/85600.
+    jmespath.functions.REVERSE_TYPES_MAP['string'] = jmespath.functions.REVERSE_TYPES_MAP['string'] + (
+        'AnsibleUnicode', 'AnsibleUnsafeText', '_AnsibleTaggedStr',
+    )
+    jmespath.functions.REVERSE_TYPES_MAP['array'] = jmespath.functions.REVERSE_TYPES_MAP['array'] + (
+        'AnsibleSequence', '_AnsibleLazyTemplateList',
+    )
+    jmespath.functions.REVERSE_TYPES_MAP['object'] = jmespath.functions.REVERSE_TYPES_MAP['object'] + (
+        'AnsibleMapping', '_AnsibleLazyTemplateDict',
+    )
     try:
         return jmespath.search(expr, data)
     except jmespath.exceptions.JMESPathError as e:
