@@ -5,62 +5,81 @@
 
 from __future__ import annotations
 
-DOCUMENTATION = '''
-    name: xen_orchestra
-    short_description: Xen Orchestra inventory source
-    version_added: 4.1.0
-    author:
-        - Dom Del Nano (@ddelnano) <ddelnano@gmail.com>
-        - Samori Gorse (@shinuza) <samorigorse@gmail.com>
-    requirements:
-        - websocket-client >= 1.0.0
+DOCUMENTATION = r"""
+name: xen_orchestra
+short_description: Xen Orchestra inventory source
+version_added: 4.1.0
+author:
+  - Dom Del Nano (@ddelnano) <ddelnano@gmail.com>
+  - Samori Gorse (@shinuza) <samorigorse@gmail.com>
+requirements:
+  - websocket-client >= 1.0.0
+description:
+  - Get inventory hosts from a Xen Orchestra deployment.
+  - Uses a configuration file as an inventory source, it must end in C(.xen_orchestra.yml) or C(.xen_orchestra.yaml).
+extends_documentation_fragment:
+  - constructed
+  - inventory_cache
+options:
+  plugin:
+    description: The name of this plugin, it should always be set to V(community.general.xen_orchestra) for this plugin to
+      recognize it as its own.
+    required: true
+    choices: ['community.general.xen_orchestra']
+    type: str
+  api_host:
     description:
-        - Get inventory hosts from a Xen Orchestra deployment.
-        - 'Uses a configuration file as an inventory source, it must end in C(.xen_orchestra.yml) or C(.xen_orchestra.yaml).'
-    extends_documentation_fragment:
-        - constructed
-        - inventory_cache
-    options:
-        plugin:
-            description: The name of this plugin, it should always be set to V(community.general.xen_orchestra) for this plugin to recognize it as its own.
-            required: true
-            choices: ['community.general.xen_orchestra']
-            type: str
-        api_host:
-            description:
-                - API host to XOA API.
-                - If the value is not specified in the inventory configuration, the value of environment variable E(ANSIBLE_XO_HOST) will be used instead.
-            type: str
-            env:
-                - name: ANSIBLE_XO_HOST
-        user:
-            description:
-                - Xen Orchestra user.
-                - If the value is not specified in the inventory configuration, the value of environment variable E(ANSIBLE_XO_USER) will be used instead.
-            required: true
-            type: str
-            env:
-                - name: ANSIBLE_XO_USER
-        password:
-            description:
-                - Xen Orchestra password.
-                - If the value is not specified in the inventory configuration, the value of environment variable E(ANSIBLE_XO_PASSWORD) will be used instead.
-            required: true
-            type: str
-            env:
-                - name: ANSIBLE_XO_PASSWORD
-        validate_certs:
-            description: Verify TLS certificate if using HTTPS.
-            type: boolean
-            default: true
-        use_ssl:
-            description: Use wss when connecting to the Xen Orchestra API
-            type: boolean
-            default: true
-'''
+      - API host to XOA API.
+      - If the value is not specified in the inventory configuration, the value of environment variable E(ANSIBLE_XO_HOST)
+        is used instead.
+    type: str
+    env:
+      - name: ANSIBLE_XO_HOST
+  user:
+    description:
+      - Xen Orchestra user.
+      - If the value is not specified in the inventory configuration, the value of environment variable E(ANSIBLE_XO_USER)
+        is used instead.
+    required: true
+    type: str
+    env:
+      - name: ANSIBLE_XO_USER
+  password:
+    description:
+      - Xen Orchestra password.
+      - If the value is not specified in the inventory configuration, the value of environment variable E(ANSIBLE_XO_PASSWORD)
+        is used instead.
+    required: true
+    type: str
+    env:
+      - name: ANSIBLE_XO_PASSWORD
+  validate_certs:
+    description: Verify TLS certificate if using HTTPS.
+    type: boolean
+    default: true
+  use_ssl:
+    description: Use wss when connecting to the Xen Orchestra API.
+    type: boolean
+    default: true
+  use_vm_uuid:
+    description:
+      - Import Xen VMs to inventory using their UUID as the VM entry name.
+      - If set to V(false) use VM name labels instead of UUIDs.
+    type: boolean
+    default: true
+    version_added: 10.4.0
+  use_host_uuid:
+    description:
+      - Import Xen Hosts to inventory using their UUID as the Host entry name.
+      - If set to V(false) use Host name labels instead of UUIDs.
+    type: boolean
+    default: true
+    version_added: 10.4.0
+"""
 
 
-EXAMPLES = '''
+EXAMPLES = r"""
+---
 # file must be named xen_orchestra.yaml or xen_orchestra.yml
 plugin: community.general.xen_orchestra
 api_host: 192.168.1.255
@@ -69,11 +88,12 @@ password: xo_pwd
 validate_certs: true
 use_ssl: true
 groups:
-    kube_nodes: "'kube_node' in tags"
+  kube_nodes: "'kube_node' in tags"
 compose:
-    ansible_port: 2222
-
-'''
+  ansible_port: 2222
+use_vm_uuid: false
+use_host_uuid: true
+"""
 
 import json
 import ssl
@@ -196,10 +216,20 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         self._set_composite_vars(self.get_option('compose'), variables, name, strict=strict)
 
     def _add_vms(self, vms, hosts, pools):
+        vm_name_list = []
         for uuid, vm in vms.items():
+            if self.vm_entry_name_type == 'name_label':
+                if vm['name_label'] not in vm_name_list:
+                    entry_name = vm['name_label']
+                    vm_name_list.append(vm['name_label'])
+                else:
+                    vm_duplicate_count = vm_name_list.count(vm['name_label'])
+                    entry_name = f"{vm['name_label']}_{vm_duplicate_count}"
+                    vm_name_list.append(vm['name_label'])
+            else:
+                entry_name = uuid
             group = 'with_ip'
             ip = vm.get('mainIpAddress')
-            entry_name = uuid
             power_state = vm['power_state'].lower()
             pool_name = self._pool_group_name_for_uuid(pools, vm['$poolId'])
             host_name = self._host_group_name_for_uuid(hosts, vm['$container'])
@@ -246,8 +276,19 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
             self._apply_constructable(entry_name, self.inventory.get_host(entry_name).get_vars())
 
     def _add_hosts(self, hosts, pools):
+        host_name_list = []
         for host in hosts.values():
-            entry_name = host['uuid']
+            if self.host_entry_name_type == 'name_label':
+                if host['name_label'] not in host_name_list:
+                    entry_name = host['name_label']
+                    host_name_list.append(host['name_label'])
+                else:
+                    host_duplicate_count = host_name_list.count(host['name_label'])
+                    entry_name = f"{host['name_label']}_{host_duplicate_count}"
+                    host_name_list.append(host['name_label'])
+            else:
+                entry_name = host['uuid']
+
             group_name = f"xo_host_{clean_group_name(host['name_label'])}"
             pool_name = self._pool_group_name_for_uuid(pools, host['$poolId'])
 
@@ -337,5 +378,13 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         if not self.get_option('use_ssl'):
             self.protocol = 'ws'
 
+        self.vm_entry_name_type = 'uuid'
+        if not self.get_option('use_vm_uuid'):
+            self.vm_entry_name_type = 'name_label'
+
+        self.host_entry_name_type = 'uuid'
+        if not self.get_option('use_host_uuid'):
+            self.host_entry_name_type = 'name_label'
+
         objects = self._get_objects()
         self._populate(make_unsafe(objects))
