@@ -8,13 +8,12 @@
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: jenkins_build
 short_description: Manage jenkins builds
 version_added: 2.2.0
 description:
-    - Manage Jenkins builds with Jenkins REST API.
+  - Manage Jenkins builds with Jenkins REST API.
 requirements:
   - "python-jenkins >= 0.4.12"
 author:
@@ -64,7 +63,7 @@ options:
     type: str
   user:
     description:
-       - User to authenticate with the Jenkins server.
+      - User to authenticate with the Jenkins server.
     type: str
   detach:
     description:
@@ -79,9 +78,9 @@ options:
     default: 10
     type: int
     version_added: 7.4.0
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Create a jenkins build using basic authentication
   community.general.jenkins_build:
     name: "test-check"
@@ -100,6 +99,16 @@ EXAMPLES = '''
     state: stopped
     url: http://localhost:8080
 
+- name: Trigger Jenkins build in detached mode
+  community.general.jenkins_build:
+    name: "detached-build"
+    state: present
+    user: admin
+    token: abcdefghijklmnopqrstuvwxyz123456
+    url: http://localhost:8080
+    detach: true
+    time_between_checks: 20
+
 - name: Delete a jenkins build using token authentication
   community.general.jenkins_build:
     name: "delete-experiment"
@@ -108,10 +117,9 @@ EXAMPLES = '''
     user: Jenkins
     token: abcdefghijklmnopqrstuvwxyz123456
     url: http://localhost:8080
-'''
+"""
 
-RETURN = '''
----
+RETURN = r"""
 name:
   description: Name of the jenkins job.
   returned: success
@@ -128,7 +136,7 @@ user:
   type: str
   sample: admin
 url:
-  description: Url to connect to the Jenkins server.
+  description: URL to connect to the Jenkins server.
   returned: success
   type: str
   sample: https://jenkins.mydomain.com
@@ -136,7 +144,7 @@ build_info:
   description: Build info of the jenkins job.
   returned: success
   type: dict
-'''
+"""
 
 import traceback
 from time import sleep
@@ -182,11 +190,11 @@ class JenkinsBuild:
 
     def get_jenkins_connection(self):
         try:
-            if (self.user and self.password):
+            if self.user and self.password:
                 return jenkins.Jenkins(self.jenkins_url, self.user, self.password)
-            elif (self.user and self.token):
+            elif self.user and self.token:
                 return jenkins.Jenkins(self.jenkins_url, self.user, self.token)
-            elif (self.user and not (self.password or self.token)):
+            elif self.user and not (self.password or self.token):
                 return jenkins.Jenkins(self.jenkins_url, self.user)
             else:
                 return jenkins.Jenkins(self.jenkins_url)
