@@ -14,20 +14,21 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
----
+DOCUMENTATION = r"""
 module: nagios
 short_description: Perform common tasks in Nagios related to downtime and notifications
 description:
-  - "The C(nagios) module has two basic functions: scheduling downtime and toggling alerts for services or hosts."
+  - 'The C(nagios) module has two basic functions: scheduling downtime and toggling alerts for services or hosts.'
   - The C(nagios) module is not idempotent.
-  - All actions require the O(host) parameter to be given explicitly. In playbooks you can use the C({{inventory_hostname}}) variable to refer
-    to the host the playbook is currently running on.
-  - You can specify multiple services at once by separating them with commas, .e.g. O(services=httpd,nfs,puppet).
-  - When specifying what service to handle there is a special service value, O(host), which will handle alerts/downtime/acknowledge for the I(host itself),
-    for example O(services=host). This keyword may not be given with other services at the same time.
-    B(Setting alerts/downtime/acknowledge for a host does not affect alerts/downtime/acknowledge for any of the services running on it.)
-    To schedule downtime for all services on particular host use keyword "all", for example O(services=all).
+  - All actions require the O(host) parameter to be given explicitly. In playbooks you can use the C({{inventory_hostname}})
+    variable to refer to the host the playbook is currently running on.
+  - The module executes commands and needs to be run directly on the Nagios server
+    with a user that has appropriate access rights. It does not use Nagios' HTTP API.
+  - Searches for a I(nagios.cfg) in I(/etc/nagios), I(/etc/nagios2), I(/etc/nagios3), I(/usr/local/etc/nagios),
+    I(/usr/local/groundwork/nagios/etc), I(/omd/sites/oppy/tmp/nagios), I(/usr/local/nagios/etc),
+    I(/usr/local/nagios), I(/opt/nagios/etc), and I(/opt/nagios),
+    or a I(icinga.cfg) in I(/etc/icinga) and I(/usr/local/icinga/etc).
+    (The Nagios configuration file should be readable by the Ansible user.)
 extends_documentation_fragment:
   - community.general.attributes
 attributes:
@@ -41,9 +42,20 @@ options:
       - Action to take.
       - The V(acknowledge) and V(forced_check) actions were added in community.general 1.2.0.
     required: true
-    choices: [ "downtime", "delete_downtime", "enable_alerts", "disable_alerts", "silence", "unsilence",
-               "silence_nagios", "unsilence_nagios", "command", "servicegroup_service_downtime",
-               "servicegroup_host_downtime", "acknowledge", "forced_check" ]
+    choices:
+      - downtime
+      - delete_downtime
+      - enable_alerts
+      - disable_alerts
+      - silence
+      - unsilence
+      - silence_nagios
+      - unsilence_nagios
+      - command
+      - servicegroup_service_downtime
+      - servicegroup_host_downtime
+      - acknowledge
+      - forced_check
     type: str
   host:
     description:
@@ -51,18 +63,16 @@ options:
     type: str
   cmdfile:
     description:
-      - Path to the nagios I(command file) (FIFO pipe).
-        Only required if auto-detection fails.
+      - Path to the nagios I(command file) (FIFO pipe). Only required if auto-detection fails.
     type: str
   author:
     description:
-     - Author to leave downtime comments as.
-       Only used when O(action) is V(downtime) or V(acknowledge).
+      - Author to leave downtime comments as. Only used when O(action) is V(downtime) or V(acknowledge).
     type: str
     default: Ansible
   comment:
     description:
-     - Comment when O(action) is V(downtime) or V(acknowledge).
+      - Comment when O(action) is V(downtime) or V(acknowledge).
     type: str
     default: Scheduling downtime
   start:
@@ -79,9 +89,18 @@ options:
   services:
     description:
       - What to manage downtime/alerts for. Separate multiple services with commas.
-      - "B(Required) option when O(action) is one of: V(downtime), V(acknowledge), V(forced_check), V(enable_alerts), V(disable_alerts)."
-    aliases: [ "service" ]
-    type: str
+      - 'B(Required) option when O(action) is one of: V(downtime), V(acknowledge), V(forced_check), V(enable_alerts), V(disable_alerts).'
+      - When specifying what O(services) to handle there is a special service value, V(host), which handles alerts/downtime/acknowledge
+        for the I(host itself), for example O(services=host). This keyword may not be given with other services at the same
+        time. B(Setting alerts/downtime/acknowledge for a host does not affect alerts/downtime/acknowledge for any of the
+        services running on it.) To schedule downtime for all O(services) on particular host use keyword V(all), for example
+        O(services=all).
+      - Before community.general 11.2.0, one could specify multiple services at once by separating them with commas, for example
+        O(services=httpd,nfs,puppet). Since community.general 11.2.0, there can be spaces around the commas, and an actual
+        list can be provided.
+    aliases: ["service"]
+    type: list
+    elements: str
   servicegroup:
     description:
       - The Servicegroup we want to set downtimes/alerts for.
@@ -89,14 +108,14 @@ options:
     type: str
   command:
     description:
-      - The raw command to send to nagios, which should not include the submitted time header or the line-feed.
-      - B(Required) option when using the V(command) O(action).
+      - The raw command to send to Nagios, which should not include the submitted time header or the line-feed.
+      - B(Required) option when O(action=command).
     type: str
 
 author: "Tim Bielawa (@tbielawa)"
-'''
+"""
 
-EXAMPLES = '''
+EXAMPLES = r"""
 - name: Set 30 minutes of apache downtime
   community.general.nagios:
     action: downtime
@@ -214,7 +233,9 @@ EXAMPLES = '''
 - name: Disable httpd and nfs alerts
   community.general.nagios:
     action: disable_alerts
-    service: httpd,nfs
+    service:
+      - httpd
+      - nfs
     host: '{{ inventory_hostname }}'
 
 - name: Disable HOST alerts
@@ -245,7 +266,7 @@ EXAMPLES = '''
   community.general.nagios:
     action: command
     command: DISABLE_FAILURE_PREDICTION
-'''
+"""
 
 import time
 import os.path
@@ -315,7 +336,7 @@ def main():
             start=dict(type='str'),
             minutes=dict(type='int', default=30),
             cmdfile=dict(type='str', default=which_cmdfile()),
-            services=dict(type='str', aliases=['service']),
+            services=dict(type='list', elements='str', aliases=['service']),
             command=dict(type='str'),
         ),
         required_if=[
@@ -373,10 +394,12 @@ class Nagios(object):
         self.cmdfile = kwargs['cmdfile']
         self.command = kwargs['command']
 
-        if (kwargs['services'] is None) or (kwargs['services'] == 'host') or (kwargs['services'] == 'all'):
+        if kwargs['services'] is None :
             self.services = kwargs['services']
+        elif len(kwargs['services']) == 1 and kwargs['services'][0] in ['host', 'all']:
+            self.services = kwargs['services'][0]
         else:
-            self.services = kwargs['services'].split(',')
+            self.services = kwargs['services']
 
         self.command_results = []
 
@@ -1234,14 +1257,9 @@ class Nagios(object):
         elif self.action == 'unsilence_nagios':
             self.unsilence_nagios()
 
-        elif self.action == 'command':
+        else:    # self.action == 'command'
             self.nagios_cmd(self.command)
 
-        # wtf?
-        else:
-            self.module.fail_json(msg="unknown action specified: '%s'" %
-                                      self.action)
-
         self.module.exit_json(nagios_commands=self.command_results,
                               changed=True)
 
