@@ -8,13 +8,11 @@ from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: terraform
 short_description: Manages a Terraform deployment (and plans)
 description:
-  - Provides support for deploying resources with Terraform and pulling
-    resource information back into Ansible.
+  - Provides support for deploying resources with Terraform and pulling resource information back into Ansible.
 extends_documentation_fragment:
   - community.general.attributes
 attributes:
@@ -27,18 +25,16 @@ options:
   state:
     choices: ['planned', 'present', 'absent']
     description:
-      - Goal state of given stage/project
+      - Goal state of given stage/project.
     type: str
     default: present
   binary_path:
     description:
-      - The path of a terraform binary to use, relative to the 'service_path'
-        unless you supply an absolute path.
+      - The path of a C(terraform) binary to use, relative to the 'service_path' unless you supply an absolute path.
     type: path
   project_path:
     description:
-      - The path to the root of the Terraform directory with the
-        vars.tf/main.tf/etc to use.
+      - The path to the root of the Terraform directory with the C(vars.tf)/C(main.tf)/etc to use.
     type: path
     required: true
   plugin_paths:
@@ -48,89 +44,84 @@ options:
       - When set, the plugin discovery and auto-download behavior of Terraform is disabled.
       - The directory structure in the plugin path can be tricky. The Terraform docs
         U(https://learn.hashicorp.com/tutorials/terraform/automate-terraform#pre-installed-plugins)
-        show a simple directory of files, but actually, the directory structure
-        has to follow the same structure you would see if Terraform auto-downloaded the plugins.
-        See the examples below for a tree output of an example plugin directory.
+        show a simple directory of files, but actually, the directory structure has to follow the same structure you would
+        see if Terraform auto-downloaded the plugins. See the examples below for a tree output of an example plugin directory.
     type: list
     elements: path
     version_added: 3.0.0
   workspace:
     description:
-      - The terraform workspace to work with. This sets the E(TF_WORKSPACE) environmental variable
-        that is used to override workspace selection. For more information about workspaces
-        have a look at U(https://developer.hashicorp.com/terraform/language/state/workspaces).
+      - The terraform workspace to work with. This sets the E(TF_WORKSPACE) environmental variable that is used to override
+        workspace selection. For more information about workspaces have a look at U(https://developer.hashicorp.com/terraform/language/state/workspaces).
     type: str
     default: default
   purge_workspace:
     description:
-      - Only works with state = absent
-      - If true, the workspace will be deleted after the "terraform destroy" action.
-      - The 'default' workspace will not be deleted.
+      - Only works with state = absent.
+      - If V(true), the O(workspace) is deleted after the C(terraform destroy) action.
+      - If O(workspace=default) then it is not deleted.
     default: false
     type: bool
   plan_file:
     description:
-      - The path to an existing Terraform plan file to apply. If this is not
-        specified, Ansible will build a new TF plan and execute it.
-        Note that this option is required if 'state' has the 'planned' value.
+      - The path to an existing Terraform plan file to apply. If this is not specified, Ansible builds a new TF plan and execute
+        it. Note that this option is required if O(state=planned).
     type: path
   state_file:
     description:
-      - The path to an existing Terraform state file to use when building plan.
-        If this is not specified, the default C(terraform.tfstate) will be used.
+      - The path to an existing Terraform state file to use when building plan. If this is not specified, the default C(terraform.tfstate)
+        is used.
       - This option is ignored when plan is specified.
     type: path
   variables_files:
     description:
-      - The path to a variables file for Terraform to fill into the TF
-        configurations. This can accept a list of paths to multiple variables files.
+      - The path to a variables file for Terraform to fill into the TF configurations. This can accept a list of paths to
+        multiple variables files.
     type: list
     elements: path
-    aliases: [ 'variables_file' ]
+    aliases: ['variables_file']
   variables:
     description:
-      - A group of key-values pairs to override template variables or those in variables files.
-        By default, only string and number values are allowed, which are passed on unquoted.
-      - Support complex variable structures (lists, dictionaries, numbers, and booleans) to reflect terraform variable syntax when O(complex_vars=true).
+      - A group of key-values pairs to override template variables or those in variables files. By default, only string and
+        number values are allowed, which are passed on unquoted.
+      - Support complex variable structures (lists, dictionaries, numbers, and booleans) to reflect terraform variable syntax
+        when O(complex_vars=true).
       - Ansible integers or floats are mapped to terraform numbers.
       - Ansible strings are mapped to terraform strings.
       - Ansible dictionaries are mapped to terraform objects.
       - Ansible lists are mapped to terraform lists.
       - Ansible booleans are mapped to terraform booleans.
-      - "B(Note) passwords passed as variables will be visible in the log output. Make sure to use C(no_log=true) in production!"
+      - B(Note) passwords passed as variables are visible in the log output. Make sure to use C(no_log=true) in production!.
     type: dict
   complex_vars:
     description:
       - Enable/disable capability to handle complex variable structures for C(terraform).
-      - If V(true) the O(variables) also accepts dictionaries, lists, and booleans to be passed to C(terraform).
-        Strings that are passed are correctly quoted.
+      - If V(true) the O(variables) also accepts dictionaries, lists, and booleans to be passed to C(terraform). Strings that
+        are passed are correctly quoted.
       - When disabled, supports only simple variables (strings, integers, and floats), and passes them on unquoted.
     type: bool
     default: false
     version_added: 5.7.0
   targets:
     description:
-      - A list of specific resources to target in this plan/application. The
-        resources selected here will also auto-include any dependencies.
+      - A list of specific resources to target in this plan/application. The resources selected here are also auto-include
+        any dependencies.
     type: list
     elements: str
     default: []
   lock:
     description:
-      - Enable statefile locking, if you use a service that accepts locks (such
-        as S3+DynamoDB) to store your statefile.
+      - Enable statefile locking, if you use a service that accepts locks (such as S3+DynamoDB) to store your statefile.
     type: bool
     default: true
   lock_timeout:
     description:
-      - How long to maintain the lock on the statefile, if you use a service
-        that accepts locks (such as S3+DynamoDB).
+      - How long to maintain the lock on the statefile, if you use a service that accepts locks (such as S3+DynamoDB).
     type: int
   force_init:
     description:
-      - To avoid duplicating infra, if a state file can't be found this will
-        force a C(terraform init). Generally, this should be turned off unless
-        you intend to provision an entirely new Terraform deployment.
+      - To avoid duplicating infra, if a state file cannot be found this forces a C(terraform init). Generally, this should
+        be turned off unless you intend to provision an entirely new Terraform deployment.
     default: false
     type: bool
   overwrite_init:
@@ -145,8 +136,8 @@ options:
     type: dict
   backend_config_files:
     description:
-      - The path to a configuration file to provide at init state to the -backend-config parameter.
-        This can accept a list of paths to multiple configuration files.
+      - The path to a configuration file to provide at init state to the -backend-config parameter. This can accept a list
+        of paths to multiple configuration files.
     type: list
     elements: path
     version_added: '0.2.0'
@@ -164,8 +155,8 @@ options:
     version_added: '1.3.0'
   check_destroy:
     description:
-      - Apply only when no resources are destroyed. Note that this only prevents "destroy" actions,
-        but not "destroy and re-create" actions. This option is ignored when O(state=absent).
+      - Apply only when no resources are destroyed. Note that this only prevents "destroy" actions, but not "destroy and re-create"
+        actions. This option is ignored when O(state=absent).
     type: bool
     default: false
     version_added: '3.3.0'
@@ -174,18 +165,31 @@ options:
       - Restrict concurrent operations when Terraform applies the plan.
     type: int
     version_added: '3.8.0'
+  no_color:
+    description:
+      - If V(true), suppress color codes in output from Terraform commands.
+      - If V(false), allows Terraform to use color codes in its output.
+    type: bool
+    default: true
+    version_added: 11.0.0
 notes:
-   - To just run a C(terraform plan), use check mode.
-requirements: [ "terraform" ]
+  - To just run a C(terraform plan), use check mode.
+requirements: ["terraform"]
 author: "Ryan Scott Brown (@ryansb)"
-'''
+"""
 
-EXAMPLES = """
+EXAMPLES = r"""
 - name: Basic deploy of a service
   community.general.terraform:
     project_path: '{{ project_dir }}'
     state: present
 
+- name: Deploy with color output enabled
+  community.general.terraform:
+    project_path: '{{ project_dir }}'
+    state: present
+    no_color: false
+
 - name: Define the backend configuration at init
   community.general.terraform:
     project_path: 'project/'
@@ -248,33 +252,30 @@ EXAMPLES = """
 #                     └── terraform-provider-vsphere_v1.26.0_x4
 """
 
-RETURN = """
+RETURN = r"""
 outputs:
   type: complex
-  description: A dictionary of all the TF outputs by their assigned name. Use RV(ignore:outputs.MyOutputName.value) to access the value.
+  description: A dictionary of all the TF outputs by their assigned name. Use RV(ignore:outputs.MyOutputName.value) to access
+    the value.
   returned: on success
   sample: '{"bukkit_arn": {"sensitive": false, "type": "string", "value": "arn:aws:s3:::tf-test-bukkit"}'
   contains:
     sensitive:
       type: bool
       returned: always
-      description: Whether Terraform has marked this value as sensitive
+      description: Whether Terraform has marked this value as sensitive.
     type:
       type: str
       returned: always
-      description: The type of the value (string, int, etc)
+      description: The type of the value (string, int, and so on).
     value:
       type: str
       returned: always
-      description: The value of the output as interpolated by Terraform
-stdout:
-  type: str
-  description: Full C(terraform) command stdout, in case you want to display it or examine the event log
-  returned: always
-  sample: ''
+      description: The value of the output as interpolated by Terraform.
 command:
   type: str
-  description: Full C(terraform) command built by this module, in case you want to re-run the command outside the module or debug a problem.
+  description: Full C(terraform) command built by this module, in case you want to re-run the command outside the module or
+    debug a problem.
   returned: always
   sample: terraform apply ...
 """
@@ -298,17 +299,20 @@ def get_version(bin_path):
     return terraform_version
 
 
-def preflight_validation(bin_path, project_path, version, variables_args=None, plan_file=None):
+def preflight_validation(bin_path, project_path, version, variables_args=None, plan_file=None, no_color=True):
     if project_path is None or '/' not in project_path:
         module.fail_json(msg="Path for Terraform project can not be None or ''.")
     if not os.path.exists(bin_path):
         module.fail_json(msg="Path for Terraform binary '{0}' doesn't exist on this host - check the path and try again please.".format(bin_path))
     if not os.path.isdir(project_path):
         module.fail_json(msg="Path for Terraform project '{0}' doesn't exist on this host - check the path and try again please.".format(project_path))
+    cmd = [bin_path, 'validate']
+    if no_color:
+        cmd.append('-no-color')
     if LooseVersion(version) < LooseVersion('0.15.0'):
-        module.run_command([bin_path, 'validate', '-no-color'] + variables_args, check_rc=True, cwd=project_path)
+        module.run_command(cmd + variables_args, check_rc=True, cwd=project_path)
     else:
-        module.run_command([bin_path, 'validate', '-no-color'], check_rc=True, cwd=project_path)
+        module.run_command(cmd, check_rc=True, cwd=project_path)
 
 
 def _state_args(state_file):
@@ -319,8 +323,10 @@ def _state_args(state_file):
     return ['-state', state_file]
 
 
-def init_plugins(bin_path, project_path, backend_config, backend_config_files, init_reconfigure, provider_upgrade, plugin_paths, workspace):
-    command = [bin_path, 'init', '-input=false', '-no-color']
+def init_plugins(bin_path, project_path, backend_config, backend_config_files, init_reconfigure, provider_upgrade, plugin_paths, workspace, no_color=True):
+    command = [bin_path, 'init', '-input=false']
+    if no_color:
+        command.append('-no-color')
     if backend_config:
         for key, val in backend_config.items():
             command.extend([
@@ -340,9 +346,12 @@ def init_plugins(bin_path, project_path, backend_config, backend_config_files, i
     rc, out, err = module.run_command(command, check_rc=True, cwd=project_path, environ_update={"TF_WORKSPACE": workspace})
 
 
-def get_workspace_context(bin_path, project_path):
+def get_workspace_context(bin_path, project_path, no_color=True):
     workspace_ctx = {"current": "default", "all": []}
-    command = [bin_path, 'workspace', 'list', '-no-color']
+    command = [bin_path, 'workspace', 'list']
+    if no_color:
+        command.append('-no-color')
+
     rc, out, err = module.run_command(command, cwd=project_path)
     if rc != 0:
         module.warn("Failed to list Terraform workspaces:\n{0}".format(err))
@@ -358,25 +367,27 @@ def get_workspace_context(bin_path, project_path):
     return workspace_ctx
 
 
-def _workspace_cmd(bin_path, project_path, action, workspace):
-    command = [bin_path, 'workspace', action, workspace, '-no-color']
+def _workspace_cmd(bin_path, project_path, action, workspace, no_color=True):
+    command = [bin_path, 'workspace', action, workspace]
+    if no_color:
+        command.append('-no-color')
     rc, out, err = module.run_command(command, check_rc=True, cwd=project_path)
     return rc, out, err
 
 
-def create_workspace(bin_path, project_path, workspace):
-    _workspace_cmd(bin_path, project_path, 'new', workspace)
+def create_workspace(bin_path, project_path, workspace, no_color=True):
+    _workspace_cmd(bin_path, project_path, 'new', workspace, no_color)
 
 
-def select_workspace(bin_path, project_path, workspace):
-    _workspace_cmd(bin_path, project_path, 'select', workspace)
+def select_workspace(bin_path, project_path, workspace, no_color=True):
+    _workspace_cmd(bin_path, project_path, 'select', workspace, no_color)
 
 
-def remove_workspace(bin_path, project_path, workspace):
-    _workspace_cmd(bin_path, project_path, 'delete', workspace)
+def remove_workspace(bin_path, project_path, workspace, no_color=True):
+    _workspace_cmd(bin_path, project_path, 'delete', workspace, no_color)
 
 
-def build_plan(command, project_path, variables_args, state_file, targets, state, args, plan_path=None):
+def build_plan(command, project_path, variables_args, state_file, targets, state, args, plan_path=None, no_color=True):
     if plan_path is None:
         f, plan_path = tempfile.mkstemp(suffix='.tfplan')
 
@@ -398,7 +409,10 @@ def build_plan(command, project_path, variables_args, state_file, targets, state
         for a in args:
             plan_command.append(a)
 
-    plan_command.extend(['-input=false', '-no-color', '-detailed-exitcode', '-out', plan_path])
+    plan_options = ['-input=false', '-detailed-exitcode', '-out', plan_path]
+    if no_color:
+        plan_options.insert(0, '-no-color')
+    plan_command.extend(plan_options)
 
     for t in targets:
         plan_command.extend(['-target', t])
@@ -493,7 +507,7 @@ def main():
             state_file=dict(type='path'),
             targets=dict(type='list', elements='str', default=[]),
             lock=dict(type='bool', default=True),
-            lock_timeout=dict(type='int',),
+            lock_timeout=dict(type='int'),
             force_init=dict(type='bool', default=False),
             backend_config=dict(type='dict'),
             backend_config_files=dict(type='list', elements='path'),
@@ -502,6 +516,7 @@ def main():
             check_destroy=dict(type='bool', default=False),
             parallelism=dict(type='int'),
             provider_upgrade=dict(type='bool', default=False),
+            no_color=dict(type='bool', default=True),
         ),
         required_if=[('state', 'planned', ['plan_file'])],
         supports_check_mode=True,
@@ -525,6 +540,7 @@ def main():
     overwrite_init = module.params.get('overwrite_init')
     check_destroy = module.params.get('check_destroy')
     provider_upgrade = module.params.get('provider_upgrade')
+    no_color = module.params.get('no_color')
 
     if bin_path is not None:
         command = [bin_path]
@@ -534,22 +550,30 @@ def main():
     checked_version = get_version(command[0])
 
     if LooseVersion(checked_version) < LooseVersion('0.15.0'):
-        DESTROY_ARGS = ('destroy', '-no-color', '-force')
-        APPLY_ARGS = ('apply', '-no-color', '-input=false', '-auto-approve=true')
+        if no_color:
+            DESTROY_ARGS = ('destroy', '-no-color', '-force')
+            APPLY_ARGS = ('apply', '-no-color', '-input=false', '-auto-approve=true')
+        else:
+            DESTROY_ARGS = ('destroy', '-force')
+            APPLY_ARGS = ('apply', '-input=false', '-auto-approve=true')
     else:
-        DESTROY_ARGS = ('destroy', '-no-color', '-auto-approve')
-        APPLY_ARGS = ('apply', '-no-color', '-input=false', '-auto-approve')
+        if no_color:
+            DESTROY_ARGS = ('destroy', '-no-color', '-auto-approve')
+            APPLY_ARGS = ('apply', '-no-color', '-input=false', '-auto-approve')
+        else:
+            DESTROY_ARGS = ('destroy', '-auto-approve')
+            APPLY_ARGS = ('apply', '-input=false', '-auto-approve')
 
     if force_init:
         if overwrite_init or not os.path.isfile(os.path.join(project_path, ".terraform", "terraform.tfstate")):
-            init_plugins(command[0], project_path, backend_config, backend_config_files, init_reconfigure, provider_upgrade, plugin_paths, workspace)
+            init_plugins(command[0], project_path, backend_config, backend_config_files, init_reconfigure, provider_upgrade, plugin_paths, workspace, no_color)
 
-    workspace_ctx = get_workspace_context(command[0], project_path)
+    workspace_ctx = get_workspace_context(command[0], project_path, no_color)
     if workspace_ctx["current"] != workspace:
         if workspace not in workspace_ctx["all"]:
-            create_workspace(command[0], project_path, workspace)
+            create_workspace(command[0], project_path, workspace, no_color)
         else:
-            select_workspace(command[0], project_path, workspace)
+            select_workspace(command[0], project_path, workspace, no_color)
 
     if state == 'present':
         command.extend(APPLY_ARGS)
@@ -560,7 +584,9 @@ def main():
         command.append('-parallelism=%d' % module.params.get('parallelism'))
 
     def format_args(vars):
-        if isinstance(vars, str):
+        if vars is None:
+            return 'null'
+        elif isinstance(vars, str):
             return '"{string}"'.format(string=vars.replace('\\', '\\\\').replace('"', '\\"')).replace('\n', '\\n')
         elif isinstance(vars, bool):
             if vars:
@@ -577,7 +603,7 @@ def main():
                     ret_out.append('{0}={{{1}}}'.format(k, process_complex_args(v)))
                 elif isinstance(v, list):
                     ret_out.append("{0}={1}".format(k, process_complex_args(v)))
-                elif isinstance(v, (integer_types, float, str, bool)):
+                elif isinstance(v, (integer_types, float, str, bool)) or v is None:
                     ret_out.append('{0}={1}'.format(k, format_args(v)))
                 else:
                     # only to handle anything unforeseen
@@ -589,7 +615,7 @@ def main():
                     l_out.append("{{{0}}}".format(process_complex_args(item)))
                 elif isinstance(item, list):
                     l_out.append("{0}".format(process_complex_args(item)))
-                elif isinstance(item, (str, integer_types, float, bool)):
+                elif isinstance(item, (str, integer_types, float, bool)) or item is None:
                     l_out.append(format_args(item))
                 else:
                     # only to handle anything unforeseen
@@ -634,7 +660,7 @@ def main():
         for f in variables_files:
             variables_args.extend(['-var-file', f])
 
-    preflight_validation(command[0], project_path, checked_version, variables_args)
+    preflight_validation(command[0], project_path, checked_version, variables_args, plan_file, no_color)
 
     if module.params.get('lock') is not None:
         if module.params.get('lock'):
@@ -661,7 +687,7 @@ def main():
             module.fail_json(msg='Could not find plan_file "{0}", check the path and try again.'.format(plan_file))
     else:
         plan_file, needs_application, out, err, command = build_plan(command, project_path, variables_args, state_file,
-                                                                     module.params.get('targets'), state, APPLY_ARGS, plan_file)
+                                                                     module.params.get('targets'), state, APPLY_ARGS, plan_file, no_color)
         if state == 'present' and check_destroy and '- destroy' in out:
             module.fail_json(msg="Aborting command because it would destroy some resources. "
                                  "Consider switching the 'check_destroy' to false to suppress this error")
@@ -672,13 +698,13 @@ def main():
         if state == 'absent':
             plan_absent_args = ['-destroy']
             plan_file, needs_application, out, err, command = build_plan(command, project_path, variables_args, state_file,
-                                                                         module.params.get('targets'), state, plan_absent_args, plan_file)
+                                                                         module.params.get('targets'), state, plan_absent_args, plan_file, no_color)
         diff_command = [command[0], 'show', '-json', plan_file]
         rc, diff_output, err = module.run_command(diff_command, check_rc=False, cwd=project_path)
         changed, result_diff = get_diff(diff_output)
         if rc != 0:
             if workspace_ctx["current"] != workspace:
-                select_workspace(command[0], project_path, workspace_ctx["current"])
+                select_workspace(command[0], project_path, workspace_ctx["current"], no_color)
             module.fail_json(msg=err.rstrip(), rc=rc, stdout=out,
                              stdout_lines=out.splitlines(), stderr=err,
                              stderr_lines=err.splitlines(),
@@ -688,7 +714,7 @@ def main():
         rc, out, err = module.run_command(command, check_rc=False, cwd=project_path)
         if rc != 0:
             if workspace_ctx["current"] != workspace:
-                select_workspace(command[0], project_path, workspace_ctx["current"])
+                select_workspace(command[0], project_path, workspace_ctx["current"], no_color)
             module.fail_json(msg=err.rstrip(), rc=rc, stdout=out,
                              stdout_lines=out.splitlines(), stderr=err,
                              stderr_lines=err.splitlines(),
@@ -697,7 +723,11 @@ def main():
         if ' 0 added, 0 changed' not in out and not state == "absent" or ' 0 destroyed' not in out:
             changed = True
 
-    outputs_command = [command[0], 'output', '-no-color', '-json'] + _state_args(state_file)
+    if no_color:
+        outputs_command = [command[0], 'output', '-no-color', '-json'] + _state_args(state_file)
+    else:
+        outputs_command = [command[0], 'output', '-json'] + _state_args(state_file)
+
     rc, outputs_text, outputs_err = module.run_command(outputs_command, cwd=project_path)
     outputs = {}
     if rc == 1:
@@ -712,9 +742,9 @@ def main():
 
     # Restore the Terraform workspace found when running the module
     if workspace_ctx["current"] != workspace:
-        select_workspace(command[0], project_path, workspace_ctx["current"])
+        select_workspace(command[0], project_path, workspace_ctx["current"], no_color)
     if state == 'absent' and workspace != 'default' and purge_workspace is True:
-        remove_workspace(command[0], project_path, workspace)
+        remove_workspace(command[0], project_path, workspace, no_color)
 
     result = {
         'state': state,
