@@ -9,13 +9,13 @@ import json
 import pytest
 
 from ansible_collections.community.general.plugins.modules import terraform
-from ansible_collections.community.general.tests.unit.plugins.modules.utils import set_module_args
+from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import set_module_args
 
 
 def test_terraform_without_argument(capfd):
-    set_module_args({})
-    with pytest.raises(SystemExit) as results:
-        terraform.main()
+    with set_module_args({}):
+        with pytest.raises(SystemExit) as results:
+            terraform.main()
 
     out, err = capfd.readouterr()
     assert not err
