@@ -6,11 +6,12 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-from ansible_collections.community.routeros.tests.unit.compat.mock import patch, MagicMock
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import patch, MagicMock
+from ansible_collections.community.internal_test_tools.tests.unit.plugins.modules.utils import set_module_args, AnsibleExitJson, AnsibleFailJson, ModuleTestCase
+
 from ansible_collections.community.routeros.tests.unit.plugins.modules.fake_api import (
     FAKE_ROS_VERSION, FakeLibRouterosError, fake_ros_api, massage_expected_result_data, create_fake_path,
 )
-from ansible_collections.community.routeros.tests.unit.plugins.modules.utils import set_module_args, AnsibleExitJson, AnsibleFailJson, ModuleTestCase
 from ansible_collections.community.routeros.plugins.modules import api_modify
 
 
@@ -42,6 +43,17 @@ START_IP_DNS_STATIC = [
         'address': '192.168.88.15',
         'dynamic': True,
     },
+    {
+        '.id': '*9',
+        'comment': '',
+        'name': 'foobar',
+        'type': 'SRV',
+        'srv-port': '123',
+        'srv-priority': 5,
+        'srv-target': '192.168.88.23',
+        'srv-weight': 15,
+        'dynamic': False,
+    },
 ]
 
 START_IP_DNS_STATIC_OLD_DATA = massage_expected_result_data(START_IP_DNS_STATIC, ('ip', 'dns', 'static'), remove_dynamic=True)
@@ -318,8 +330,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
 
     def test_module_fail_when_required_args_missing(self):
         with self.assertRaises(AnsibleFailJson) as exc:
-            set_module_args({})
-            self.module.main()
+            with set_module_args({}):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -331,8 +343,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'path': 'something invalid',
                 'data': [],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -348,8 +360,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     'foo': 'bar',
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -366,8 +378,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     '!comment': None,
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -383,8 +395,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     '!disabled': None,
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -400,8 +412,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     '!comment': 'foo',
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -416,8 +428,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     'name': None,
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -432,8 +444,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     'interface': 'eth0',
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -448,8 +460,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     'address': '192.168.88.1',
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -466,8 +478,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     'address': '192.168.88.1',
                 }],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['failed'], True)
@@ -496,10 +508,17 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                         'name': 'router',
                         'text': 'Router Text Entry',
                     },
+                    {
+                        'name': 'foobar',
+                        'type': 'SRV',
+                        'srv-port': '123',
+                        'srv-priority': 5,
+                        'srv-target': '192.168.88.23',
+                    },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -529,12 +548,20 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                         '!comment': None,
                         'text': 'Router Text Entry',
                     },
+                    {
+                        'name': 'foobar',
+                        'type': 'SRV',
+                        'srv-port': 123,
+                        'srv-priority': '5',
+                        'srv-target': '192.168.88.23',
+                        'srv-weight': '15',
+                    },
                 ],
                 'handle_absent_entries': 'remove',
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -556,8 +583,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -591,8 +618,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -623,6 +650,18 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'disabled': False,
                 'match-subdomain': False,
             },
+            {
+                '.id': '*9',
+                'name': 'foobar',
+                'type': 'SRV',
+                'srv-port': '123',
+                'srv-priority': 5,
+                'srv-target': '192.168.88.23',
+                'srv-weight': 15,
+                'ttl': '1d',
+                'disabled': False,
+                'match-subdomain': False,
+            },
             {
                 '.id': '*NEW1',
                 'name': 'router',
@@ -656,8 +695,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -688,6 +727,18 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'disabled': False,
                 'match-subdomain': False,
             },
+            {
+                '.id': '*9',
+                'name': 'foobar',
+                'type': 'SRV',
+                'srv-port': '123',
+                'srv-priority': 5,
+                'srv-target': '192.168.88.23',
+                'srv-weight': 15,
+                'ttl': '1d',
+                'disabled': False,
+                'match-subdomain': False,
+            },
             {
                 '.id': '*NEW1',
                 'name': 'router',
@@ -722,8 +773,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 ],
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -754,6 +805,18 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'disabled': False,
                 'match-subdomain': False,
             },
+            {
+                '.id': '*9',
+                'name': 'foobar',
+                'type': 'SRV',
+                'srv-port': '123',
+                'srv-priority': 5,
+                'srv-target': '192.168.88.23',
+                'srv-weight': 15,
+                'ttl': '1d',
+                'disabled': False,
+                'match-subdomain': False,
+            },
             {
                 'name': 'router',
                 'text': 'Router Text Entry 2',
@@ -785,8 +848,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -844,8 +907,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -903,8 +966,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -963,8 +1026,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1017,8 +1080,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1077,8 +1140,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1128,8 +1191,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1164,8 +1227,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1212,8 +1275,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 'ensure_order': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1285,8 +1348,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'ensure_order': True,
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1340,8 +1403,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -1363,8 +1426,31 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 ],
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
+
+        result = exc.exception.args[0]
+        self.assertEqual(result['changed'], False)
+        self.assertEqual(result['old_data'], START_IP_SETTINGS_OLD_DATA)
+        self.assertEqual(result['new_data'], START_IP_SETTINGS_OLD_DATA)
+
+    @patch('ansible_collections.community.routeros.plugins.modules.api_modify.compose_api_path',
+           new=create_fake_path(('ip', 'settings'), START_IP_SETTINGS, read_only=True))
+    def test_sync_value_idempotent_3(self):
+        with self.assertRaises(AnsibleExitJson) as exc:
+            args = self.config_module_args.copy()
+            args.update({
+                'path': 'ip settings',
+                'data': [
+                    {
+                        'accept-redirects': 'yes',
+                        'icmp-rate-limit': '20',
+                    },
+                ],
+                'handle_entries_content': 'remove',
+            })
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -1386,8 +1472,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1426,8 +1512,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 ],
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1466,8 +1552,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 ],
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1507,8 +1593,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1551,8 +1637,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                     },
                 ],
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -1587,8 +1673,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -1621,8 +1707,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'handle_entries_content': 'remove',
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1676,8 +1762,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1729,8 +1815,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 'ensure_order': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1785,8 +1871,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'ensure_order': True,
                 '_ansible_check_mode': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1847,8 +1933,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 'ensure_order': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -1879,8 +1965,44 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 'ensure_order': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
+
+        result = exc.exception.args[0]
+        self.assertEqual(result['changed'], False)
+        self.assertEqual(result['old_data'], START_IP_DHCP_CLIENT_OLD_DATA)
+        self.assertEqual(result['new_data'], START_IP_DHCP_CLIENT_OLD_DATA)
+
+    @patch('ansible_collections.community.routeros.plugins.modules.api_modify.compose_api_path',
+           new=create_fake_path(('ip', 'dhcp-client'), START_IP_DHCP_CLIENT, read_only=True))
+    def test_default_remove_combination_idempotent_2(self):
+        with self.assertRaises(AnsibleExitJson) as exc:
+            args = self.config_module_args.copy()
+            args.update({
+                'path': 'ip dhcp-client',
+                'data': [
+                    {
+                        'interface': 'ether1',
+                        'add-default-route': 'yes',
+                        'default-route-distance': '1',
+                    },
+                    {
+                        'interface': 'ether2',
+                        'dhcp-options': None,
+                        'add-default-route': True,
+                        'default-route-distance': 1,
+                    },
+                    {
+                        'interface': 'ether3',
+                        'dhcp-options': 'hostname',
+                    },
+                ],
+                'handle_absent_entries': 'remove',
+                'handle_entries_content': 'remove',
+                'ensure_order': True,
+            })
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -1911,8 +2033,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_entries_content': 'remove',
                 'ensure_order': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], True)
@@ -1969,8 +2091,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'ensure_order': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
@@ -2005,8 +2127,8 @@ class TestRouterosApiModifyModule(ModuleTestCase):
                 'handle_absent_entries': 'remove',
                 'ensure_order': True,
             })
-            set_module_args(args)
-            self.module.main()
+            with set_module_args(args):
+                self.module.main()
 
         result = exc.exception.args[0]
         self.assertEqual(result['changed'], False)
