@@ -17,10 +17,13 @@ short_description: Manage VMware vSphere clusters
 description:
     - Adds or removes VMware vSphere clusters.
     - To manage DRS, HA and VSAN related configurations, use the modules vmware_cluster_drs, vmware_cluster_ha and vmware_cluster_vsan.
-    - All values and VMware object names are case sensitive.
 author:
 - Joseph Callen (@jcpowermac)
 - Abhijeet Kasurde (@Akasurde)
+deprecated:
+  removed_in: 6.0.0
+  why: This module has been moved to the L(new vmware.vmware collection,https://forum.ansible.com/t/5880)
+  alternative: Use M(vmware.vmware.cluster) instead.
 options:
     cluster_name:
       description:
@@ -81,9 +84,9 @@ from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
     PyVmomi,
     find_datacenter_by_name,
-    vmware_argument_spec,
     wait_for_task)
-from ansible.module_utils._text import to_native
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VMwareCluster(PyVmomi):
@@ -196,7 +199,7 @@ class VMwareCluster(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(dict(
         cluster_name=dict(type='str', required=True),
         datacenter=dict(type='str', required=True, aliases=['datacenter_name']),
