@@ -27,28 +27,51 @@ options:
     primary_pvlans:
         description:
             - A list of VLAN IDs that should be configured as Primary PVLANs.
-            - If C(primary_pvlans) isn't specified, all PVLANs will be deleted if present.
+            - If not specified, all PVLANs will be deleted if present.
             - Each member of the list requires primary_pvlan_id (int) set.
             - The secondary promiscuous PVLAN will be created automatically.
-            - If C(secondary_pvlans) isn't specified, the primary PVLANs and each secondary promiscuous PVLAN will be created.
+            - If O(secondary_pvlans) isn't specified, the primary PVLANs and each secondary promiscuous PVLAN will be created.
             - Please see examples for more information.
         type: list
         default: []
         elements: dict
+        suboptions:
+            primary_pvlan_id:
+                description:
+                    - The primary VLAN ID.
+                    - The VLAN IDs of 0 and 4095 are reserved and cannot be used in this option.
+                type: int
     secondary_pvlans:
         description:
             - A list of VLAN IDs that should be configured as Secondary PVLANs.
-            - 'C(primary_pvlans) need to be specified to create any Secondary PVLAN.'
-            - If C(primary_pvlans) isn't specified, all PVLANs will be deleted if present.
+            - 'O(primary_pvlans) need to be specified to create any Secondary PVLAN.'
+            - If O(primary_pvlans) isn't specified, all PVLANs will be deleted if present.
             - Each member of the list requires primary_pvlan_id (int), secondary_pvlan_id (int), and pvlan_type (str) to be set.
             - The type of the secondary PVLAN can be isolated or community. The secondary promiscuous PVLAN will be created automatically.
             - Please see examples for more information.
         type: list
         default: []
         elements: dict
+        suboptions:
+            primary_pvlan_id:
+                description:
+                    - The primary VLAN ID.
+                    - The VLAN IDs of 0 and 4095 are reserved and cannot be used in this option.
+                type: int
+            secondary_pvlan_id:
+                description:
+                    - The type of PVLAN.
+                type: int
+            pvlan_type:
+                description:
+                    - The secondary VLAN ID.
+                    - The VLAN IDs of 0 and 4095 are reserved and cannot be used in this option.
+                choices:
+                    - community
+                    - isolated
+                type: str
 extends_documentation_fragment:
 - community.vmware.vmware.documentation
-
 '''
 
 EXAMPLES = r'''
@@ -130,10 +153,11 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import (
-    PyVmomi, TaskError, find_dvs_by_name, vmware_argument_spec, wait_for_task
+    PyVmomi, TaskError, find_dvs_by_name, wait_for_task
 )
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 
 
 class VMwareDvSwitchPvlans(PyVmomi):
@@ -484,6 +508,7 @@ class VMwareDvSwitchPvlans(PyVmomi):
 
     def build_change_message(self, operation, changed_list):
         """Build the changed message"""
+        message = None
         if operation == 'add':
             changed_operation = 'added'
         elif operation == 'remove':
@@ -504,12 +529,20 @@ class VMwareDvSwitchPvlans(PyVmomi):
 
 def main():
     """Main"""
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         dict(
             switch=dict(required=True, aliases=['dvswitch']),
-            primary_pvlans=dict(type='list', default=list(), elements='dict'),
-            secondary_pvlans=dict(type='list', default=list(), elements='dict'),
+            primary_pvlans=dict(type='list', default=list(), elements='dict',
+                                options=dict(
+                                    primary_pvlan_id=dict(type='int')
+            )),
+            secondary_pvlans=dict(type='list', default=list(), elements='dict',
+                                  options=dict(
+                                      primary_pvlan_id=dict(type='int'),
+                                      secondary_pvlan_id=dict(type='int'),
+                                      pvlan_type=dict(type='str', choices=['community', 'isolated'])
+            )),
         )
     )
 
