@@ -166,7 +166,7 @@ vm_boot_status:
 
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
 from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, find_vm_by_id, wait_for_task, TaskError
 from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 
