@@ -118,8 +118,9 @@ RETURN = r''' # '''
 
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec, wait_for_task
-from ansible.module_utils._text import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, wait_for_task
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class PyVmomiHelper(PyVmomi):
@@ -202,7 +203,7 @@ class PyVmomiHelper(PyVmomi):
 
 
 def main():
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         name=dict(type='str'),
         name_match=dict(type='str', choices=['first', 'last'], default='first'),
