@@ -87,13 +87,13 @@ options:
                 type: list
                 description:
                 - List of active adapters used for load balancing.
-                - All vmnics are used as active adapters if C(active_adapters) and C(standby_adapters) are not defined.
+                - All vmnics are used as active adapters if O(teaming.active_adapters) and O(teaming.standby_adapters) are not defined.
                 elements: str
             standby_adapters:
                 type: list
                 description:
                 - List of standby adapters used for failover.
-                - All vmnics are used as active adapters if C(active_adapters) and C(standby_adapters) are not defined.
+                - All vmnics are used as active adapters if O(teaming.active_adapters) and O(teaming.standby_adapters) are not defined.
                 elements: str
         required: false
         aliases: [ 'teaming_policy' ]
@@ -120,13 +120,13 @@ options:
         description:
             - Name of cluster name for host membership.
             - Portgroup will be created on all hosts of the given cluster.
-            - This option is required if C(hosts) is not specified.
+            - This option is required if O(hosts) is not specified.
         aliases: [ 'cluster' ]
         type: str
     hosts:
         description:
             - List of name of host or hosts on which portgroup needs to be added.
-            - This option is required if C(cluster_name) is not specified.
+            - This option is required if O(cluster_name) is not specified.
         aliases: [ esxi_hostname ]
         type: list
         elements: str
@@ -263,8 +263,9 @@ except ImportError:
     pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec
-from ansible.module_utils._text import to_native
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
+from ansible.module_utils.common.text.converters import to_native
 
 
 class VMwareHostPortGroup(PyVmomi):
@@ -971,7 +972,7 @@ class VMwareHostPortGroup(PyVmomi):
 
 def main():
     """Main"""
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(dict(
         portgroup=dict(type='str', required=True, aliases=['portgroup_name']),
         switch=dict(type='str', required=True, aliases=['switch_name', 'vswitch']),
