@@ -18,22 +18,6 @@ description:
 author:
 - Dag Wieers (@dagwieers)
 options:
-  host:
-    description:
-    - The vCenter server on which the datastore is available.
-    type: str
-    required: true
-    aliases: [ hostname ]
-  username:
-    description:
-    - The user name to authenticate on the vCenter server.
-    type: str
-    required: true
-  password:
-    description:
-    - The password to authenticate on the vCenter server.
-    type: str
-    required: true
   datacenter:
     description:
     - The datacenter on the vCenter server that holds the datastore.
@@ -50,12 +34,6 @@ options:
     type: str
     required: true
     aliases: [ dest ]
-  validate_certs:
-    description:
-    - If V(false), SSL certificates will not be validated. This should only be
-      set to V(false) when no other option exists.
-    type: bool
-    default: true
   timeout:
     description:
     - The timeout in seconds for the upload to the datastore.
@@ -73,12 +51,14 @@ options:
     default: file
 notes:
 - The vSphere folder API does not allow to remove directory objects.
+extends_documentation_fragment:
+- community.vmware.vmware.documentation
 '''
 
 EXAMPLES = r'''
 - name: Create an empty file on a datastore
   community.vmware.vsphere_file:
-    host: '{{ vhost }}'
+    hostname: '{{ vhost }}'
     username: '{{ vuser }}'
     password: '{{ vpass }}'
     datacenter: DC1 Someplace
@@ -89,7 +69,7 @@ EXAMPLES = r'''
 
 - name: Create a directory on a datastore
   community.vmware.vsphere_file:
-    host: '{{ vhost }}'
+    hostname: '{{ vhost }}'
     username: '{{ vuser }}'
     password: '{{ vpass }}'
     datacenter: DC2 Someplace
@@ -100,7 +80,7 @@ EXAMPLES = r'''
 
 - name: Query a file on a datastore
   community.vmware.vsphere_file:
-    host: '{{ vhost }}'
+    hostname: '{{ vhost }}'
     username: '{{ vuser }}'
     password: '{{ vpass }}'
     datacenter: DC1 Someplace
@@ -112,7 +92,7 @@ EXAMPLES = r'''
 
 - name: Delete a file on a datastore
   community.vmware.vsphere_file:
-    host: '{{ vhost }}'
+    hostname: '{{ vhost }}'
     username: '{{ vuser }}'
     password: '{{ vpass }}'
     datacenter: DC2 Someplace
@@ -126,14 +106,13 @@ RETURN = r'''
 '''
 
 import socket
-import sys
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.six import PY2
-from ansible.module_utils.six.moves.urllib.error import HTTPError
-from ansible.module_utils.six.moves.urllib.parse import quote, urlencode
+from urllib.error import HTTPError
+from urllib.parse import quote, urlencode
 from ansible.module_utils.urls import open_url
-from ansible.module_utils._text import to_native
+from ansible.module_utils.common.text.converters import to_native
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 
 
 def vmware_path(datastore, datacenter, path):
@@ -152,22 +131,22 @@ def vmware_path(datastore, datacenter, path):
 
 def main():
 
+    argument_spec = base_argument_spec()
+
+    argument_spec.update(dict(
+        datacenter=dict(type='str', required=True),
+        datastore=dict(type='str', required=True),
+        path=dict(type='str', required=True, aliases=['dest']),
+        state=dict(type='str', default='file', choices=['absent', 'directory', 'file', 'touch']),
+        timeout=dict(type='int', default=10),
+    ))
+
     module = AnsibleModule(
-        argument_spec=dict(
-            host=dict(type='str', required=True, aliases=['hostname']),
-            username=dict(type='str', required=True),
-            password=dict(type='str', required=True, no_log=True),
-            datacenter=dict(type='str', required=True),
-            datastore=dict(type='str', required=True),
-            path=dict(type='str', required=True, aliases=['dest']),
-            state=dict(type='str', default='file', choices=['absent', 'directory', 'file', 'touch']),
-            timeout=dict(type='int', default=10),
-            validate_certs=dict(type='bool', default=True),
-        ),
+        argument_spec=argument_spec,
         supports_check_mode=True,
     )
 
-    host = module.params.get('host')
+    host = module.params.get('hostname')
     username = module.params.get('username')
     password = module.params.get('password')
     datacenter = module.params.get('datacenter')
@@ -200,9 +179,6 @@ def main():
     except Exception as e:
         module.fail_json(msg=to_native(e), errno=dir(e), reason=to_native(e), **result)
 
-    if PY2:
-        sys.exc_clear()  # Avoid false positive traceback in fail_json() on Python 2
-
     status = r.getcode()
     if status == 200:
         exists = True
@@ -233,9 +209,6 @@ def main():
             except Exception as e:
                 module.fail_json(msg=to_native(e), errno=e[0], reason=to_native(e), **result)
 
-            if PY2:
-                sys.exc_clear()  # Avoid false positive traceback in fail_json() on Python 2
-
             result['reason'] = r.msg
             result['status'] = r.getcode()
 
@@ -272,9 +245,6 @@ def main():
             except Exception as e:
                 module.fail_json(msg=to_native(e), errno=e[0], reason=to_native(e), **result)
 
-            if PY2:
-                sys.exc_clear()  # Avoid false positive traceback in fail_json() on Python 2
-
             result['reason'] = r.msg
             result['status'] = r.getcode()
             if result['status'] != 201:
@@ -292,9 +262,6 @@ def main():
             except Exception as e:
                 module.fail_json(msg=to_native(e), errno=e[0], reason=to_native(e), **result)
 
-            if PY2:
-                sys.exc_clear()  # Avoid false positive traceback in fail_json() on Python 2
-
             status = r.getcode()
             if status != 204:
                 result['reason'] = r.msg
@@ -333,9 +300,6 @@ def main():
             except Exception as e:
                 module.fail_json(msg=to_native(e), errno=e[0], reason=to_native(e), **result)
 
-            if PY2:
-                sys.exc_clear()  # Avoid false positive traceback in fail_json() on Python 2
-
             result['reason'] = r.msg
             result['status'] = r.getcode()
             if result['status'] != 201:
