@@ -1,6 +1,6 @@
 #
 # -*- coding: utf-8 -*-
-# © Copyright 2020 Dell Inc. or its subsidiaries. All Rights Reserved
+# © Copyright 2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 # GNU General Public License v3.0+
 # (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 """
@@ -28,15 +28,27 @@ from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.s
     get_diff,
     update_states,
     get_replaced_config,
-    send_requests
+    remove_empties_from_list,
+)
+from ansible_collections.dellemc.enterprise_sonic.plugins.module_utils.network.sonic.utils.formatted_diff_utils import (
+    __DELETE_CONFIG_IF_NO_SUBCONFIG,
+    get_new_config,
+    get_formatted_config_diff
 )
 from ansible.module_utils.connection import ConnectionError
 
 PATCH = 'patch'
 DELETE = 'delete'
-test_keys = [
+TEST_KEYS = [
     {'vlan_map': {'vlan': '', 'vni': ''}},
     {'vrf_map': {'vni': '', 'vrf': ''}},
+    {'suppress_vlan_neigh': {'vlan_name': ''}},
+]
+test_keys_generate_config = [
+    {'config': {'name': '', '__delete_op': __DELETE_CONFIG_IF_NO_SUBCONFIG}},
+    {'vlan_map': {'vlan': '', 'vni': '', '__delete_op': __DELETE_CONFIG_IF_NO_SUBCONFIG}},
+    {'vrf_map': {'vni': '', 'vrf': '', '__delete_op': __DELETE_CONFIG_IF_NO_SUBCONFIG}},
+    ['suppress_vlan_neigh', {'vlan_name': '', '__delete_op': __DELETE_CONFIG_IF_NO_SUBCONFIG}],
 ]
 
 
@@ -76,7 +88,6 @@ class Vxlans(ConfigBase):
         :returns: The result from module execution
         """
         result = {'changed': False}
-        warnings = list()
 
         existing_vxlans_facts = self.get_vxlans_facts()
         commands, requests = self.set_config(existing_vxlans_facts)
@@ -96,7 +107,21 @@ class Vxlans(ConfigBase):
         if result['changed']:
             result['after'] = changed_vxlans_facts
 
-        result['warnings'] = warnings
+        new_config = changed_vxlans_facts
+        old_config = existing_vxlans_facts
+        if self._module.check_mode:
+            result.pop('after', None)
+            new_config = get_new_config(commands, existing_vxlans_facts,
+                                        test_keys_generate_config)
+            new_config = self.post_process_generated_config(new_config)
+            result['after(generated)'] = new_config
+
+        if self._module._diff:
+            self.sort_lists_in_config(new_config)
+            self.sort_lists_in_config(old_config)
+            result['diff'] = get_formatted_config_diff(old_config,
+                                                       new_config,
+                                                       self._module._verbosity)
         return result
 
     def set_config(self, existing_vxlans_facts):
@@ -122,15 +147,14 @@ class Vxlans(ConfigBase):
                   to the desired configuration
         """
         state = self._module.params['state']
-
-        diff = get_diff(want, have, test_keys)
+        diff = get_diff(want, have, TEST_KEYS)
 
         if state == 'overridden':
-            commands, requests = self._state_overridden(want, have)
+            commands, requests = self._state_overridden(want, have, diff)
         elif state == 'deleted':
-            commands, requests = self._state_deleted(want, have, diff)
+            commands, requests = self._state_deleted(want, have)
         elif state == 'merged':
-            commands, requests = self._state_merged(want, have, diff)
+            commands, requests = self._state_merged(have, diff)
         elif state == 'replaced':
             commands, requests = self._state_replaced(want, have, diff)
 
@@ -143,67 +167,61 @@ class Vxlans(ConfigBase):
         :returns: the commands necessary to migrate the current configuration
                   to the desired configuration
         """
-        requests = []
-        replaced_config = get_replaced_config(want, have, test_keys)
+        commands, requests = [], []
+        replaced_config = get_replaced_config(want, have, TEST_KEYS)
 
         if replaced_config:
             self.sort_lists_in_config(replaced_config)
             self.sort_lists_in_config(have)
-            is_delete_all = (replaced_config == have)
+            is_delete_all = replaced_config == have
             if is_delete_all:
-                requests = self.get_delete_all_vxlan_request(have)
+                del_requests = self.get_delete_all_vxlan_request(have)
+                have = []
             else:
-                requests = self.get_delete_vxlan_request(replaced_config, have)
+                del_requests = self.get_delete_vxlan_request(replaced_config, have)
 
-            send_requests(self._module, requests)
+            requests.extend(del_requests)
+            commands.extend(update_states(replaced_config, 'deleted'))
             commands = want
         else:
             commands = diff
 
-        requests = []
-
         if commands:
-            requests = self.get_create_vxlans_request(commands, have)
+            requests.extend(self.get_create_vxlans_request(commands, have))
             if len(requests) > 0:
-                commands = update_states(commands, "replaced")
-            else:
-                commands = []
-        else:
-            commands = []
+                commands.extend(update_states(commands, "replaced"))
 
         return commands, requests
 
-    def _state_overridden(self, want, have):
+    def _state_overridden(self, want, have, diff):
         """ The command generator when state is overridden
 
         :rtype: A list
         :returns: the commands necessary to migrate the current configuration
                   to the desired configuration
         """
-        self.sort_lists_in_config(want)
-        self.sort_lists_in_config(have)
-
-        if have and have != want:
-            requests = self.get_delete_all_vxlan_request(have)
-            send_requests(self._module, requests)
+        commands, requests = [], []
+        mod_commands, mod_requests = None, None
+        del_commands = get_diff(have, want, TEST_KEYS)
 
+        if del_commands:
+            del_requests = self.get_delete_all_vxlan_request(have)
+            requests.extend(del_requests)
+            commands.extend(update_states(have, 'deleted'))
             have = []
+            mod_commands = want
+            mod_requests = self.get_create_vxlans_request(mod_commands, have)
+        elif diff:
+            mod_commands = diff
+            mod_requests = self.get_create_vxlans_request(mod_commands, have)
 
-        commands = []
-        requests = []
-
-        if not have and want:
-            commands = want
-            requests = self.get_create_vxlans_request(commands, have)
-
-            if len(requests) > 0:
-                commands = update_states(commands, "overridden")
-            else:
-                commands = []
+        if mod_requests:
+            requests.extend(mod_requests)
+            commands.extend(update_states(mod_commands, 'overridden'))
 
         return commands, requests
 
-    def _state_merged(self, want, have, diff):
+    def _state_merged(self, have, diff):
         """ The command generator when state is merged
 
         :rtype: A list
@@ -223,7 +241,7 @@ class Vxlans(ConfigBase):
 
         return commands, requests
 
-    def _state_deleted(self, want, have, diff):
+    def _state_deleted(self, want, have):
         """ The command generator when state is deleted
 
         :rtype: A list
@@ -262,6 +280,7 @@ class Vxlans(ConfigBase):
         tunnel_requests = self.get_create_tunnel_request(configs, have)
         vlan_map_requests = self.get_create_vlan_map_request(configs, have)
         vrf_map_requests = self.get_create_vrf_map_request(configs, have)
+        suppress_vlan_neigh_requests = self.get_create_suppress_vlan_neigh_request(configs)
 
         if tunnel_requests:
             requests.extend(tunnel_requests)
@@ -269,54 +288,42 @@ class Vxlans(ConfigBase):
             requests.extend(vlan_map_requests)
         if vrf_map_requests:
             requests.extend(vrf_map_requests)
+        if suppress_vlan_neigh_requests:
+            requests.extend(suppress_vlan_neigh_requests)
 
         return requests
 
     def get_delete_all_vxlan_request(self, have):
         requests = []
 
-        vrf_map_requests = []
-        vlan_map_requests = []
-        src_ip_requests = []
-        primary_ip_requests = []
-        evpn_nvo_requests = []
-        tunnel_requests = []
-
         # Need to delete in reverse order of creation.
         # vrf_map needs to be cleared before vlan_map
         # vlan_map needs to be cleared before tunnel(source-ip)
         for conf in have:
             name = conf['name']
+            suppress_vlan_neigh_list = conf.get('suppress_vlan_neigh', [])
             vlan_map_list = conf.get('vlan_map', [])
             vrf_map_list = conf.get('vrf_map', [])
-            src_ip = conf.get('source_ip', None)
-            primary_ip = conf.get('primary_ip', None)
-            evpn_nvo = conf.get('evpn_nvo', None)
+            src_ip = conf.get('source_ip')
+            primary_ip = conf.get('primary_ip')
+            external_ip = conf.get('external_ip')
+            evpn_nvo = conf.get('evpn_nvo')
 
+            if suppress_vlan_neigh_list:
+                requests.extend(self.get_delete_suppress_vlan_neigh_request(conf, suppress_vlan_neigh_list))
             if vrf_map_list:
-                vrf_map_requests.extend(self.get_delete_vrf_map_request(conf, conf, name, vrf_map_list))
+                requests.extend(self.get_delete_vrf_map_request(conf, vrf_map_list))
             if vlan_map_list:
-                vlan_map_requests.extend(self.get_delete_vlan_map_request(conf, conf, name, vlan_map_list))
+                requests.extend(self.get_delete_vlan_map_request(conf, name, vlan_map_list))
             if src_ip:
-                src_ip_requests.extend(self.get_delete_src_ip_request(conf, conf, name, src_ip))
+                requests.extend(self.get_delete_src_ip_request(conf, name, src_ip))
             if primary_ip:
-                primary_ip_requests.extend(self.get_delete_primary_ip_request(conf, conf, name, primary_ip))
+                requests.extend(self.get_delete_primary_ip_request(conf, name, primary_ip))
+            if external_ip:
+                requests.extend(self.get_delete_external_ip_request(conf, name, external_ip))
             if evpn_nvo:
-                evpn_nvo_requests.extend(self.get_delete_evpn_request(conf, conf, evpn_nvo))
-            tunnel_requests.extend(self.get_delete_tunnel_request(conf, conf, name))
-
-        if vrf_map_requests:
-            requests.extend(vrf_map_requests)
-        if vlan_map_requests:
-            requests.extend(vlan_map_requests)
-        if src_ip_requests:
-            requests.extend(src_ip_requests)
-        if primary_ip_requests:
-            requests.extend(primary_ip_requests)
-        if evpn_nvo_requests:
-            requests.extend(evpn_nvo_requests)
-        if tunnel_requests:
-            requests.extend(tunnel_requests)
+                requests.extend(self.get_delete_evpn_request(conf, conf, evpn_nvo))
+            requests.extend(self.get_delete_tunnel_request(name))
 
         return requests
 
@@ -326,86 +333,63 @@ class Vxlans(ConfigBase):
         if not configs:
             return requests
 
-        vrf_map_requests = []
-        vlan_map_requests = []
-        src_ip_requests = []
-        evpn_nvo_requests = []
-        primary_ip_requests = []
-        tunnel_requests = []
-
         # Need to delete in the reverse order of creation.
         # vrf_map needs to be cleared before vlan_map
         # vlan_map needs to be cleared before tunnel(source-ip)
         for conf in configs:
 
             name = conf['name']
-            src_ip = conf.get('source_ip', None)
-            evpn_nvo = conf.get('evpn_nvo', None)
-            primary_ip = conf.get('primary_ip', None)
-            vlan_map_list = conf.get('vlan_map', None)
-            vrf_map_list = conf.get('vrf_map', None)
+            src_ip = conf.get('source_ip')
+            evpn_nvo = conf.get('evpn_nvo')
+            primary_ip = conf.get('primary_ip')
+            external_ip = conf.get('external_ip')
+            vlan_map_list = conf.get('vlan_map')
+            vrf_map_list = conf.get('vrf_map')
+            suppress_vlan_neigh_list = conf.get('suppress_vlan_neigh')
 
-            have_vlan_map_count = 0
-            have_vrf_map_count = 0
             matched = next((each_vxlan for each_vxlan in have if each_vxlan['name'] == name), None)
-            if matched:
-                have_vlan_map = matched.get('vlan_map', [])
-                have_vrf_map = matched.get('vrf_map', [])
-                if have_vlan_map:
-                    have_vlan_map_count = len(have_vlan_map)
-                if have_vrf_map:
-                    have_vrf_map_count = len(have_vrf_map)
 
             is_delete_full = False
             if (name and vlan_map_list is None and vrf_map_list is None and
-                    src_ip is None and evpn_nvo is None and primary_ip is None):
+                    src_ip is None and evpn_nvo is None and primary_ip is None and
+                    external_ip is None and suppress_vlan_neigh_list is None):
                 is_delete_full = True
                 vrf_map_list = matched.get("vrf_map", [])
                 vlan_map_list = matched.get("vlan_map", [])
+                suppress_vlan_neigh_list = matched.get("suppress_vlan_neigh", [])
 
             if vlan_map_list is not None and len(vlan_map_list) == 0 and matched:
                 vlan_map_list = matched.get("vlan_map", [])
             if vrf_map_list is not None and len(vrf_map_list) == 0 and matched:
                 vrf_map_list = matched.get("vrf_map", [])
+            if suppress_vlan_neigh_list is not None and len(suppress_vlan_neigh_list) == 0 and matched:
+                suppress_vlan_neigh_list = matched.get("suppress_vlan_neigh", [])
 
+            if suppress_vlan_neigh_list:
+                requests.extend(self.get_delete_suppress_vlan_neigh_request(matched, suppress_vlan_neigh_list))
             if vrf_map_list:
-                temp_vrf_map_requests = self.get_delete_vrf_map_request(conf, matched, name, vrf_map_list)
-                if temp_vrf_map_requests:
-                    vrf_map_requests.extend(temp_vrf_map_requests)
-                    have_vrf_map_count -= len(temp_vrf_map_requests)
+                requests.extend(self.get_delete_vrf_map_request(matched, vrf_map_list))
             if vlan_map_list:
-                temp_vlan_map_requests = self.get_delete_vlan_map_request(conf, matched, name, vlan_map_list)
-                if temp_vlan_map_requests:
-                    vlan_map_requests.extend(temp_vlan_map_requests)
-                    have_vlan_map_count -= len(temp_vlan_map_requests)
+                requests.extend(self.get_delete_vlan_map_request(matched, name, vlan_map_list))
             if src_ip:
-                src_ip_requests.extend(self.get_delete_src_ip_request(conf, matched, name, src_ip))
+                requests.extend(self.get_delete_src_ip_request(matched, name, src_ip))
             if evpn_nvo:
-                evpn_nvo_requests.extend(self.get_delete_evpn_request(conf, matched, evpn_nvo))
+                requests.extend(self.get_delete_evpn_request(conf, matched, evpn_nvo))
             if primary_ip:
-                primary_ip_requests.extend(self.get_delete_primary_ip_request(conf, matched, name, primary_ip))
+                requests.extend(self.get_delete_primary_ip_request(matched, name, primary_ip))
+            if external_ip:
+                requests.extend(self.get_delete_external_ip_request(matched, name, external_ip))
             if is_delete_full:
-                tunnel_requests.extend(self.get_delete_tunnel_request(conf, matched, name))
-
-        if vrf_map_requests:
-            requests.extend(vrf_map_requests)
-        if vlan_map_requests:
-            requests.extend(vlan_map_requests)
-        if src_ip_requests:
-            requests.extend(src_ip_requests)
-        if evpn_nvo_requests:
-            requests.extend(evpn_nvo_requests)
-        if primary_ip_requests:
-            requests.extend(primary_ip_requests)
-        if tunnel_requests:
-            requests.extend(tunnel_requests)
+                requests.extend(self.get_delete_tunnel_request(name))
 
         return requests
 
-    def get_create_evpn_request(self, conf):
+    @staticmethod
+    def get_create_evpn_request(evpn_nvo, name):
         # Create URL and payload
         url = "data/sonic-vxlan:sonic-vxlan/EVPN_NVO/EVPN_NVO_LIST"
-        payload = self.build_create_evpn_payload(conf)
+        evpn_nvo_list = [{'name': evpn_nvo, 'source_vtep': name}]
+        payload = {'sonic-vxlan:EVPN_NVO_LIST': evpn_nvo_list}
         request = {"path": url, "method": PATCH, "data": payload}
 
         return request
@@ -414,36 +398,30 @@ class Vxlans(ConfigBase):
         # Create URL and payload
         requests = []
         url = "data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL"
+        have_evpn_nvo_dict = {conf.get('name'): conf['evpn_nvo'] for conf in have if conf.get('evpn_nvo')}
+
         for conf in configs:
-            payload = self.build_create_tunnel_payload(conf)
-            request = {"path": url, "method": PATCH, "data": payload}
-            requests.append(request)
-            if conf.get('evpn_nvo', None):
-                requests.append(self.get_create_evpn_request(conf))
+            vtep_ip_dict = {}
+            vtep_ip_dict['name'] = conf['name']
+
+            if conf.get('source_ip'):
+                vtep_ip_dict['src_ip'] = conf['source_ip']
+            if conf.get('primary_ip'):
+                vtep_ip_dict['primary_ip'] = conf['primary_ip']
+            if conf.get('external_ip'):
+                vtep_ip_dict['external_ip'] = conf['external_ip']
+            if vtep_ip_dict:
+                payload = {'sonic-vxlan:VXLAN_TUNNEL': {'VXLAN_TUNNEL_LIST': [vtep_ip_dict]}}
+                request = {"path": url, "method": PATCH, "data": payload}
+                requests.append(request)
+            if conf.get('evpn_nvo'):
+                requests.append(self.get_create_evpn_request(conf['evpn_nvo'], conf['name']))
+            # Create evpn_nvo if not specified or not already configured when source_ip is specified
+            elif conf.get('source_ip') and not have_evpn_nvo_dict.get(conf['name']):
+                requests.append(self.get_create_evpn_request('nvo1', conf['name']))
 
         return requests
 
-    def build_create_evpn_payload(self, conf):
-
-        evpn_nvo_list = [{'name': conf['evpn_nvo'], 'source_vtep': conf['name']}]
-        evpn_dict = {'sonic-vxlan:EVPN_NVO_LIST': evpn_nvo_list}
-
-        return evpn_dict
-
-    def build_create_tunnel_payload(self, conf):
-        payload_url = dict()
-
-        vtep_ip_dict = dict()
-        vtep_ip_dict['name'] = conf['name']
-        if conf.get('source_ip', None):
-            vtep_ip_dict['src_ip'] = conf['source_ip']
-        if conf.get('primary_ip', None):
-            vtep_ip_dict['primary_ip'] = conf['primary_ip']
-
-        payload_url['sonic-vxlan:VXLAN_TUNNEL'] = {'VXLAN_TUNNEL_LIST': [vtep_ip_dict]}
-
-        return payload_url
-
     def get_create_vlan_map_request(self, configs, have):
         # Create URL and payload
         requests = []
@@ -466,7 +444,6 @@ class Vxlans(ConfigBase):
                                     is_change_needed = False
 
                     if is_change_needed:
-                        map_name = "map_{0}_Vlan{1}".format(vni, vlan)
                         payload = self.build_create_vlan_map_payload(conf, each_vlan_map)
                         url = "data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL_MAP"
                         request = {"path": url, "method": PATCH, "data": payload}
@@ -475,12 +452,10 @@ class Vxlans(ConfigBase):
         return requests
 
     def build_create_vlan_map_payload(self, conf, vlan_map):
-        payload_url = dict()
-
-        vlan_map_dict = dict()
+        payload_url, vlan_map_dict = {}, {}
         vlan_map_dict['name'] = conf['name']
-        vlan_map_dict['mapname'] = "map_{vni}_Vlan{vlan}".format(vni=vlan_map['vni'], vlan=vlan_map['vlan'])
-        vlan_map_dict['vlan'] = "Vlan{vlan}".format(vlan=vlan_map['vlan'])
+        vlan_map_dict['mapname'] = f"map_{vlan_map['vni']}_Vlan{vlan_map['vlan']}"
+        vlan_map_dict['vlan'] = f"Vlan{vlan_map['vlan']}"
         vlan_map_dict['vni'] = vlan_map['vni']
 
         payload_url['sonic-vxlan:VXLAN_TUNNEL_MAP'] = {'VXLAN_TUNNEL_MAP_LIST': [vlan_map_dict]}
@@ -509,16 +484,46 @@ class Vxlans(ConfigBase):
                                     is_change_needed = False
 
                     if is_change_needed:
-                        payload = self.build_create_vrf_map_payload(conf, each_vrf_map)
-                        url = "data/sonic-vrf:sonic-vrf/VRF/VRF_LIST={vrf}/vni".format(vrf=vrf)
+                        payload = self.build_create_vrf_map_payload(each_vrf_map)
+                        url = f"data/sonic-vrf:sonic-vrf/VRF/VRF_LIST={vrf}/vni"
                         request = {"path": url, "method": PATCH, "data": payload}
                         requests.append(request)
 
         return requests
 
-    def build_create_vrf_map_payload(self, conf, vrf_map):
+    def build_create_vrf_map_payload(self, vrf_map):
+        payload_url = {"sonic-vrf:vni": vrf_map['vni']}
+        return payload_url
 
-        payload_url = dict({"sonic-vrf:vni": vrf_map['vni']})
+    def get_create_suppress_vlan_neigh_request(self, configs):
+        # Create URL and payload
+        requests, vlan_list = [], []
+        payload = {}
+
+        for conf in configs:
+            new_suppress_vlan_neigh_list = conf.get('suppress_vlan_neigh', [])
+            if new_suppress_vlan_neigh_list:
+                for each_suppress_vlan_neigh in new_suppress_vlan_neigh_list:
+                    vlan_name = each_suppress_vlan_neigh.get('vlan_name')
+                    vlan_list.append(vlan_name)
+
+                payload.update(self.build_create_suppress_vlan_neigh_payload(vlan_list))
+                url = "data/sonic-vxlan:sonic-vxlan/SUPPRESS_VLAN_NEIGH"
+                request = {"path": url, "method": PATCH, "data": payload}
+                requests.append(request)
+
+        return requests
+
+    def build_create_suppress_vlan_neigh_payload(self, vlan_list):
+        payload_url = {}
+        vlans = []
+
+        for vlan in vlan_list:
+            suppress_vlan_neigh_dict = {}
+            suppress_vlan_neigh_dict['name'] = vlan
+            suppress_vlan_neigh_dict['suppress'] = 'on'
+            vlans.append(suppress_vlan_neigh_dict)
+        payload_url['sonic-vxlan:SUPPRESS_VLAN_NEIGH'] = {'SUPPRESS_VLAN_NEIGH_LIST': vlans}
         return payload_url
 
     def get_delete_evpn_request(self, conf, matched, del_evpn_nvo):
@@ -539,24 +544,24 @@ class Vxlans(ConfigBase):
 
         return requests
 
-    def get_delete_tunnel_request(self, conf, matched, name):
+    def get_delete_tunnel_request(self, name):
         # Create URL and payload
         requests = []
 
-        url = "data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL/VXLAN_TUNNEL_LIST={name}".format(name=name)
+        url = f"data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL/VXLAN_TUNNEL_LIST={name}"
         requests.append({"path": url, "method": DELETE})
 
         return requests
 
-    def get_delete_src_ip_request(self, conf, matched, name, del_source_ip):
+    def get_delete_src_ip_request(self, matched, name, del_source_ip):
         # Create URL and payload
         requests = []
 
-        url = "data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL/VXLAN_TUNNEL_LIST={name}/src_ip"
+        url = f"data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL/VXLAN_TUNNEL_LIST={name}/src_ip"
 
         is_change_needed = False
         if matched:
-            matched_source_ip = matched.get('source_ip', None)
+            matched_source_ip = matched.get('source_ip')
             if matched_source_ip and matched_source_ip == del_source_ip:
                 is_change_needed = True
 
@@ -566,7 +571,7 @@ class Vxlans(ConfigBase):
 
         return requests
 
-    def get_delete_primary_ip_request(self, conf, matched, name, del_primary_ip):
+    def get_delete_primary_ip_request(self, matched, name, del_primary_ip):
         # Create URL and payload
         requests = []
 
@@ -574,7 +579,7 @@ class Vxlans(ConfigBase):
 
         is_change_needed = False
         if matched:
-            matched_primary_ip = matched.get('primary_ip', None)
+            matched_primary_ip = matched.get('primary_ip')
             if matched_primary_ip and matched_primary_ip == del_primary_ip:
                 is_change_needed = True
 
@@ -584,7 +589,19 @@ class Vxlans(ConfigBase):
 
         return requests
 
-    def get_delete_vlan_map_request(self, conf, matched, name, del_vlan_map_list):
+    def get_delete_external_ip_request(self, matched, name, external_ip):
+        requests = []
+        url = "data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL/VXLAN_TUNNEL_LIST={name}/external_ip"
+
+        if matched:
+            matched_external_ip = matched.get('external_ip')
+            if matched_external_ip and matched_external_ip == external_ip:
+                request = {"path": url.format(name=name), "method": DELETE}
+                requests.append(request)
+
+        return requests
+
+    def get_delete_vlan_map_request(self, matched, name, del_vlan_map_list):
         # Create URL and payload
         requests = []
 
@@ -594,7 +611,7 @@ class Vxlans(ConfigBase):
 
             is_change_needed = False
             if matched:
-                matched_vlan_map_list = matched.get('vlan_map', None)
+                matched_vlan_map_list = matched.get('vlan_map')
                 if matched_vlan_map_list:
                     matched_vlan_map = next((e_vlan_map for e_vlan_map in matched_vlan_map_list if e_vlan_map['vni'] == vni), None)
                     if matched_vlan_map:
@@ -602,14 +619,14 @@ class Vxlans(ConfigBase):
                             is_change_needed = True
 
             if is_change_needed:
-                map_name = "map_{0}_Vlan{1}".format(vni, vlan)
-                url = "data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL_MAP/VXLAN_TUNNEL_MAP_LIST={name},{map_name}".format(name=name, map_name=map_name)
+                map_name = f"map_{vni}_Vlan{vlan}"
+                url = f"data/sonic-vxlan:sonic-vxlan/VXLAN_TUNNEL_MAP/VXLAN_TUNNEL_MAP_LIST={name},{map_name}"
                 request = {"path": url, "method": DELETE}
                 requests.append(request)
 
         return requests
 
-    def get_delete_vrf_map_request(self, conf, matched, name, del_vrf_map_list):
+    def get_delete_vrf_map_request(self, matched, del_vrf_map_list):
         # Create URL and payload
         requests = []
 
@@ -619,7 +636,7 @@ class Vxlans(ConfigBase):
 
             is_change_needed = False
             if matched:
-                matched_vrf_map_list = matched.get('vrf_map', None)
+                matched_vrf_map_list = matched.get('vrf_map')
                 if matched_vrf_map_list:
                     matched_vrf_map = next((e_vrf_map for e_vrf_map in matched_vrf_map_list if e_vrf_map['vni'] == vni), None)
                     if matched_vrf_map:
@@ -627,7 +644,30 @@ class Vxlans(ConfigBase):
                             is_change_needed = True
 
             if is_change_needed:
-                url = "data/sonic-vrf:sonic-vrf/VRF/VRF_LIST={vrf}/vni".format(vrf=vrf)
+                url = f"data/sonic-vrf:sonic-vrf/VRF/VRF_LIST={vrf}/vni"
+                request = {"path": url, "method": DELETE}
+                requests.append(request)
+
+        return requests
+
+    def get_delete_suppress_vlan_neigh_request(self, matched, del_suppress_vlan_neigh_list):
+        # Create URL and payload
+        requests = []
+
+        for each_suppress_vlan_neigh in del_suppress_vlan_neigh_list:
+            vlan_name = each_suppress_vlan_neigh.get('vlan_name')
+
+            is_change_needed = False
+            if matched:
+                matched_suppress_vlan_neigh_list = matched.get('suppress_vlan_neigh')
+                if matched_suppress_vlan_neigh_list:
+                    matched_suppress_vlan_neigh = next(
+                        (e_svn for e_svn in matched_suppress_vlan_neigh_list if e_svn['vlan_name'] == vlan_name), None)
+                    if matched_suppress_vlan_neigh:
+                        is_change_needed = True
+
+            if is_change_needed:
+                url = f"data/sonic-vxlan:sonic-vxlan/SUPPRESS_VLAN_NEIGH/SUPPRESS_VLAN_NEIGH_LIST={vlan_name}"
                 request = {"path": url, "method": DELETE}
                 requests.append(request)
 
@@ -635,15 +675,22 @@ class Vxlans(ConfigBase):
 
     def sort_lists_in_config(self, config):
         if config:
-            config.sort(key=self.get_name)
+            config.sort(key=lambda x: x['name'])
             for cfg in config:
                 if 'vlan_map' in cfg and cfg['vlan_map']:
-                    cfg['vlan_map'].sort(key=self.get_vni)
+                    cfg['vlan_map'].sort(key=lambda x: x['vni'])
                 if 'vrf_map' in cfg and cfg['vrf_map']:
-                    cfg['vrf_map'].sort(key=self.get_vni)
+                    cfg['vrf_map'].sort(key=lambda x: x['vni'])
+                if 'suppress_vlan_neigh' in cfg and cfg['suppress_vlan_neigh']:
+                    cfg['suppress_vlan_neigh'].sort(key=lambda x: x['vlan_name'])
 
-    def get_name(self, name):
-        return name.get('name')
-
-    def get_vni(self, vni):
-        return vni.get('vni')
+    def post_process_generated_config(self, configs):
+        confs = remove_empties_from_list(configs)
+        if confs:
+            for conf in confs[:]:
+                vlan_map = conf.get('vlan_map')
+                vrf_map = conf.get('vrf_map')
+                suppress_vlan_neigh = conf.get('suppress_vlan_neigh')
+                if not vlan_map and not vrf_map and not suppress_vlan_neigh:
+                    confs.remove(conf)
+        return confs
