@@ -72,6 +72,13 @@ class TestSonicLoggingModule(TestSonicModule):
         result = self.execute_module(changed=True)
         self.validate_config_requests()
 
+    def test_sonic_logging_deleted_03(self):
+        set_module_args(self.fixture_data['deleted_03']['module_args'])
+        self.initialize_facts_get_requests(self.fixture_data['deleted_03']['existing_logging_config'])
+        self.initialize_config_requests(self.fixture_data['deleted_03']['expected_config_requests'])
+        result = self.execute_module(changed=True)
+        self.validate_config_requests()
+
     def test_sonic_logging_replaced_01(self):
         set_module_args(self.fixture_data['replaced_01']['module_args'])
         self.initialize_facts_get_requests(self.fixture_data['replaced_01']['existing_logging_config'])
