@@ -17,7 +17,7 @@ import json
 
 from urllib.error import HTTPError, URLError
 import pytest
-from mock import MagicMock
+from unittest.mock import MagicMock
 from ansible_collections.dellemc.openmanage.plugins.modules import idrac_session
 from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import FakeAnsibleModule
 from ansible_collections.dellemc.openmanage.tests.unit.plugins.modules.common import AnsibleFailJSonException
