@@ -2,8 +2,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 8.1.0
-# Copyright (C) 2019-2023 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.12.3
+# Copyright (C) 2019-2025 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -160,6 +160,26 @@ class TestOmeFirmwareBaseline(FakeAnsibleModule):
         catrepo = self.module.get_catrepo_ids(f_module, params["inp"], ome_connection_mock_for_firmware_baseline)
         assert catrepo == params["out"]
 
+    @pytest.mark.parametrize("params", [{"inp": catrepo_param1, "out": catrepo_out1}])
+    def test_get_catrepo_ids_fail(self, ome_connection_mock_for_firmware_baseline,
+                                  ome_response_mock, params):
+        ome_connection_mock_for_firmware_baseline.get_all_items_with_pagination.return_value = {
+            "value": [
+                {
+                    "Id": 22,
+                    "Repository": {
+                        "Id": 12,
+                        "Name": "catalog1",
+                    },
+                    "Status": "Running"
+                }
+            ]
+        }
+        f_module = self.get_module_mock(params=params["inp"])
+        with pytest.raises(Exception) as exc:
+            self.module.get_catrepo_ids(f_module, params["inp"], ome_connection_mock_for_firmware_baseline)
+        assert exc.value.args[0] == "Unable to create the firmware baseline as the catalog is in Running status."
+
     @pytest.mark.parametrize("params", [{"mparams": {"state": "absent", "baseline_name": "my_baseline1"}, "res": [
         {"Id": 12, "Name": "my_baseline1"}], "json_data": {
         "value": [{"Id": 12, "Name": "my_baseline1"}]}, "success": True}, {
@@ -308,6 +328,24 @@ class TestOmeFirmwareBaseline(FakeAnsibleModule):
                                           "device_service_tags", "DeviceServiceTag")
         assert targets == params["out"]
 
+    @pytest.mark.parametrize("params", [{"inp": inp_param2, "out": out2}])
+    def test_get_dev_ids_fail(self, ome_connection_mock_for_firmware_baseline,
+                              ome_response_mock, params):
+        f_module = self.get_module_mock(params=params["inp"])
+        ome_connection_mock_for_firmware_baseline.get_all_items_with_pagination.return_value = {
+            "value":
+                [
+                    {
+                        "Id": 13,
+                        "Type": 1000,
+                        "DeviceServiceTag": "R940PT3"
+                    }
+                ]
+        }
+        with pytest.raises(Exception) as err:
+            self.module.get_dev_ids(f_module, ome_connection_mock_for_firmware_baseline,
+                                    "device_service_tags", "DeviceServiceTag")
+        assert err.value.args[0] == "Unable to complete the operation because the entered target DeviceServiceTag 'R840PT3' is invalid."
     grp_param1 = {"device_group_names": ["group1", "group2"]}
     grp_out1 = [
         {
@@ -359,6 +397,23 @@ class TestOmeFirmwareBaseline(FakeAnsibleModule):
         targets = self.module.get_group_ids(f_module, ome_connection_mock_for_firmware_baseline)
         assert targets == params["out"]
 
+    @pytest.mark.parametrize("params", [{"inp": grp_param2, "out": grp_out2}])
+    def test_get_group_ids_fail(self, ome_connection_mock_for_firmware_baseline,
+                                ome_response_mock, params):
+        f_module = self.get_module_mock(params=params["inp"])
+        ome_connection_mock_for_firmware_baseline.get_all_items_with_pagination.return_value = {
+            "value": [
+                {
+                    "Id": 23,
+                    "TypeId": 6000,
+                    "Name": "group2"
+                }
+            ]
+        }
+        with pytest.raises(Exception) as err:
+            self.module.get_group_ids(f_module, ome_connection_mock_for_firmware_baseline)
+        assert err.value.args[0] == "Unable to complete the operation because the entered target Group Name 'group1' is invalid."
+
     payload_param1 = {"catalog_name": "cat1",
                       "baseline_name": "baseline1",
                       "baseline_description": "baseline_description",
@@ -506,7 +561,7 @@ class TestOmeFirmwareBaseline(FakeAnsibleModule):
         ome_response_mock.success = True
         ome_response_mock.json_data = params.get("json_data")
         ome_default_args.update(params.get('mparams'))
-        result = self._run_module_with_fail_json(ome_default_args)
+        result = self._run_module(ome_default_args)
         assert result["msg"] == params['message']
 
     def test_main_failure01(self, ome_connection_mock_for_firmware_baseline, ome_default_args, ome_response_mock,
@@ -517,7 +572,7 @@ class TestOmeFirmwareBaseline(FakeAnsibleModule):
         ome_response_mock.success = False
         ome_response_mock.json_data = baseline_status1
         ome_default_args.update({"baseline_name": "b1", "device_ids": [12, 23]})
-        result = self._run_module_with_fail_json(ome_default_args)
+        result = self._run_module(ome_default_args)
         assert result["failed"] is True
         assert 'msg' in result
 
@@ -529,7 +584,7 @@ class TestOmeFirmwareBaseline(FakeAnsibleModule):
         ome_response_mock.success = False
         ome_response_mock.json_data = baseline_status1
         ome_default_args.update({"baseline_name": "b1"})
-        result = self._run_module_with_fail_json(ome_default_args)
+        result = self._run_module(ome_default_args)
         assert result["failed"] is True
         assert 'msg' in result
 
@@ -547,12 +602,12 @@ class TestOmeFirmwareBaseline(FakeAnsibleModule):
             assert result["unreachable"] is True
         elif exc_type not in [HTTPError, SSLValidationError]:
             mocker.patch(MODULE_PATH + 'check_existing_baseline', side_effect=exc_type("exception message"))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         else:
             mocker.patch(MODULE_PATH + 'check_existing_baseline',
                          side_effect=exc_type('https://testhost.com', 400, 'http error message',
                                               {"accept-type": "application/json"}, StringIO(json_str)))
-            result = self._run_module_with_fail_json(ome_default_args)
+            result = self._run_module(ome_default_args)
             assert result['failed'] is True
         assert 'msg' in result
