@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 #
-# Dell EMC OpenManage Ansible Modules
-# Version 3.6.0
-# Copyright (C) 2020-2021 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Dell OpenManage Ansible Modules
+# Version 7.0.0
+# Copyright (C) 2020-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -164,7 +164,7 @@ class TestOmeSmartFabric(FakeAnsibleModule):
         else:
             for status_code, msg in {501: SYSTEM_NOT_SUPPORTED_ERROR_MSG, 400: 'http error message'}.items():
                 mocker.patch(MODULE_PATH + 'ome_smart_fabric.fabric_actions',
-                             side_effect=exc_type('http://testhost.com', status_code, msg,
+                             side_effect=exc_type('https://testhost.com', status_code, msg,
                                                   {"accept-type": "application/json"}, StringIO(json_str)))
                 result = self._run_module_with_fail_json(ome_default_args)
                 assert result['failed'] is True
