@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -294,10 +297,10 @@ EXAMPLES = '''
         adom: ansible
         state: present
         dnsfilter_profile:
-          block-action: redirect
-          block-botnet: disable
+          block_action: redirect
+          block_botnet: disable
           comment: "ansible-test-comment"
-          log-all-domain: disable
+          log_all_domain: disable
           name: "ansible-test"
 
 - name: Gathering fortimanager facts
@@ -372,6 +375,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'dnsfilter_profile': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
