@@ -131,6 +131,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -139,22 +140,22 @@ EXAMPLES = '''
     - name: Device VDOM table.
       fortinet.fortimanager.fmgr_dvmdb_device_vdom:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         device: <your own value>
         state: present # <value in [present, absent]>
         dvmdb_device_vdom:
-          comments: <string>
-          name: <string>
-          opmode: <value in [nat, transparent]>
-          rtm_prof_id: <integer>
-          status: <string>
-          vpn_id: <integer>
-          meta_fields: <dict>
-          vdom_type: <value in [traffic, admin]>
+          name: "your value" # Required variable, string
+          # comments: <string>
+          # opmode: <value in [nat, transparent]>
+          # rtm_prof_id: <integer>
+          # status: <string>
+          # vpn_id: <integer>
+          # meta_fields: <dict>
+          # vdom_type: <value in [traffic, admin]>
 '''
 
 RETURN = '''
