@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -136,6 +139,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -144,23 +148,23 @@ EXAMPLES = '''
     - name: SMTP.
       fortinet.fortimanager.fmgr_emailfilter_profile_smtp:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         profile: <your own value>
         emailfilter_profile_smtp:
-          action: <value in [pass, tag, discard]>
-          hdrip: <value in [disable, enable]>
-          local_override: <value in [disable, enable]>
-          log: <value in [disable, enable]>
-          tag_msg: <string>
-          tag_type:
-            - "subject"
-            - "header"
-            - "spaminfo"
-          log_all: <value in [disable, enable]>
+          # action: <value in [pass, tag, discard]>
+          # hdrip: <value in [disable, enable]>
+          # local_override: <value in [disable, enable]>
+          # log: <value in [disable, enable]>
+          # tag_msg: <string>
+          # tag_type:
+          #   - "subject"
+          #   - "header"
+          #   - "spaminfo"
+          # log_all: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -218,6 +222,7 @@ def main():
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'profile': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'emailfilter_profile_smtp': {
             'type': 'dict',
             'v_range': [['6.2.0', '']],
