@@ -64,6 +64,9 @@ options:
         description: The rc codes list with which the conditions to fail will be overriden.
         type: list
         elements: int
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -162,6 +165,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -170,26 +174,25 @@ EXAMPLES = '''
     - name: Server SSH public key authentication settings.
       fortinet.fortimanager.fmgr_firewall_accessproxy_serverpubkeyauthsettings:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         access_proxy: <your own value>
         firewall_accessproxy_serverpubkeyauthsettings:
-          auth_ca: <string>
-          cert_extension:
-            -
-              critical: <value in [no, yes]>
-              data: <string>
-              name: <string>
-              type: <value in [fixed, user]>
-          permit_agent_forwarding: <value in [disable, enable]>
-          permit_port_forwarding: <value in [disable, enable]>
-          permit_pty: <value in [disable, enable]>
-          permit_user_rc: <value in [disable, enable]>
-          permit_x11_forwarding: <value in [disable, enable]>
-          source_address: <value in [disable, enable]>
+          # auth_ca: <string>
+          # cert_extension:
+          #   - critical: <value in [no, yes]>
+          #     data: <string>
+          #     name: <string>
+          #     type: <value in [fixed, user]>
+          # permit_agent_forwarding: <value in [disable, enable]>
+          # permit_port_forwarding: <value in [disable, enable]>
+          # permit_pty: <value in [disable, enable]>
+          # permit_user_rc: <value in [disable, enable]>
+          # permit_x11_forwarding: <value in [disable, enable]>
+          # source_address: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -248,6 +251,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'access-proxy': {'type': 'str', 'api_name': 'access_proxy'},
         'access_proxy': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'firewall_accessproxy_serverpubkeyauthsettings': {
             'type': 'dict',
             'v_range': [['7.0.0', '']],
