@@ -102,6 +102,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -110,13 +111,13 @@ EXAMPLES = '''
     - name: Enable/disable logging of FortiGuard antivirus and IPS update packages received by FortiManagers built-in FortiGuard.
       fortinet.fortimanager.fmgr_fmupdate_avips_advancedlog:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         fmupdate_avips_advancedlog:
-          log_fortigate: <value in [disable, enable]>
-          log_server: <value in [disable, enable]>
+          # log_fortigate: <value in [disable, enable]>
+          # log_server: <value in [disable, enable]>
 '''
 
 RETURN = '''
