@@ -103,8 +103,8 @@ EXAMPLES = '''
     - name: Meta fields firewall central snat map
       fortinet.fortimanager.fmgr_pm_config_metafields_firewall_centralsnatmap:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         pm_config_metafields_firewall_centralsnatmap:
