@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -331,6 +334,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -339,76 +343,76 @@ EXAMPLES = '''
     - name: Configure AntiSpam profiles.
       fortinet.fortimanager.fmgr_spamfilter_profile:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         spamfilter_profile:
-          comment: <string>
-          external: <value in [disable, enable]>
-          flow_based: <value in [disable, enable]>
-          name: <string>
-          options:
-            - "bannedword"
-            - "spamemailbwl"
-            - "spamfsip"
-            - "spamfssubmit"
-            - "spamfschksum"
-            - "spamfsurl"
-            - "spamhelodns"
-            - "spamipbwl"
-            - "spamraddrdns"
-            - "spamrbl"
-            - "spamhdrcheck"
-            - "spamfsphish"
-            - "spambwl"
-          replacemsg_group: <string>
-          spam_bwl_table: <string>
-          spam_bword_table: <string>
-          spam_bword_threshold: <integer>
-          spam_filtering: <value in [disable, enable]>
-          spam_iptrust_table: <string>
-          spam_log: <value in [disable, enable]>
-          spam_log_fortiguard_response: <value in [disable, enable]>
-          spam_mheader_table: <string>
-          spam_rbl_table: <string>
-          gmail:
-            log: <value in [disable, enable]>
-          imap:
-            action: <value in [pass, tag]>
-            log: <value in [disable, enable]>
-            tag_msg: <string>
-            tag_type:
-              - "subject"
-              - "header"
-              - "spaminfo"
-          mapi:
-            action: <value in [pass, discard]>
-            log: <value in [disable, enable]>
-          msn_hotmail:
-            log: <value in [disable, enable]>
-          pop3:
-            action: <value in [pass, tag]>
-            log: <value in [disable, enable]>
-            tag_msg: <string>
-            tag_type:
-              - "subject"
-              - "header"
-              - "spaminfo"
-          smtp:
-            action: <value in [pass, tag, discard]>
-            hdrip: <value in [disable, enable]>
-            local_override: <value in [disable, enable]>
-            log: <value in [disable, enable]>
-            tag_msg: <string>
-            tag_type:
-              - "subject"
-              - "header"
-              - "spaminfo"
-          yahoo_mail:
-            log: <value in [disable, enable]>
+          name: "your value" # Required variable, string
+          # comment: <string>
+          # external: <value in [disable, enable]>
+          # flow_based: <value in [disable, enable]>
+          # options:
+          #   - "bannedword"
+          #   - "spamemailbwl"
+          #   - "spamfsip"
+          #   - "spamfssubmit"
+          #   - "spamfschksum"
+          #   - "spamfsurl"
+          #   - "spamhelodns"
+          #   - "spamipbwl"
+          #   - "spamraddrdns"
+          #   - "spamrbl"
+          #   - "spamhdrcheck"
+          #   - "spamfsphish"
+          #   - "spambwl"
+          # replacemsg_group: <string>
+          # spam_bwl_table: <string>
+          # spam_bword_table: <string>
+          # spam_bword_threshold: <integer>
+          # spam_filtering: <value in [disable, enable]>
+          # spam_iptrust_table: <string>
+          # spam_log: <value in [disable, enable]>
+          # spam_log_fortiguard_response: <value in [disable, enable]>
+          # spam_mheader_table: <string>
+          # spam_rbl_table: <string>
+          # gmail:
+          #   log: <value in [disable, enable]>
+          # imap:
+          #   action: <value in [pass, tag]>
+          #   log: <value in [disable, enable]>
+          #   tag_msg: <string>
+          #   tag_type:
+          #     - "subject"
+          #     - "header"
+          #     - "spaminfo"
+          # mapi:
+          #   action: <value in [pass, discard]>
+          #   log: <value in [disable, enable]>
+          # msn_hotmail:
+          #   log: <value in [disable, enable]>
+          # pop3:
+          #   action: <value in [pass, tag]>
+          #   log: <value in [disable, enable]>
+          #   tag_msg: <string>
+          #   tag_type:
+          #     - "subject"
+          #     - "header"
+          #     - "spaminfo"
+          # smtp:
+          #   action: <value in [pass, tag, discard]>
+          #   hdrip: <value in [disable, enable]>
+          #   local_override: <value in [disable, enable]>
+          #   log: <value in [disable, enable]>
+          #   tag_msg: <string>
+          #   tag_type:
+          #     - "subject"
+          #     - "header"
+          #     - "spaminfo"
+          # yahoo_mail:
+          #   log: <value in [disable, enable]>
 '''
 
 RETURN = '''
@@ -465,6 +469,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'spamfilter_profile': {
             'type': 'dict',
             'v_range': [['6.0.0', '7.2.1']],
