@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -115,6 +118,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -123,18 +127,18 @@ EXAMPLES = '''
     - name: Configuration method to edit custom TLV entries.
       fortinet.fortimanager.fmgr_switchcontroller_lldpprofile_customtlvs:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         lldp_profile: <your own value>
         state: present # <value in [present, absent]>
         switchcontroller_lldpprofile_customtlvs:
-          information_string: <string>
-          name: <string>
-          oui: <string>
-          subtype: <integer>
+          name: "your value" # Required variable, string
+          # information_string: <string>
+          # oui: <string>
+          # subtype: <integer>
 '''
 
 RETURN = '''
@@ -193,6 +197,7 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'lldp-profile': {'type': 'str', 'api_name': 'lldp_profile'},
         'lldp_profile': {'type': 'str'},
+        'revision_note': {'type': 'str'},
         'switchcontroller_lldpprofile_customtlvs': {
             'type': 'dict',
             'v_range': [['6.0.0', '']],
