@@ -208,6 +208,7 @@ options:
 EXAMPLES = '''
 - name: Example playbook
   hosts: fortimanagers
+  gather_facts: false
   connection: httpapi
   vars:
     ansible_httpapi_use_ssl: true
@@ -220,7 +221,7 @@ EXAMPLES = '''
         state: present
         system_admin_ldap:
           adom:
-            - adom-name: ansible
+            - adom_name: ansible
           name: ansible-test-ldap
           password: Fortinet
           port: 390
@@ -306,7 +307,7 @@ def main():
                 'attributes': {'type': 'str'},
                 'ca-cert': {'type': 'str'},
                 'cnid': {'type': 'str'},
-                'connect-timeout': {'v_range': [['6.0.0', '7.4.2']], 'type': 'int'},
+                'connect-timeout': {'v_range': [['6.0.0', '7.2.9'], ['7.4.0', '7.4.2']], 'type': 'int'},
                 'dn': {'type': 'str'},
                 'filter': {'type': 'str'},
                 'group': {'type': 'str'},
@@ -323,7 +324,7 @@ def main():
                 'username': {'type': 'str'},
                 'adom-access': {'v_range': [['7.0.3', '']], 'choices': ['all', 'specify'], 'type': 'str'},
                 'ssl-protocol': {
-                    'v_range': [['7.4.4', '7.4.5']],
+                    'v_range': [['7.4.4', '7.4.7'], ['7.6.2', '']],
                     'choices': ['follow-global-ssl-protocol', 'sslv3', 'tlsv1.0', 'tlsv1.1', 'tlsv1.2', 'tlsv1.3'],
                     'type': 'str'
                 }
