@@ -137,6 +137,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -145,20 +146,20 @@ EXAMPLES = '''
     - name: Pre-authorized and blocked security fabric nodes.
       fortinet.fortimanager.fmgr_system_csf_trustedlist:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         state: present # <value in [present, absent]>
         system_csf_trustedlist:
-          action: <value in [accept, deny]>
-          authorization_type: <value in [serial, certificate]>
-          certificate: <string>
-          downstream_authorization: <value in [disable, enable]>
-          ha_members: <string>
-          index: <integer>
-          name: <string>
-          serial: <string>
+          name: "your value" # Required variable, string
+          # action: <value in [accept, deny]>
+          # authorization_type: <value in [serial, certificate]>
+          # certificate: <string>
+          # downstream_authorization: <value in [disable, enable]>
+          # ha_members: <string>
+          # index: <integer>
+          # serial: <string>
 '''
 
 RETURN = '''
