@@ -252,6 +252,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -260,48 +261,48 @@ EXAMPLES = '''
     - name: Log rolling policy for device logs.
       fortinet.fortimanager.fmgr_system_log_settings_rollingregular:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         system_log_settings_rollingregular:
-          days:
-            - "sun"
-            - "mon"
-            - "tue"
-            - "wed"
-            - "thu"
-            - "fri"
-            - "sat"
-          del_files: <value in [disable, enable]>
-          directory: <string>
-          file_size: <integer>
-          gzip_format: <value in [disable, enable]>
-          hour: <integer>
-          ip: <string>
-          ip2: <string>
-          ip3: <string>
-          log_format: <value in [native, text, csv]>
-          min: <integer>
-          password: <list or string>
-          password2: <list or string>
-          password3: <list or string>
-          server_type: <value in [ftp, sftp, scp]>
-          upload: <value in [disable, enable]>
-          upload_hour: <integer>
-          upload_mode: <value in [backup, mirror]>
-          upload_trigger: <value in [on-roll, on-schedule]>
-          username: <string>
-          username2: <string>
-          username3: <string>
-          when: <value in [none, daily, weekly]>
-          port: <integer>
-          port2: <integer>
-          port3: <integer>
-          rolling_upgrade_status: <integer>
-          server: <string>
-          server2: <string>
-          server3: <string>
+          # days:
+          #   - "sun"
+          #   - "mon"
+          #   - "tue"
+          #   - "wed"
+          #   - "thu"
+          #   - "fri"
+          #   - "sat"
+          # del_files: <value in [disable, enable]>
+          # directory: <string>
+          # file_size: <integer>
+          # gzip_format: <value in [disable, enable]>
+          # hour: <integer>
+          # ip: <string>
+          # ip2: <string>
+          # ip3: <string>
+          # log_format: <value in [native, text, csv]>
+          # min: <integer>
+          # password: <list or string>
+          # password2: <list or string>
+          # password3: <list or string>
+          # server_type: <value in [ftp, sftp, scp]>
+          # upload: <value in [disable, enable]>
+          # upload_hour: <integer>
+          # upload_mode: <value in [backup, mirror]>
+          # upload_trigger: <value in [on-roll, on-schedule]>
+          # username: <string>
+          # username2: <string>
+          # username3: <string>
+          # when: <value in [none, daily, weekly]>
+          # port: <integer>
+          # port2: <integer>
+          # port3: <integer>
+          # rolling_upgrade_status: <integer>
+          # server: <string>
+          # server2: <string>
+          # server3: <string>
 '''
 
 RETURN = '''
@@ -366,9 +367,9 @@ def main():
                 'file-size': {'type': 'int'},
                 'gzip-format': {'choices': ['disable', 'enable'], 'type': 'str'},
                 'hour': {'type': 'int'},
-                'ip': {'v_range': [['6.0.0', '7.0.13']], 'type': 'str'},
-                'ip2': {'v_range': [['6.0.0', '7.0.13']], 'type': 'str'},
-                'ip3': {'v_range': [['6.0.0', '7.0.13']], 'type': 'str'},
+                'ip': {'v_range': [['6.0.0', '7.0.14']], 'type': 'str'},
+                'ip2': {'v_range': [['6.0.0', '7.0.14']], 'type': 'str'},
+                'ip3': {'v_range': [['6.0.0', '7.0.14']], 'type': 'str'},
                 'log-format': {'choices': ['native', 'text', 'csv'], 'type': 'str'},
                 'min': {'type': 'int'},
                 'password': {'no_log': True, 'type': 'raw'},
