@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -119,6 +122,7 @@ EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -127,19 +131,19 @@ EXAMPLES = '''
     - name: Configure SDN proxy.
       fortinet.fortimanager.fmgr_system_sdnproxy:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
         state: present # <value in [present, absent]>
         system_sdnproxy:
-          name: <string>
-          password: <list or string>
-          server: <string>
-          server_port: <integer>
-          type: <value in [general, fortimanager]>
-          username: <string>
+          name: "your value" # Required variable, string
+          # password: <list or string>
+          # server: <string>
+          # server_port: <integer>
+          # type: <value in [general, fortimanager]>
+          # username: <string>
 '''
 
 RETURN = '''
@@ -196,6 +200,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'system_sdnproxy': {
             'type': 'dict',
             'v_range': [['7.4.1', '']],
