@@ -73,6 +73,9 @@ options:
         choices:
           - present
           - absent
+    revision_note:
+        description: The change note that can be specified when an object is created or updated.
+        type: str
     workspace_locking_adom:
         description: The adom to lock for FortiManager running in workspace mode, the value can be global and others including root.
         type: str
@@ -172,8 +175,8 @@ EXAMPLES = '''
     - name: User nsx
       fortinet.fortimanager.fmgr_user_nsx:
         # bypass_validation: false
-        workspace_locking_adom: <value in [global, custom adom including root]>
-        workspace_locking_timeout: 300
+        # workspace_locking_adom: <global or your adom name>
+        # workspace_locking_timeout: 300
         # rc_succeeded: [0, -2, -3, ...]
         # rc_failed: [-2, -3, ...]
         adom: <your own value>
@@ -252,6 +255,7 @@ def main():
     module_primary_key = 'name'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
+        'revision_note': {'type': 'str'},
         'user_nsx': {
             'type': 'dict',
             'v_range': [['6.2.1', '']],
@@ -278,7 +282,7 @@ def main():
                     'elements': 'dict'
                 },
                 'service-manager-id': {'v_range': [['7.0.4', '']], 'type': 'str'},
-                'service-manager-rev': {'v_range': [['7.0.4', '7.0.13'], ['7.2.1', '']], 'type': 'int'}
+                'service-manager-rev': {'v_range': [['7.0.4', '7.0.14'], ['7.2.1', '']], 'type': 'int'}
             }
         }
     }
