@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2022 NetApp
+# Copyright (c) 2018-2025 NetApp
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit tests for module_utils netapp.py - REST features '''
@@ -13,6 +13,7 @@ import tempfile
 from ansible.module_utils import basic
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import call, patch
 
+# pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import \
     assert_no_warnings, assert_warning_was_raised, create_module, expect_and_capture_ansible_exception, patch_ansible, print_warnings
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import patch_request_and_invoke, register_responses
@@ -182,7 +183,8 @@ def test_is_rest_false():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
     ])
-    rest_api = create_restapi_object(DEFAULT_ARGS)
+    args = {'use_rest': 'auto'}
+    rest_api = create_restapi_object(DEFAULT_ARGS, args)
     is_rest = rest_api.is_rest()
     print(rest_api.errors)
     print(rest_api.debug_logs)
@@ -197,7 +199,8 @@ def test_is_rest_false_9_5():
     register_responses([
         ('GET', 'cluster', SRR['is_rest_95']),
     ])
-    rest_api = create_restapi_object(DEFAULT_ARGS)
+    args = {'use_rest': 'auto'}
+    rest_api = create_restapi_object(DEFAULT_ARGS, args)
     is_rest = rest_api.is_rest()
     print(rest_api.errors)
     print(rest_api.debug_logs)
@@ -220,36 +223,12 @@ def test_is_rest_true_9_6():
     assert not rest_api.debug_logs
 
 
-def test_fail_has_username_password_and_cert():
-    ''' failure case in auth_method '''
-    module_args = dict(cert_filepath='dummy')
-    msg = 'Error: cannot have both basic authentication (username/password) and certificate authentication (cert/key files)'
-    assert expect_and_capture_ansible_exception(create_restapi_object, 'fail', DEFAULT_ARGS, module_args)['msg'] == msg
-
-
-def test_fail_has_username_password_and_key():
-    ''' failure case in auth_method '''
-    module_args = dict(key_filepath='dummy')
-    msg = 'Error: cannot have both basic authentication (username/password) and certificate authentication (cert/key files)'
-    assert expect_and_capture_ansible_exception(create_restapi_object, 'fail', DEFAULT_ARGS, module_args)['msg'] == msg
-
-
-def test_fail_has_username_and_cert():
-    ''' failure case in auth_method '''
-    args = dict(DEFAULT_ARGS)
-    module_args = dict(cert_filepath='dummy')
-    del args['password']
-    msg = 'Error: username and password have to be provided together and cannot be used with cert or key files'
-    assert expect_and_capture_ansible_exception(create_restapi_object, 'fail', args, module_args)['msg'] == msg
-
-
 def test_fail_has_password_and_cert():
     ''' failure case in auth_method '''
     args = dict(DEFAULT_ARGS)
-    module_args = dict(cert_filepath='dummy')
     del args['username']
-    msg = 'Error: username and password have to be provided together and cannot be used with cert or key files'
-    assert expect_and_capture_ansible_exception(create_restapi_object, 'fail', args, module_args)['msg'] == msg
+    msg = 'Error: username and password have to be provided together'
+    assert expect_and_capture_ansible_exception(create_restapi_object, 'fail', args)['msg'] == msg
 
 
 def test_has_username_password():
@@ -299,11 +278,10 @@ def test_ontaprestapi_init():
 
 @patch('logging.basicConfig')
 def test_ontaprestapi_logging(mock_config):
-    module_args = {'http_port': 123}
-    rest_api = create_restapi_object(DEFAULT_ARGS)
+    create_restapi_object(DEFAULT_ARGS)
     assert not mock_config.mock_calls
     module_args = {'feature_flags': {'trace_apis': True}}
-    rest_api = create_restapi_object(DEFAULT_ARGS, module_args)
+    create_restapi_object(DEFAULT_ARGS, module_args)
     assert len(mock_config.mock_calls) == 1
 
 
