@@ -9,8 +9,8 @@ __metaclass__ = type
 import pytest
 import sys
 
-from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+# pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import\
     patch_request_and_invoke, register_responses
 from ansible_collections.netapp.ontap.tests.unit.framework.rest_factory import rest_error_message, rest_responses
@@ -391,7 +391,6 @@ def test_negative_unknown_services():
     error = 'Error: unknown service: data_nfs9.  New services may need to be added to "additional_services".'
     assert error in call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
     assert_no_warnings()
-    error = 'Error: unknown service: data_nfs9.  New services may need to be added to "additional_services".'
     module_args = {
         'services': ['data_nfs9', 'data_cifs', 'dummy'],
         'vserver': 'vserver',
