@@ -1,4 +1,4 @@
-# (c) 2018, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit tests ONTAP Ansible module: na_ontap_user '''
@@ -7,9 +7,9 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 import pytest
 
-from ansible_collections.netapp.ontap.tests.unit.compat import unittest
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+# pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import\
     patch_request_and_invoke, register_responses
 from ansible_collections.netapp.ontap.tests.unit.framework.rest_factory import rest_error_message, rest_responses
@@ -19,8 +19,8 @@ from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mo
 
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_user import NetAppOntapUser as my_module, main as my_main   # module under test
 
-if not netapp_utils.has_netapp_lib():
-    pytestmark = pytest.mark.skip('skipping as missing required netapp_lib')
+# if not netapp_utils.has_netapp_lib():
+#     pytestmark = pytest.mark.skip('skipping as missing required netapp_lib')
 
 # REST API canned responses when mocking send_request
 SRR = rest_responses({
@@ -91,6 +91,7 @@ DEFAULT_ARGS = {
 }
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_module_fail_when_required_args_missing():
     ''' required arguments are reported as errors '''
     register_responses([
@@ -101,6 +102,22 @@ def test_module_fail_when_required_args_missing():
     print('Info: %s' % call_main(my_main, {}, module_args, fail=True)['msg'])
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
+def test_module_fail_when_vserver_missing():
+    ''' required arguments are reported as errors '''
+    register_responses([
+    ])
+    module_args = {
+        'use_rest': 'never',
+        'hostname': 'hostname',
+        'username': 'username',
+        'password': 'password',
+        'name': 'user_name',
+    }
+    assert 'Error: vserver is required' in call_main(my_main, {}, module_args, fail=True)['msg']
+
+
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_get_called():
     ''' a more interesting test '''
     register_responses([
@@ -119,6 +136,7 @@ def test_ensure_user_get_called():
     assert user_info is None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_get_called_not_found():
     ''' a more interesting test '''
     register_responses([
@@ -137,6 +155,7 @@ def test_ensure_user_get_called_not_found():
     assert user_info is None
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_apply_called():
     ''' creating user and checking idempotency '''
     register_responses([
@@ -155,6 +174,7 @@ def test_ensure_user_apply_called():
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_sp_apply_called():
     ''' creating user with service_processor application and idempotency '''
     register_responses([
@@ -179,6 +199,7 @@ def test_ensure_user_sp_apply_called():
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_apply_for_delete_called():
     ''' deleting user and checking idempotency '''
     register_responses([
@@ -198,6 +219,7 @@ def test_ensure_user_apply_for_delete_called():
     assert not call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_lock_called():
     ''' changing user_lock to True and checking idempotency'''
     register_responses([
@@ -218,6 +240,7 @@ def test_ensure_user_lock_called():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_unlock_called():
     ''' changing user_lock to False and checking idempotency'''
     register_responses([
@@ -238,6 +261,7 @@ def test_ensure_user_unlock_called():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_set_password_called():
     ''' set password '''
     register_responses([
@@ -255,6 +279,7 @@ def test_ensure_user_set_password_called():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_set_password_internal_error():
     ''' set password '''
     register_responses([
@@ -272,6 +297,7 @@ def test_set_password_internal_error():
     assert not my_obj.change_password()
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_set_password_reused():
     ''' set password '''
     register_responses([
@@ -289,6 +315,7 @@ def test_set_password_reused():
     assert not my_obj.change_password()
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_role_update_called():
     ''' set password '''
     register_responses([
@@ -307,6 +334,7 @@ def test_ensure_user_role_update_called():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_ensure_user_role_update_additional_application_called():
     ''' set password '''
     register_responses([
@@ -328,6 +356,7 @@ def test_ensure_user_role_update_additional_application_called():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_if_all_methods_catch_exception():
     register_responses([
         ('ZAPI', 'security-login-get-iter', ZRR['error']),
@@ -353,8 +382,11 @@ def test_if_all_methods_catch_exception():
     assert zapi_error_message('Error removing user user_name') in expect_and_capture_ansible_exception(my_obj.delete_user, 'fail', app)['msg']
     assert zapi_error_message('Error setting password for user user_name') in expect_and_capture_ansible_exception(my_obj.change_password, 'fail')['msg']
     assert zapi_error_message('Error modifying user user_name') in expect_and_capture_ansible_exception(my_obj.modify_user, 'fail', app, ['password'])['msg']
+    err_msg = 'vserver is required with ZAPI'
+    assert err_msg in create_module(my_module, DEFAULT_ARGS, {'use_rest': 'never', 'svm': None}, fail=True)['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_create_user_with_usm_auth():
     ''' switching back to ZAPI '''
     register_responses([
@@ -426,6 +458,27 @@ def test_ensure_create_user_rest_called():
     assert call_main(my_main, DEFAULT_ARGS, module_args)['changed']
 
 
+def test_ensure_create_cluster_user_rest_called():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest']),
+        ('GET', 'security/accounts', SRR['zero_records']),
+        ('POST', 'security/accounts', SRR['empty_good']),
+    ])
+    module_args = {
+        "hostname": "hostname",
+        "username": "username",
+        "password": "password",
+        "name": "user_name",
+        "use_rest": "always",
+        'role_name': 'vsadmin',
+        'applications': ['http', 'ontapi'],
+        'authentication_method': 'password',
+        'set_password': 'xfjjttjwll`1',
+        'lock_user': True
+    }
+    assert call_main(my_main, module_args)['changed']
+
+
 def test_ensure_delete_user_rest_called():
     register_responses([
         ('GET', 'cluster', SRR['is_rest']),
@@ -539,10 +592,11 @@ def test_negative_zapi_missing_netapp_lib(mock_has):
     module_args = {
         'use_rest': 'never',
     }
-    msg = "Error: the python NetApp-Lib module is required.  Import error: None"
-    assert msg == call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
+    msg = "Error: the python NetApp-Lib module is required."
+    assert msg in call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
 
 
+@pytest.mark.skipif(not netapp_utils.has_netapp_lib(), reason="skipping as missing required netapp_lib")
 def test_negative_zapi_missing_apps():
     register_responses([
     ])
